@@ -2,8 +2,8 @@
 //                              App_gSpiceUI.hpp                                                   *
 //                             ------------------                                                  *
 // Started     : 2003-08-15                                                                        *
-// Last Update : 2014-12-13                                                                        *
-// Copyright   : (C) 2003 by MSWaters                                                              *
+// Last Update : 2018-10-10                                                                        *
+// Copyright   : (C) 2003-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -17,11 +17,14 @@
 #include "App_gSpiceUI.hpp"
 
 //**************************************************************************************************
-// All programs must have a "main" function. Under wxWidgets main( ) is
-// implemented using the following macro which creates an application instance
-// and starts program execution.
+// All programs must have a "main" function. Under wxWidgets main( ) is implemented using the
+// following macro which creates an application instance and starts program execution.
 
+#if wxCHECK_VERSION( 3,0,0 )
 wxIMPLEMENT_APP( App_gSpiceUI );
+#else
+wxIMPLEMENT_APP( App_gSpiceUI )
+#endif
 
 //**************************************************************************************************
 // Implement an event table in which the events are routed to their respective
@@ -50,6 +53,37 @@ App_gSpiceUI::~App_gSpiceUI( )
 {
 }
 
+//**************************************************************************************************
+// Set the configuration file name and update its contents based on the command line arguments.
+
+void  App_gSpiceUI::UpdateCfg( void )
+{
+  // Set the simulation engine type
+  if( m_oCmdLn.m_eSimEng     != eSIMR_NONE ) g_oConfig.bSetSimEng( m_oCmdLn.m_eSimEng );
+
+  // Set the schematic capture / editor program
+  if( m_oCmdLn.m_eEdaSuite   != eEDA_NONE  ) g_oConfig.bSetEdaSuite( m_oCmdLn.m_eEdaSuite );
+
+  // Set the waveform data viewer utility
+  if( m_oCmdLn.m_eDataViewer != eVIEW_NONE ) g_oConfig.bSetDataViewer( m_oCmdLn.m_eDataViewer );
+
+  // Set the analysis type
+  if( m_oCmdLn.m_eAnalysis   != eCMD_NONE  ) g_oConfig.bSetAnalysis( m_oCmdLn.m_eAnalysis );
+
+  // Set the Guile procedure to be used by GNetList
+  if( ! m_oCmdLn.m_osGuileProc.IsEmpty( )  ) g_oConfig.bSetGuileProc( m_oCmdLn.m_osGuileProc );
+
+  // Set the netlist and/or the schematics file name/s
+  if( ! m_oCmdLn.m_osNetLstFile.IsEmpty( ) || ! m_oCmdLn.m_osaSchemFiles.IsEmpty( ) )
+  {
+      g_oConfig.bSetNetLstFile( m_oCmdLn.m_osNetLstFile  );
+      g_oConfig.bSetSchemFiles( m_oCmdLn.m_osaSchemFiles );
+  }
+
+  // Write any changes to file
+  g_oConfig.bFlush( );
+}
+
 //**************************************************************************************************
 //                                         Event Handlers                                          *
 //**************************************************************************************************
@@ -65,12 +99,23 @@ bool  App_gSpiceUI::OnInit( void )
 {
   // The following lines magically makes locale stuff work, don't touch!
   m_oLocale.Init( wxLANGUAGE_DEFAULT, wxLOCALE_LOAD_DEFAULT );
-//  setlocale( LC_ALL, "C" );
   setlocale( LC_NUMERIC, "C" );
 
-  // Set the command line and process it
-  if( ! m_oCmdLnPcr.bSetCmdLine( argc, argv ) ) return( false );
-  if( ! m_oCmdLnPcr.bProcArgs( ) )              return( false );
+  // Process the command line
+  if( ! m_oCmdLn.bSetCmdLn( argc, argv ) ) return( false );
+  if( ! m_oCmdLn.bProcArgs( ) )            return( false );
+
+  // Open the global configuration object (this needs to happen as early as possible)
+  if( ! m_oCmdLn.m_osConfigFile.IsEmpty( ) )
+       g_oConfig.bSetFileName( m_oCmdLn.m_osConfigFile );
+  else g_oConfig.bSetFileName( wxString( wxT('.') ) + GetAppName( ) + wxT(".conf") );
+  g_oConfig.bOpen( );
+
+  // Update the configuration with command line argument values (if any)
+  UpdateCfg( );
+
+  // Rebuild/clean the configuration file if requested
+  if( m_oCmdLn.m_bCleanCfgFile ) g_oConfig.bClean( );
 
   // Create the GUI
   m_poFrmMain = new FrmMain( this );
@@ -86,10 +131,9 @@ bool  App_gSpiceUI::OnInit( void )
 //**************************************************************************************************
 // wxWidgets calls wxApp::OnRun( ) to start execution of the application.
 //
-// This function is where the execution of a program written in wxWidgets
-// starts. The default implementation just enters the main loop and starts
-// handling the events until it terminates. The return value of this function
-// becomes the exit code of the application.
+// This function is where the execution of a program written in wxWidgets starts. The default
+// implementation just enters the main loop and starts handling the events until it terminates. The
+// return value of this function becomes the exit code of the application.
 //
 // Return Values :
 //   EXIT_SUCCESS - application exit code on success
@@ -97,42 +141,23 @@ bool  App_gSpiceUI::OnInit( void )
 /*
 int  App_gSpiceUI::OnRun( void )
 {
-  MainLoop( );
 
   return( EXIT_SUCCESS );
 }
-// */
-//**************************************************************************************************
-// wxWidgets calls wxApp::Mainloop( ) on creation of the application.
-//
-// Return Values :
-//   0 - the return value is not used
-/*
-int  App_gSpiceUI::MainLoop( void )
-{
-  while( m_poFrmMain->bIsOpen( ) )
-  {
-     Yield( );            // Allow messages in the event queue to be processed
-
-     wxMilliSleep( 100 ); // Sleep for 100msec
-  }
-
-  return( 0 );
-}
-// */
+*/
 //**************************************************************************************************
 // wxWidgets calls wxApp::OnExit( ) on application termination.
 //
-// This method does any processing which needs to be done as the application is
-// about to exit. Note that it is not called at all if OnInit( ) failed.
+// This method does any processing which needs to be done as the application is about to exit. Note
+// that it is not called at all if OnInit( ) failed.
 //
 // Return Values :
 //   0 - the return value is not used
 
 int  App_gSpiceUI::OnExit( void )
 {
-  // Delete the global configuration object
-  delete wxConfig::Set( (wxConfig *) NULL );
+  g_oConfig.bFlush( );
+  g_oConfig.bClose( );
 
   return( 0 );
 }
