@@ -3,8 +3,8 @@
 //                                       ------------------                                        *
 // Description : The main application class. It all begins here.                                   *
 // Started     : 2003-08-15                                                                        *
-// Last Update : 2015-01-05                                                                        *
-// Copyright   : (C) 2003 by MSWaters                                                              *
+// Last Update : 2018-10-23                                                                        *
+// Copyright   : (C) 2003-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -18,25 +18,17 @@
 #ifndef APP_GSPICEUI_HPP
 #define APP_GSPICEUI_HPP
 
-// System includes
-
-//#include <iostream>
-
-// In the following include using <locale.h> instead of <clocale> at the request of a user running
-// Solaris 9 on a Ultra SPARC and Sun's C++ compiler.
-//#include <locale.h> ???
-
 // Application includes
 
 #include "CmdLinePcr.hpp"
+#include "Config.hpp"
 #include "main/FrmMain.hpp"
 
-// wxWidgets includes
+// This flag indicates debug mode, if it's enabled the app. will produce lots of lovely console spew
+bool    g_bDebug;
 
-#include <wx/config.h>
-
-// This flag indicates debug mode, if it's enabled gspiceui will produce lots of lovely console spew
-bool  g_bDebug;
+// This object is the global interface to the configuration file
+Config  g_oConfig;
 
 //**************************************************************************************************
 
@@ -45,18 +37,19 @@ class App_gSpiceUI : public wxApp
   private :
 
     wxLocale    m_oLocale;
-    CmdLinePcr  m_oCmdLnPcr;
+    CmdLinePcr  m_oCmdLn;
     FrmMain   * m_poFrmMain;
 
+    void  UpdateCfg( void );
+
   public :
 
-    App_gSpiceUI( void );
-   ~App_gSpiceUI( );
+          App_gSpiceUI( void );
+         ~App_gSpiceUI( );
 
     // Event handlers
     virtual  bool  OnInit  ( void );
 //  virtual  int   OnRun   ( void );
-//  virtual  int   MainLoop( void );
     virtual  int   OnExit  ( void );
 
     // Leave this as the last line as private access is envoked by this macro
