@@ -3,8 +3,8 @@
 //                                        ----------------                                         *
 // Description : This class does the command line processing.                                      *
 // Started     : 2005-02-22                                                                        *
-// Last Update : 2015-01-09                                                                        *
-// Copyright   : (C) 2005 by MSWaters                                                              *
+// Last Update : 2018-10-13                                                                        *
+// Copyright   : (C) 2005-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -18,10 +18,6 @@
 #ifndef CMDLINEPCR_HPP
 #define CMDLINEPCR_HPP
 
-// System includes
-
-//#include <iostream>
-
 // Application includes
 
 #include "Version.hpp"
@@ -30,18 +26,9 @@
 
 // wxWidgets includes
 
-#include <wx/config.h>
 #include <wx/cmdline.h>
 #include <wx/filename.h>
 
-// Local constant declarations
-
-#define CLP_NGSPICE  wxT("NG-Spice")
-#define CLP_GNUCAP   wxT("GNU-Cap")
-
-#define CLP_GAW      wxT("Gaw")
-#define CLP_GWAVE    wxT("Gwave")
-
 //**************************************************************************************************
 
 class CmdLinePcr : wxCmdLineParser
@@ -51,18 +38,24 @@ class CmdLinePcr : wxCmdLineParser
     int            m_iArgC;
     wxChar **      m_ppsArgV;
 
-    wxString       m_osSimrType;
-    wxString       m_osAnaType;
+  public :
+
+    eTypeSimEng    m_eSimEng;
+    eTypeEDA       m_eEdaSuite;
+    eTypeViewer    m_eDataViewer;
+    eTypeCmd       m_eAnalysis;
     wxString       m_osGuileProc;
-    wxString       m_osViewer;
     wxString       m_osConfigFile;
     wxString       m_osNetLstFile;
     wxArrayString  m_osaSchemFiles;
     bool           m_bCleanCfgFile;
 
+  private :
+
     bool  bProcOption_a( int * piArg );  // Analysis page specifier
     bool  bProcOption_c( int * piArg );  // Rebuild/clean configuration file
     bool  bProcOption_d( int * piArg );  // Print debug info. to console
+    bool  bProcOption_e( int * piArg );  // Specify the EDA tool suite
     bool  bProcOption_g( int * piArg );  // Specify Guile procedure for importing schematic file/s
     bool  bProcOption_h( int * piArg );  // Display usage and exit
     bool  bProcOption_r( int * piArg );  // Specify a configuration file
@@ -74,23 +67,19 @@ class CmdLinePcr : wxCmdLineParser
     bool  bProcSchems  ( int * piArg );  // Schematic file name/s
     bool  bProcNetList ( int * piArg );  // Netlist file name
 
-    void  Usage( void );
-    void  Version( void );
-
-    void  SetConfig( void );
-    void  CleanCfgFile( void );
+    void  Usage        ( void );
+    void  Version      ( void );
+    void  TooManyArgs  ( int iArg );
 
   public :
 
           CmdLinePcr( void );
          ~CmdLinePcr( );
 
-    bool  bClear( void );
-    bool  bSetCmdLine( int iArgC, wxChar ** ppsArgV );
+    bool  bClear   ( void );
+    bool  bSetCmdLn( int iArgC, wxChar ** ppsArgV );
     bool  bProcArgs( void );
 
-    const wxString & rosGetConfigFile( void ) { return( m_osConfigFile ); }
-
     void  Print( const wxString & rosPrefix=wxT("  ") );
 };
 
