@@ -1,9 +1,9 @@
 //**************************************************************************************************
 //                                           CmdBase.cpp                                           *
 //                                          -------------                                          *
-//  Started     : 2006-08-31                                                                       *
-//  Last Update : 2015-03-04                                                                       *
-//  Copyright   : (C) 2006 by MSWaters                                                             *
+// Started     : 2006-08-31                                                                        *
+// Last Update : 2018-09-25                                                                        *
+// Copyright   : (C) 2006-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -19,9 +19,23 @@
 //**************************************************************************************************
 // Constructor.
 
-CmdBase::CmdBase( void ) : wxString( wxT("") )
+CmdBase::CmdBase( void ) : wxString( )
 {
-  bSetDefaults( );
+  m_osErrMsg = wxT("Invalid");
+
+  m_eSimEng  = eSIMR_NONE;
+  m_eCmdType = eCMD_NONE;
+}
+
+//**************************************************************************************************
+// Copy constructor.
+//
+// Argument List :
+//   roCmd - A reference to the object to be copied
+
+CmdBase::CmdBase( const CmdBase & roCmd ) : wxString( )
+{
+  *this = roCmd;
 }
 
 //**************************************************************************************************
@@ -122,11 +136,9 @@ CmdBase & CmdBase::operator = ( const CmdBase & roCmd )
 
 void  CmdBase::Print( const wxString & rosPrefix )
 {
-  std::cout << rosPrefix .mb_str( ) << "wxString   : \""
-            << this     ->mb_str( ) << "\"\n";
+  std::cout << rosPrefix .mb_str( ) << "wxString   : \"" << this     ->mb_str( ) << "\"\n";
 
-  std::cout << rosPrefix .mb_str( ) << "m_osErrMsg : \""
-            << m_osErrMsg.mb_str( ) << "\"\n";
+  std::cout << rosPrefix .mb_str( ) << "m_osErrMsg : \"" << m_osErrMsg.mb_str( ) << "\"\n";
 
   std::cout << rosPrefix .mb_str( ) << "m_eSimEng  : ";
   switch( m_eSimEng )
