@@ -2,8 +2,8 @@
 //                                         PnlAnaBase.cpp                                          *
 //                                        ----------------                                         *
 // Started     : 2004-04-26                                                                        *
-// Last Update : 2015-03-29                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-11-04                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -16,20 +16,6 @@
 
 #include "PnlAnaBase.hpp"
 
-//**************************************************************************************************
-// Allocate storage for static data members.
-
-Component  PnlAnaBase::m_oCpntSwpSrc;
-
-//**************************************************************************************************
-// Implement an event table.
-
-wxBEGIN_EVENT_TABLE( PnlAnaBase, wxPanel )
-
-  EVT_CHOICE( PnlAnaBase::ID_CHO_SRCNAME, PnlAnaBase::OnSrcName )
-
-wxEND_EVENT_TABLE( )
-
 //**************************************************************************************************
 // Constructor.
 //
@@ -39,8 +25,6 @@ wxEND_EVENT_TABLE( )
 PnlAnaBase::PnlAnaBase( wxWindow * poWin ) : wxPanel( poWin )
 {
   m_eAnaType = eCMD_NONE;
-
-  bClear( );
 }
 
 //**************************************************************************************************
@@ -59,7 +43,7 @@ PnlAnaBase::~PnlAnaBase( )
 
 bool  PnlAnaBase::bClear( void )
 {
-  m_osErrMsg.Empty( ); // Clear the error string
+  m_osErrMsg.Empty( );  // Clear the error string
 
   return( true );
 }
@@ -80,21 +64,23 @@ void  PnlAnaBase::CreateBase( void )
 
   // Create and add sweep parameter labels
 #ifdef LAYOUT_MNGR
-  m_oPnlStart.bCreate( poPnl, ID_PNL_START, 120 );
-  m_oPnlStop .bCreate( poPnl, ID_PNL_STOP,  120 );
-  m_oPnlStep .bCreate( poPnl, ID_PNL_STEP,  120 );
+  m_oPnlStart .bCreate( poPnl, ID_PNL_START, 123, 95, 82 );
+  m_oPnlStop  .bCreate( poPnl, ID_PNL_STOP,  123, 95, 82 );
+  m_oPnlStep  .bCreate( poPnl, ID_PNL_STEP,  123, 95, 82 );
 #else
   m_oSbxSwpPars.Create( poPnl, ID_UNUSED, wxT(" Sweep Parameters "), wxPoint(  6,  5 ),
                         wxSize( 330, 167 ) );
-  m_oPnlStart.bCreate( poPnl, ID_PNL_START, 123, 95, 82,             wxPoint( 22, 26 ) );
-  m_oPnlStop .bCreate( poPnl, ID_PNL_STOP,  123, 95, 82,             wxPoint( 22, 56 ) );
-  m_oPnlStep .bCreate( poPnl, ID_PNL_STEP,  123, 95, 82,             wxPoint( 22, 86 ) );
+  m_oPnlStart .bCreate( poPnl, ID_PNL_START, 123, 95, 82,            wxPoint( 22, 26 ) );
+  m_oPnlStop  .bCreate( poPnl, ID_PNL_STOP,  123, 95, 82,            wxPoint( 22, 56 ) );
+  m_oPnlStep  .bCreate( poPnl, ID_PNL_STEP,  123, 95, 82,            wxPoint( 22, 86 ) );
+
+  // Set static box font
+  m_oSbxSwpPars.SetOwnFont( FONT_SLANT );
 #endif // LAYOUT_MNGR
 
-  m_oPnlStart.bSetName( wxT("Start Value") );
-  m_oPnlStop .bSetName( wxT("Stop Value") );
-  m_oPnlStep .bSetName( wxT("Step Increment") );
-  m_oSbxSwpPars.SetOwnFont( FONT_SLANT );
+  m_oPnlStart .bSetName( wxT("Start Value") );
+  m_oPnlStop  .bSetName( wxT("Stop Value") );
+  m_oPnlStep  .bSetName( wxT("Step Increment") );
 
   // Create the parameter (probe) panel and controls
 #ifdef LAYOUT_MNGR
@@ -105,10 +91,10 @@ void  PnlAnaBase::CreateBase( void )
 
   // Create and add simulation parameter check boxes
 #ifdef LAYOUT_MNGR
-  m_oCbxVoltage .Create( poPnl, ID_CBX_VOLT, wxT("Voltage")    );
-  m_oCbxCurrent .Create( poPnl, ID_CBX_CURR, wxT("Current")    );
-  m_oCbxPower   .Create( poPnl, ID_CBX_PWR,  wxT("Power")      );
-  m_oCbxResist  .Create( poPnl, ID_CBX_RES,  wxT("Resistance") );
+  m_oCbxVoltage .Create( poPnl, ID_CBX_VOLT, wxT("Voltage")      );
+  m_oCbxCurrent .Create( poPnl, ID_CBX_CURR, wxT("Current")      );
+  m_oCbxPower   .Create( poPnl, ID_CBX_PWR,  wxT("Power")        );
+  m_oCbxResist  .Create( poPnl, ID_CBX_RES,  wxT("Resistance  ") );
 #else
   m_oSbxCalcPars.Create( poPnl, ID_UNUSED  , wxT(" Parameters "),    wxPoint( 343,   5 ),
                          wxSize( 105, 122 ) );
@@ -116,12 +102,15 @@ void  PnlAnaBase::CreateBase( void )
   m_oCbxCurrent .Create( poPnl, ID_CBX_CURR, wxT("Current"),         wxPoint( 349,  50 ) );
   m_oCbxPower   .Create( poPnl, ID_CBX_PWR,  wxT("Power"),           wxPoint( 349,  75 ) );
   m_oCbxResist  .Create( poPnl, ID_CBX_RES,  wxT("Resistance"),      wxPoint( 349, 100 ) );
-#endif // LAYOUT_MNGR
+
+  // Set static box font
   m_oSbxCalcPars.SetOwnFont( FONT_SLANT );
+#endif // LAYOUT_MNGR
 
   // Create and add .OPTIONS configuration dialog button
 #ifdef LAYOUT_MNGR
   m_oBtnOPTIONS.Create( this, ID_BTN_OPTIONS, wxT(".OPTIONS ...") );
+  m_oBtnOPTIONS.SetMinSize( wxSize( 105, GUI_CTRL_HT+4 ) );
 #else
   m_oBtnOPTIONS.Create( this, ID_BTN_OPTIONS, wxT(".OPTIONS ..."),   wxPoint( 343, 135 ),
                         wxSize( 105, -1 ) );
@@ -175,17 +164,16 @@ void  PnlAnaBase::CreateSigSrc( void )
   // Create and add input source
 #ifdef LAYOUT_MNGR
   m_oChoSrcName.Create( poPnl, ID_CHO_SRCNAME );
-  m_oPnlSrcLvl.bCreate( poPnl, ID_PNL_SRCLVL  );
+  m_oChoSrcName.SetMinSize( wxSize( 121, GUI_CTRL_HT ) );
 #else
   m_oSbxSigSrc .Create( poPnl, ID_UNUSED, wxT(" Signal Source "), wxPoint(   6, 178 ),
-                        wxSize( 330, 60 ) );
+                        wxSize( 145, 60 ) );
   m_oChoSrcName.Create( poPnl, ID_CHO_SRCNAME,                    wxPoint(  18, 200 ),
                         wxSize( 121, GUI_CTRL_HT ) );
-  m_oPnlSrcLvl.bCreate( poPnl, ID_PNL_SRCLVL, -1, 95, 82,         wxPoint( 142, 200 ) );
-#endif // LAYOUT_MNGR
 
   // Set static box font
   m_oSbxSigSrc.SetOwnFont( FONT_SLANT );
+#endif // LAYOUT_MNGR
 }
 
 //**************************************************************************************************
@@ -204,11 +192,11 @@ void  PnlAnaBase::CreateCpxPrt( void )
 
   // Create and add simulation parameter complex part check boxes
 #ifdef LAYOUT_MNGR
-  m_oCbxMag   .Create( poPnl, ID_CBX_MAG  , wxT("Magnitude")  );
-  m_oCbxPhase .Create( poPnl, ID_CBX_PHASE, wxT("Phase")      );
-  m_oCbxReal  .Create( poPnl, ID_CBX_REAL , wxT("Real Part")  );
-  m_oCbxImag  .Create( poPnl, ID_CBX_IMAG , wxT("Imag. Part") );
-  m_oCbxMagDb .Create( poPnl, ID_CBX_MAGDB, wxT("Mag. in dB") );
+  m_oCbxMag   .Create( poPnl, ID_CBX_MAG  , wxT("Magnitude")     );
+  m_oCbxPhase .Create( poPnl, ID_CBX_PHASE, wxT("Phase")         );
+  m_oCbxReal  .Create( poPnl, ID_CBX_REAL , wxT("Real Part")     );
+  m_oCbxImag  .Create( poPnl, ID_CBX_IMAG , wxT("Imag. Part")    );
+  m_oCbxMagDb .Create( poPnl, ID_CBX_MAGDB, wxT("Mag. in dB   ") );
 #else
   m_oSbxCpxPrt.Create( poPnl, ID_UNUSED,    wxT(" Complex Parts "), wxPoint( 455,   5 ),
                        wxSize( 110, 146 ) );
@@ -217,10 +205,10 @@ void  PnlAnaBase::CreateCpxPrt( void )
   m_oCbxReal  .Create( poPnl, ID_CBX_REAL,  wxT("Real Part"),       wxPoint( 461,  74 ) );
   m_oCbxImag  .Create( poPnl, ID_CBX_IMAG,  wxT("Imag. Part"),      wxPoint( 461,  99 ) );
   m_oCbxMagDb .Create( poPnl, ID_CBX_MAGDB, wxT("Mag. in dB"),      wxPoint( 461, 124 ) );
-#endif // LAYOUT_MNGR
 
   // Set static box font
   m_oSbxCpxPrt.SetOwnFont( FONT_SLANT );
+#endif // LAYOUT_MNGR
 }
 
 //**************************************************************************************************
@@ -239,15 +227,15 @@ void  PnlAnaBase::CreateTemp( void )
 
   // Create and add analysis temperature
 #ifdef LAYOUT_MNGR
-  m_oPnlTemp.bCreate( poPnl, ID_PNL_TEMP );
+  m_oPnlTemp.bCreate( poPnl, ID_PNL_TEMP, 0, 85, 20 );
 #else
   m_oSbxTemp. Create( poPnl, ID_UNUSED, wxT(" Temperature "), wxPoint( 343, 178 ),
                       wxSize( 156, 60 ) );
-  m_oPnlTemp.bCreate( poPnl, ID_PNL_TEMP, 0, 95, 40,          wxPoint( 353, 200 ) );
-#endif // LAYOUT_MNGR
+  m_oPnlTemp.bCreate( poPnl, ID_PNL_TEMP, 0, 85, 20,          wxPoint( 353, 200 ) );
 
   // Set static box font
   m_oSbxTemp.SetOwnFont( FONT_SLANT );
+#endif // LAYOUT_MNGR
 
   // Set PnlValue parameters
   m_oPnlTemp.bShowUnits( PnlValue::eSHOW_LBL );
@@ -258,122 +246,157 @@ void  PnlAnaBase::CreateTemp( void )
 //**************************************************************************************************
 // Layout the panel display objects.
 
+#ifdef LAYOUT_MNGR
+
 void  PnlAnaBase::DoLayout( void )
 {
-#ifndef LAYOUT_MNGR
-  return;
-#endif
-
-  wxWindow       * poWin;
-  wxSizer        * poSzr;
-  wxGridBagSizer * poSzrGB;
-  wxSizerFlags     oFlags;
-  wxGBPosition     oGBPosn;
-  wxGBSpan         oGBSpan;
-  int              iFlags;
-  int              iBorder;
+  wxWindow         * poWin;
+  wxStaticBoxSizer * poSzrSB;
+  wxGridBagSizer   * poSzrGB;
+  wxSizerFlags       oFlags;
+  wxGBPosition       oGBPosn;
+  wxGBSpan           oGBSpan;
+  wxFont             oFont;
+  int                iFlags;
+  int                iBorder;
 
   //---------------------------------------------------------------------------
   // Create and set the sizer for the sweep panel
+
   poWin = m_oPnlStart.GetParent( );
-  poSzr = new wxStaticBoxSizer( wxVERTICAL, poWin, wxT(" Sweep Parameters ") );
-  poWin->SetSizer( poSzr );
+  poSzrSB = new wxStaticBoxSizer( wxVERTICAL, poWin, wxT(" Sweep Parameters ") );
+  poWin->SetSizer( poSzrSB );
+
+  // Set the font for the static box label
+  oFont = poSzrSB->GetStaticBox( )->GetFont( );
+  oFont.SetStyle( wxFONTSTYLE_ITALIC );
+  poSzrSB->GetStaticBox( )->SetFont( oFont );
 
   // Layout the sweep panel
   oFlags.Align( wxALIGN_LEFT );
-  oFlags.Border( wxALL & ~wxBOTTOM, 3 );
-  poSzr->Add( &m_oPnlStart, oFlags );
-  poSzr->Add( &m_oPnlStop , oFlags );
-  poSzr->Add( &m_oPnlStep , oFlags );
-  poSzr->AddSpacer( 3 );
-  poSzr->Add( &m_oRbxSweep, oFlags );
+  oFlags.Border( wxLEFT | wxRIGHT, 8 );
+  poSzrSB->AddSpacer( 7 );
+  poSzrSB->Add( &m_oPnlStart, oFlags );
+  poSzrSB->Add( &m_oPnlStop , oFlags );
+  poSzrSB->Add( &m_oPnlStep , oFlags );
+  poSzrSB->AddSpacer( 6 );
+  oFlags.Border( wxLEFT          , 6 );
+  poSzrSB->Add( &m_oRbxSweep, oFlags );
+  poSzrSB->AddSpacer( 6 );
 
   //---------------------------------------------------------------------------
   // If required create the signal source panel
+
   poWin = m_oChoSrcName.GetParent( );
   if( poWin != NULL )
   {
     // Create and set the sizer for the signal source panel
-    poSzr = new wxStaticBoxSizer( wxHORIZONTAL, poWin, wxT(" Signal Source ") );
-    poWin->SetSizer( poSzr );
+    poSzrSB = new wxStaticBoxSizer( wxHORIZONTAL, poWin, wxT(" Signal Source ") );
+    poWin->SetSizer( poSzrSB );
+
+    // Set the font for the static box label
+    poSzrSB->GetStaticBox( )->SetFont( oFont );
 
     // Layout the signal source panel
     oFlags.Align( wxALIGN_LEFT );
-    oFlags.Border( wxALL, 3 );
-    poSzr->Add( &m_oChoSrcName, oFlags );
-    poSzr->Add( &m_oPnlSrcLvl , oFlags );
+    oFlags.Border( wxTOP | wxBOTTOM, 6 );
+    poSzrSB->AddSpacer( 8 );
+    poSzrSB->Add( &m_oChoSrcName, oFlags );
+    poSzrSB->AddSpacer( 3 );
+    if( m_oPnlSrcLvl.GetParent( ) != NULL ) poSzrSB->Add( &m_oPnlSrcLvl, oFlags );
+    if( m_oBtnSetup .GetParent( ) != NULL ) poSzrSB->Add( &m_oBtnSetup , oFlags );
+    poSzrSB->AddSpacer( 6 );
   }
 
   //---------------------------------------------------------------------------
+  // Create the parameter (probe) panel
+
   // Create and set the sizer for the parameter (probe) panel
   poWin = m_oCbxVoltage.GetParent( );
-  poSzr = new wxStaticBoxSizer( wxVERTICAL, poWin, wxT(" Parameters ") );
-  poWin->SetSizer( poSzr );
+  poSzrSB = new wxStaticBoxSizer( wxVERTICAL, poWin, wxT(" Parameters ") );
+  poWin->SetSizer( poSzrSB );
+
+  // Set the font for the static box label
+  poSzrSB->GetStaticBox( )->SetFont( oFont );
 
   // Layout the parameter (probe) panel
   oFlags.Align( wxALIGN_LEFT );
-  oFlags.Border( wxALL & ~wxBOTTOM, 3 );
-  poSzr->Add( &m_oCbxVoltage, oFlags );
-  poSzr->Add( &m_oCbxCurrent, oFlags );
-  poSzr->Add( &m_oCbxPower  , oFlags );
-  poSzr->Add( &m_oCbxResist , oFlags );
-  poSzr->AddSpacer( 3 );
+  oFlags.Border( wxALL & ~wxBOTTOM, 6 );
+  poSzrSB->Add( &m_oCbxVoltage, oFlags );
+  poSzrSB->Add( &m_oCbxCurrent, oFlags );
+  poSzrSB->Add( &m_oCbxPower  , oFlags );
+  oFlags.Border( wxALL            , 6 );
+  poSzrSB->Add( &m_oCbxResist , oFlags );
 
   //---------------------------------------------------------------------------
   // If required create the complex parts panel
+
   poWin = m_oCbxMag.GetParent( );
   if( poWin != NULL )
   {
     // Create and set the sizer for the complex part panel
-    poSzr = new wxStaticBoxSizer( wxVERTICAL, poWin, wxT(" Complex Parts ") );
-    poWin->SetSizer( poSzr );
+    poSzrSB = new wxStaticBoxSizer( wxVERTICAL, poWin, wxT(" Complex Parts ") );
+    poWin->SetSizer( poSzrSB );
+
+    // Set the font for the static box label
+    poSzrSB->GetStaticBox( )->SetFont( oFont );
 
     // Layout the complex part panel
     oFlags.Align( wxALIGN_LEFT );
-    oFlags.Border( wxALL & ~wxBOTTOM, 3 );
-    poSzr->Add( &m_oCbxMag  , oFlags );
-    poSzr->Add( &m_oCbxPhase, oFlags );
-    poSzr->Add( &m_oCbxReal , oFlags );
-    poSzr->Add( &m_oCbxImag , oFlags );
-    poSzr->Add( &m_oCbxMagDb, oFlags );
-    poSzr->AddSpacer( 3 );
+    oFlags.Border( wxALL & ~wxBOTTOM, 6 );
+    poSzrSB->Add( &m_oCbxMag  , oFlags );
+    poSzrSB->Add( &m_oCbxPhase, oFlags );
+    poSzrSB->Add( &m_oCbxReal , oFlags );
+    poSzrSB->Add( &m_oCbxImag , oFlags );
+    oFlags.Border( wxALL            , 6 );
+    poSzrSB->Add( &m_oCbxMagDb, oFlags );
   }
 
   //---------------------------------------------------------------------------
   // If required create the analysis temperature panel
+
   poWin = m_oPnlTemp.GetParent( );
   if( poWin != NULL )
   {
     // Create and set the sizer for the analysis temperature panel
-    poSzr = new wxStaticBoxSizer( wxVERTICAL, poWin, wxT(" Temperature ") );
-    poWin->SetSizer( poSzr );
+    poSzrSB = new wxStaticBoxSizer( wxVERTICAL, poWin, wxT(" Temperature ") );
+    poWin->SetSizer( poSzrSB );
+
+    // Set the font for the static box label
+    poSzrSB->GetStaticBox( )->SetFont( oFont );
 
     // Layout the complex part panel
     oFlags.Align( wxALIGN_LEFT );
-    oFlags.Border( wxALL, 3 );
-    poSzr->Add( &m_oPnlTemp, oFlags );
+    oFlags.Border( wxALL, 6 );
+    poSzrSB->Add( &m_oPnlTemp, oFlags );
   }
 
   //---------------------------------------------------------------------------
-  // Create and set the underlying panel's sizer
-  poSzrGB = new wxGridBagSizer( 1, 1 );
+  // Create the sizer for the whole analysis panel
+
+  // Create and set the analysis panel sizer
+  poSzrGB = new wxGridBagSizer( );
   SetSizer( poSzrGB );
 
+  // Set horizontal & vertical gaps between cells and the border on the cell out edges
+  poSzrGB->SetHGap( 8 );
+  poSzrGB->SetVGap( 8 );
+  iBorder = 9;
+
   // Add the sweep panel
   poWin = m_oPnlStart.GetParent( );
   oGBPosn.SetCol( 0 );     oGBPosn.SetRow( 0 );
   oGBSpan.SetColspan( 3 ); oGBSpan.SetRowspan( 4 );
-  iFlags  = wxALL | wxALIGN_CENTER;
-  iBorder = 5;
+  iFlags  = wxTOP | wxLEFT;
   poSzrGB->Add( poWin, oGBPosn, oGBSpan, iFlags, iBorder );
 
+  // Add the signal source panel
   poWin = m_oChoSrcName.GetParent( );
   if( poWin != NULL )
   {
-    // Add the signal source panel
     oGBPosn.SetCol( 0 );     oGBPosn.SetRow( 4 );
     oGBSpan.SetColspan( 3 ); oGBSpan.SetRowspan( 1 );
-    iFlags = wxALL | wxALIGN_LEFT;
+    iFlags = wxLEFT;
     poSzrGB->Add( poWin, oGBPosn, oGBSpan, iFlags, iBorder );
   }
 
@@ -381,33 +404,38 @@ void  PnlAnaBase::DoLayout( void )
   poWin = m_oCbxVoltage.GetParent( );
   oGBPosn.SetCol( 3 );     oGBPosn.SetRow( 0 );
   oGBSpan.SetColspan( 1 ); oGBSpan.SetRowspan( 3 );
+  iFlags = wxTOP;
   poSzrGB->Add( poWin, oGBPosn, oGBSpan, iFlags, iBorder );
 
   // Add the options button
   oGBPosn.SetCol( 3 );     oGBPosn.SetRow( 3 );
   oGBSpan.SetColspan( 1 ); oGBSpan.SetRowspan( 1 );
-  iFlags = wxALL | wxALIGN_CENTER;
+  iFlags = 0;
   poSzrGB->Add( &m_oBtnOPTIONS, oGBPosn, oGBSpan, iFlags, iBorder );
 
+  // Add the complex parts panel
   poWin = m_oCbxMag.GetParent( );
   if( poWin != NULL )
   {
-    // Add the complex parts panel
     oGBPosn.SetCol( 4 );     oGBPosn.SetRow( 0 );
     oGBSpan.SetColspan( 1 ); oGBSpan.SetRowspan( 4 );
+    iFlags = wxTOP | wxRIGHT;
     poSzrGB->Add( poWin, oGBPosn, oGBSpan, iFlags, iBorder );
   }
 
+  // Add the temperature panel
   poWin = m_oPnlTemp.GetParent( );
   if( poWin != NULL )
   {
-    // Add the temperature panel
     oGBPosn.SetCol( 3 );     oGBPosn.SetRow( 4 );
     oGBSpan.SetColspan( 2 ); oGBSpan.SetRowspan( 1 );
+    iFlags = 0;
     poSzrGB->Add( poWin, oGBPosn, oGBSpan, iFlags, iBorder );
   }
 }
 
+#endif // LAYOUT_MNGR
+
 //**************************************************************************************************
 // Set the state of the step scale radio box.
 //
@@ -420,7 +448,7 @@ void  PnlAnaBase::DoLayout( void )
 
 bool  PnlAnaBase::bSetScale( eTypeScale eScale )
 {
-  if( eScale<eSCALE_FST || eScale>eSCALE_LST )      return( false );
+  if( eScale == eSCALE_NONE )                       return( false );
 #if wxCHECK_VERSION( 2,8,0 )
   if( m_oRbxSweep.GetCount( ) < (uint) eScale + 1 ) return( false );
 #else
@@ -446,7 +474,7 @@ bool  PnlAnaBase::bSetScale( eTypeScale eScale )
 
 bool  PnlAnaBase::bSetInitC( eTypeInitC eInitC )
 {
-  if( eInitC<eINITC_FST || eInitC>eINITC_LST )      return( false );
+  if( eInitC == eINITC_NONE )                       return( false );
 #if wxCHECK_VERSION( 2,8,0 )
   if( m_oRbxSweep.GetCount( ) < (uint) eInitC + 1 ) return( false );
 #else
@@ -548,7 +576,7 @@ bool  PnlAnaBase::bSetSrcCpnt( Component & roCpnt )
 
 bool  PnlAnaBase::bSetAnalysType( eTypeCmd eAnaType )
 {
-  if( eAnaType<eCMD_ANA_FST || eAnaType>eCMD_ANA_LST ) return( false );
+  if( eAnaType == eCMD_NONE ) return( false );
 
   m_eAnaType = eAnaType;
 
@@ -556,19 +584,48 @@ bool  PnlAnaBase::bSetAnalysType( eTypeCmd eAnaType )
 }
 
 //**************************************************************************************************
-//                                         Event Handlers                                          *
-//**************************************************************************************************
-// Source component choice box event handler.
+// Set the static box label for the sweep parameters.
 //
 // Argument List :
-//   roEvtCmd - An object holding information about the event
+//   rosLabel - The new label string
+//
+// Return Values :
+//   true  - Success
+//   false - Failure
 
-void  PnlAnaBase::OnSrcName( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+#ifdef LAYOUT_MNGR
+
+bool  PnlAnaBase::bSetSwpParsLbl( const wxString & rosLabel )
 {
-  // Set the sweep source component
-  if( m_oChoSrcName.GetSelection( ) > 0 )
-       m_oCpntSwpSrc.bSetName( m_oChoSrcName.GetStringSelection( ) );
-  else m_oCpntSwpSrc.bClear( );
+  wxWindow    * poWin;
+  wxSizer     * poSzr;
+  wxStaticBox * poSBx;
+  wxString      os1;
+
+  poWin = m_oPnlStart.GetParent( );
+  if( poWin != NULL )
+  {
+    poSzr = poWin->GetSizer( );
+    if( poSzr != NULL )
+    {
+      poSBx = static_cast< wxStaticBoxSizer * >( poSzr )->GetStaticBox( );
+      if( poSBx != NULL )
+      {
+#if wxCHECK_VERSION( 3,0,0 )
+        os1 = wxString( wxT(" <i>") ) + rosLabel + wxT("</i> ");
+        poSBx->SetLabelMarkup( os1 );
+#else
+        os1 = rosLabel;
+        poSBx->SetLabel( os1 );
+#endif
+        return( true );
+      }
+    }
+  }
+
+  return( false );
 }
 
+#endif // LAYOUT_MNGR
+
 //**************************************************************************************************
