@@ -2,8 +2,8 @@
 //                                           PrcBase.cpp                                           *
 //                                          -------------                                          *
 // Started     : 2004-01-29                                                                        *
-// Last Update : 2015-01-06                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-10-25                                                                        *
+// Copyright   : (C) 2004-2017 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -21,10 +21,15 @@
 
 PrcBase::PrcBase( int iFlags ) : wxProcess( iFlags )
 {
+  m_oNameLog  = DEF_LOG_FILE;  // Set the default log file path and name
+  m_osErrMsg  = wxT("");       // Clear the error message
+  m_iFlags    = 0;             // Clear the execute flags
+#if wxCHECK_VERSION( 3,0,0 )
+  m_oEnv.cwd = wxGetCwd( );    // Initialize the process working directory
+  wxGetEnvMap( &m_oEnv.env );  // Initialize the process environment variables
+#endif
   m_iPid      = -1;            // Clear the process ID number
   m_iExitCode = 0;             // Clear the process exit code
-  m_ofnLog    = DEF_LOG_FILE;  // Set the default log file path and name
-  m_osErrMsg  = wxT("");       // Clear the error message
 }
 
 //**************************************************************************************************
@@ -39,6 +44,10 @@ PrcBase::~PrcBase( )
 //**************************************************************************************************
 // Find a binary using the user's PATH environment variable given the binary name.
 //
+// Note : This function will fail for (bash) shell builtin commands like "cd" since these commands
+//        do not have a associated binary file. Builtin commands can be listed by entering "help" or
+//        for a simple list of command names "compgen -b".
+//
 // Argument List :
 //   ofnBin - The binary name without the path
 //
@@ -46,7 +55,7 @@ PrcBase::~PrcBase( )
 //   true  - Success (path prepended to oFnBinary)
 //   false - Failure
 
-bool  PrcBase::bFindBinary( wxFileName & rofnBinary )
+bool  PrcBase::bFindBinFile( wxFileName & roFileBin )
 {
   wxPathList  opl1;
   wxFileName  ofn1;
@@ -55,16 +64,16 @@ bool  PrcBase::bFindBinary( wxFileName & rofnBinary )
   m_osErrMsg = wxT("");
 
   // Initial checks
-  if( ! rofnBinary.IsOk( ) ) return( false );
+  if( ! roFileBin.IsOk( ) ) return( false );
 
   // Search environment variable PATH for the first occurrence of the binary
   opl1.AddEnvList( wxT("PATH") );
-  ofn1 = opl1.FindAbsoluteValidPath( rofnBinary.GetFullName( ) );
+  ofn1 = opl1.FindAbsoluteValidPath( roFileBin.GetFullName( ) );
 
   // Check whether the binary was successfully found
   if( !ofn1.IsOk( ) || !ofn1.FileExists( ) )
   {
-    os1 << wxT("Can't find the binary : ") << m_ofnBinary.GetFullName( );
+    os1 << wxT("Can't find the binary : ") << m_oNameBin.GetFullName( );
     wxGetEnv( wxT("PATH"), &os2 );
     os2.Prepend( wxT("$PATH = \n") );
 
@@ -82,7 +91,7 @@ bool  PrcBase::bFindBinary( wxFileName & rofnBinary )
     return( false );
   }
 
-  m_ofnBinary = ofn1;
+  m_oNameBin = ofn1;
 
   return( true );
 }
@@ -103,10 +112,10 @@ bool  PrcBase::bLogOutput( void )
   wxChar           oc1;
 
   // Check that the log file name is valid
-  if( ! m_ofnLog.IsOk( ) )          return( false );
+  if( ! m_oNameLog.IsOk( ) )        return( false );
 
   // Open the file
-  wxTextFile  oFileLog( m_ofnLog.GetFullPath( ) );
+  wxTextFile  oFileLog( m_oNameLog.GetFullPath( ) );
   if( oFileLog.Exists( ) )
        { if( ! oFileLog.Open( )   ) return( false ); }
   else { if( ! oFileLog.Create( ) ) return( false ); }
@@ -138,7 +147,7 @@ bool  PrcBase::bLogOutput( void )
       if( oc1 == wxT('\n') ) { oFileLog.AddLine( os2 ); os2 = wxT(""); }
     }
 
-    wxYield( ); // Yield CPU to other processes
+    wxTheApp->Yield( true );  // Yield CPU to other processes
   }
 
   // Delete the stream objects
@@ -150,12 +159,56 @@ bool  PrcBase::bLogOutput( void )
   if( ! os1.IsEmpty( ) ) oFileLog.AddLine( os1 );
   if( ! os2.IsEmpty( ) ) oFileLog.AddLine( os2 );
 
-  oFileLog.Write( ); // Save the changes to disk
-  oFileLog.Close( ); // Close the log file
+  oFileLog.Write( );  // Save the changes to disk
+  oFileLog.Close( );  // Close the log file
 
   return( true );
 }
 
+//**************************************************************************************************
+// Get the console output after a process has been initiated and dump it to stdout and stderr.
+
+void  PrcBase::PrintOutput( void )
+{
+  wxOutputStream * poStdOut;
+  wxInputStream  * poStdIn;
+  wxInputStream  * poStdErr;
+  wxChar           oc1;
+
+  // Get pointers to the input streams
+  poStdOut = GetOutputStream( );
+  poStdIn  = GetInputStream( );
+  poStdErr = GetErrorStream( );
+
+  // Read the console input
+  while( bIsExec( ) || poStdIn->IsOk( ) || poStdErr->IsOk( ) )
+  {
+    // Get data from stdout
+    while( poStdIn->CanRead( ) )
+    {
+      oc1 = poStdIn->GetC( );
+      if( oc1==wxT('\n') || oc1==wxT('\r') || oc1==wxT('\t') || (oc1>31 && oc1!=127) )
+        std::cout << char( oc1 );
+    }
+
+    // Get data from stderr
+    while( poStdErr->CanRead( ) )
+    {
+      oc1 = poStdErr->GetC( );
+      if( oc1==wxT('\n') || oc1==wxT('\r') || oc1==wxT('\t') || (oc1>31 && oc1!=127) )
+        std::cerr << char( oc1 );
+    }
+
+    wxTheApp->Yield( true );  // Yield CPU to other processes
+  }
+
+  // Delete the stream objects
+  delete poStdOut;
+  delete poStdIn;
+  delete poStdErr;
+  SetPipeStreams( NULL, NULL, NULL );
+}
+
 //**************************************************************************************************
 // Does the binary exist?
 //
@@ -165,7 +218,7 @@ bool  PrcBase::bLogOutput( void )
 
 bool  PrcBase::bBinExists( void )
 {
-  if( !m_ofnBinary.IsOk( ) || !m_ofnBinary.FileExists( ) )
+  if( !m_oNameBin.IsOk( ) || !m_oNameBin.FileExists( ) )
     return( false );
 
   return( true );
@@ -175,19 +228,21 @@ bool  PrcBase::bBinExists( void )
 // Set the file name of the binary to be executed.
 //
 // Argument List :
-//   rosFName - A string containing the binary file name
+//   rosFileName - A string containing the binary file name
 //
 // Return Values :
 //   true  - Success
 //   false - Failure
 
-bool  PrcBase::bSetBinary( const wxString & rosFName )
+bool  PrcBase::bSetBinFile( const wxString & rosFileName )
 {
-  if( rosFName.IsEmpty( ) )          return( false );
+  // The binary file name shouldn't contain space characters or be empty
+  if( rosFileName.IsEmpty( ) )                      return( false );
+  if( rosFileName.Find( wxT(' ') ) != wxNOT_FOUND ) return( false );
 
-  m_ofnBinary = rosFName;
+  m_oNameBin = rosFileName;
 
-  if( ! bFindBinary( m_ofnBinary ) ) return( false );
+  if( ! bFindBinFile( m_oNameBin ) ) return( false );
 
   return( true );
 }
@@ -212,34 +267,117 @@ bool  PrcBase::bSetArgLst( const wxString & rosArgLst )
 }
 
 //**************************************************************************************************
-// Set the process log file name.
-// (If set all process output can be captured to this file.)
+// Set the Current Working Directory (CWD).
 //
 // Argument List :
-//   rosFName - A string containing the full path and file name
+//   rosCwd - The proposed new CWD
 //
 // Return Values :
 //   true  - Success
 //   false - Failure
 
-bool  PrcBase::bSetLogFile( const wxString & rosFName )
+bool  PrcBase::bSetCwd( const wxString & rosCwd )
+{
+  wxFileName  ofn1;
+  wxString    os1;
+  bool        bRtn=false;
+
+  if( rosCwd.IsEmpty( ) ) return( false );
+
+  os1 = rosCwd;
+#ifndef __WXMSW__
+  if( os1.GetChar( os1.Len()-1 ) != wxT('/') ) os1 += wxT('/');
+#else
+  if( os1.GetChar( os1.Len()-1 ) != wxT('\\') ) os1 += wxT('\\');
+#endif // __WXMSW__
+  ofn1 = os1;
+  if( ofn1.IsDir( ) )
+  {
+    if( ofn1.DirExists( ) )
+    {
+      ofn1.MakeAbsolute( );
+      bRtn = wxSetWorkingDirectory( ofn1.GetPath( ) );
+#if wxCHECK_VERSION( 3,0,0 )
+      m_oEnv.cwd = wxGetCwd( );
+#endif
+    }
+  }
+
+  return( bRtn );
+}
+
+//**************************************************************************************************
+// Set the process log file name.
+// (If set all process output can be captured to this file.)
+//
+// Argument List :
+//   rosFileName - A string containing the full path and file name
+//
+// Return Values :
+//   true  - Success
+//   false - Failure
+
+bool  PrcBase::bSetLogFile( const wxString & rosFileName )
 {
   wxFileName  ofn1;
 
-  ofn1 = rosFName;
+  ofn1 = rosFileName;
 
   if( ! ofn1.IsOk( ) ) return( false );
 
   if( ofn1.GetPath( ).IsEmpty( ) ) ofn1.SetPath( wxT(".") );
 
-  m_ofnLog = ofn1;
+  m_oNameLog = ofn1;
 
   return( true );
 }
 
 //**************************************************************************************************
-// Execute a process asynchronously.
-// (Ie. Return as soon as the process has been launched).
+// Escape space characters.
+//
+// In UNIX like operating systems if path names contain space characters they must each be preceeded
+// by a backslash character to be properly processed by the command line interpreter.
+//
+// Note : This function is required to overcome a short coming in wxWidgets. The class wxFileName
+//        probably should be able to do this automatically.
+//
+// Argument List :
+//   rosPath - The path string to be check and if necessary modified
+//
+// Return Values :
+//   The path with all space characters escaped
+
+const wxString & PrcBase::rosEscSpaceChrs( const wxString & rosPath )
+{
+  static  wxString  osPath;
+#ifndef __WXMSW__
+          size_t    sz1;
+#endif // __WXMSW__
+
+  osPath = rosPath;
+
+#ifndef __WXMSW__
+  if( osPath.Find( ' ' ) != wxNOT_FOUND )
+  {
+    osPath.Trim( FALSE );                 // Trim any space chars from the beginning of the string
+    sz1 = osPath.find( ' ' );             // Search for the first space character
+    while( sz1 != (size_t) wxNOT_FOUND )
+    {
+      if( osPath[ sz1-1 ] != '\\' )       // Has the space character been escaped?
+      {
+        osPath.insert( sz1, wxT("\\") );  // Escape the space character
+        sz1 += 2;
+      }
+      sz1 = osPath.find( ' ', sz1 );      // Find the next space character
+    }
+  }
+#endif // __WXMSW__
+
+  return( osPath );
+}
+
+//**************************************************************************************************
+// Execute a process asynchronously ie. return as soon as the process has been launched.
 //
 // Return Values :
 //   true  - Success
@@ -250,23 +388,22 @@ bool  PrcBase::bExecAsync( void )
   wxString  os1, os2;
 
   // Only execute simulation if it isn't already running
-  if( bIsExec( ) )      return( false );
+  if( bIsExec( ) ) return( false );
 
   // Clear error attributes
   m_osErrMsg = wxT("");
 
-  // Check that the binary exists
-  if( ! bBinExists( ) )
-    if( ! bFindBinary( m_ofnBinary ) )
-      return( false );
-
   // Construct the command line to be executed
-  os1 = roGetBinary( ).GetFullPath( );
+  os1 = roGetBinFile( ).GetFullPath( );
   if( ! rosGetArgLst( ).IsEmpty( ) )
     os1 << wxT(' ') << rosGetArgLst( );
 
   // Attempt to execute the simulation
-  m_iPid = (int) wxExecute( os1, wxEXEC_ASYNC, this );
+#if wxCHECK_VERSION( 3,0,0 )
+  m_iPid = (int) wxExecute( os1, wxEXEC_ASYNC | m_iFlags, this, &m_oEnv );
+#else
+  m_iPid = (int) wxExecute( os1, wxEXEC_ASYNC | m_iFlags, this );
+#endif
   if( m_iPid <= 0 )
   {
     os2.Empty( );
@@ -279,8 +416,7 @@ bool  PrcBase::bExecAsync( void )
 }
 
 //**************************************************************************************************
-// Execute a process synchronously.
-// (Ie. wait for the process to terminate before returning).
+// Execute a process synchronously ie. wait for the process to terminate before returning.
 //
 // Return Values :
 //   true  - Success
@@ -339,8 +475,8 @@ bool  PrcBase::bExecSync( void )
 
 bool  PrcBase::bKill( void )
 {
-  if( ! bIsExec( ) )       return( true );
-  if( ! Exists( m_iPid ) ) return( true );
+  if( ! bIsExec( ) )                           return( true );
+  if( ! Exists( m_iPid ) )                     return( true );
 
   if( Kill( m_iPid, wxSIGTERM ) != wxKILL_OK ) return( false );
 
@@ -359,20 +495,20 @@ bool  PrcBase::bKill( void )
 
 bool  PrcBase::bDelLogFile( void )
 {
-  if( m_ofnLog.GetFullPath( ).IsEmpty( ) )          return( true );
+  if( m_oNameLog.GetFullPath( ).IsEmpty( ) )          return( true );
 
-  if( ! ::wxFileExists( m_ofnLog.GetFullPath( ) ) ) return( true );
+  if( ! ::wxFileExists( m_oNameLog.GetFullPath( ) ) ) return( true );
 
-  return( ::wxRemoveFile( m_ofnLog.GetFullPath( ) ) );
+  return( ::wxRemoveFile( m_oNameLog.GetFullPath( ) ) );
 }
 
 //**************************************************************************************************
-// Collect the output from the simulator and print to a text control.
+// Collect the input / output from the process and print to a text control.
 //
 // Argument List :
 //   roTxtCtl - The text control to contain the simulator output
 
-void  PrcBase::Print( TextCtrl & roTxtCtl )
+void  PrcBase::PrintIO( TextCtrl & roTxtCtl )
 {
   roTxtCtl.bClear( );    // Clear the text control
 
@@ -393,12 +529,11 @@ void  PrcBase::PrintCmd( TextCtrl & roTxtCtl )
 
   // Print the process command
   os1.Empty( );
-  os1 << wxT("                    ")
-      << wxT("*************** PROCESS COMMAND ***************");
+  os1 << wxT("                    *************** PROCESS COMMAND ***************");
   roTxtCtl.bAppendLine( os1 );
   os1.Empty( );
   roTxtCtl.bAppendLine( os1 );
-  os1 << roGetBinary( ).GetFullPath( );
+  os1 << roGetBinFile( ).GetFullPath( );
   if( ! rosGetArgLst( ).IsEmpty( ) ) os1 << wxT(' ') << rosGetArgLst( );
   roTxtCtl.bAppendLine( os1 );
   os1.Empty( );
@@ -416,29 +551,44 @@ void  PrcBase::PrintRsp( TextCtrl & roTxtCtl )
   wxString  os1;
 
   // Print the process command response
-  if( ! m_ofnLog.GetFullPath( ).IsEmpty( ) )
+  if( ! m_oNameLog.GetFullPath( ).IsEmpty( ) )
   {
     os1.Empty( );
-    os1 << wxT("                    ")
-        << wxT("*************** PROCESS RESPONSE **************");
+    os1 << wxT("                    *************** PROCESS RESPONSE **************");
     roTxtCtl.bAppendLine( os1 );
     os1.Empty( );
     roTxtCtl.bAppendLine( os1 );
-    if( m_ofnLog.IsOk( ) && m_ofnLog.FileExists( ) )
-      roTxtCtl.bAppendFile( m_ofnLog.GetFullPath( ) );
+    if( m_oNameLog.IsOk( ) && m_oNameLog.FileExists( ) )
+      roTxtCtl.bAppendFile( m_oNameLog.GetFullPath( ) );
     else
     {
       os1 << wxT("Couldn't load the file containing the process ouput : ")
-          << m_ofnLog.GetFullPath( );
+          << m_oNameLog.GetFullPath( );
       roTxtCtl.bAppendLine( os1 );
     }
   }
 }
 
+//**************************************************************************************************
+// Print the object attributes.
+//
+// Argument List :
+//   rosPrefix - A prefix to every line displayed (usually just spaces)
+
+void  PrcBase::Print( const wxString & rosPrefix )
+{
+  std::cout << rosPrefix.mb_str() << "m_oNameBin  : " << m_oNameBin.GetFullPath( ).mb_str() << '\n';
+  std::cout << rosPrefix.mb_str() << "m_oNameLog  : " << m_oNameLog.GetFullPath( ).mb_str() << '\n';
+  std::cout << rosPrefix.mb_str() << "m_osArgLst  : " << m_osArgLst.mb_str( )               << '\n';
+  std::cout << rosPrefix.mb_str() << "m_osErrMsg  : " << m_osErrMsg.mb_str( )               << '\n';
+  std::cout << rosPrefix.mb_str() << "m_iPid      : " << m_iPid                             << '\n';
+  std::cout << rosPrefix.mb_str() << "m_iExitCode : " << m_iExitCode                        << '\n';
+}
+
 //**************************************************************************************************
 // Call-back function called when the process terminates.
-// (WARNING : Be careful of this function definition, if it is incorrect the
-//            application can segment fault.)
+// (WARNING : Be careful of this function definition, if it's incorrect the application can throw a
+//            segmentation fault.)
 //
 // Argument List :
 //   iPid    - The PID of the process which just terminated
