@@ -2,8 +2,8 @@
 //                                          NbkGnuCap.cpp                                          *
 //                                         ---------------                                         *
 // Started     : 2003-09-05                                                                        *
-// Last Update : 2015-04-15                                                                        *
-// Copyright   : (C) 2003 by MSWaters                                                              *
+// Last Update : 2018-10-03                                                                        *
+// Copyright   : (C) 2003-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -85,7 +85,7 @@ bool  NbkGnuCap::bClear( void )
   if( ! m_poPnlGnuCapDC->bClear( ) ) bRtn = false;
   if( ! m_poPnlGnuCapAC->bClear( ) ) bRtn = false;
   if( ! m_poPnlGnuCapTR->bClear( ) ) bRtn = false;
-//  if( ! m_poPnlGnuCapFO->bClear( ) ) bRtn = false;
+//if( ! m_poPnlGnuCapFO->bClear( ) ) bRtn = false;
 
   if( ! m_oDlgCfgOPT    .bClear( ) ) bRtn = false;
 
@@ -109,8 +109,6 @@ bool  NbkGnuCap::bLoad( const SimnBase & roSimn )
 
   if( roSimn.eGetSimEng( ) != eSIMR_GNUCAP )             return( false );
 
-  PnlAnaBase::m_oCpntSwpSrc = roSimn.m_oCpntSwpSrc;
-
   SimnGnuCap & roSimnGcp = (SimnGnuCap &) roSimn;
 
   if( ! bSetPage( roSimnGcp.eGetAnaType( ) ) )           bRtn = false;
@@ -120,7 +118,7 @@ bool  NbkGnuCap::bLoad( const SimnBase & roSimn )
   if( m_poPnlGnuCapDC->bLoad( roSimnGcp ) ) sz1++;
   if( m_poPnlGnuCapAC->bLoad( roSimnGcp ) ) sz1++;
   if( m_poPnlGnuCapTR->bLoad( roSimnGcp ) ) sz1++;
-//  if( m_poPnlGnuCapFO->bLoad( roSimnGcp ) ) sz1++;
+//if( m_poPnlGnuCapFO->bLoad( roSimnGcp ) ) sz1++;
   if( sz1 == 0 )                                         bRtn = false;
 
   if( ! m_oDlgCfgOPT.bSetValues( roSimnGcp.m_oCmdOPT ) ) bRtn = false;
@@ -322,55 +320,88 @@ eTypeCmd  NbkGnuCap::eGetPage( void )
 
 void  NbkGnuCap::OnPageChangd( wxNotebookEvent & roEvtNbk )
 {
-  PnlAnaBase * poPnlAna;
+  PnlAnaBase * poPnlOld=NULL;
+  PnlAnaBase * poPnlNew=NULL;
   wxString     os1;
   int          i1;
 
-  // Transfer the ambient temperature from the previous page to OPTIONS dialog
+  // Get pointers to the old and new (current) analysis panels
   i1 = roEvtNbk.GetOldSelection( );
-  if( i1 != -1 )
+  if( i1 != wxNOT_FOUND ) poPnlOld = static_cast<PnlAnaBase *>( GetPage( (size_t) i1 ) );
+  poPnlNew = static_cast<PnlAnaBase *>( GetCurrentPage( ) );
+
+  // Synchronize the ambient temperature values between the different analysis pages
+  if( g_oConfig.bGetSyncTemps( ) )
   {
-    poPnlAna = (PnlAnaBase *) GetPage( (size_t) i1 );
-    if( poPnlAna->m_oPnlTemp.GetParent( ) != NULL )
+    // Transfer the ambient temperature from the previous page to the OPTIONS dialog
+    if( poPnlOld != NULL )
     {
-      os1 = poPnlAna->m_oPnlTemp.rosGetValue( );
-      m_oDlgCfgOPT.bSetValue( DlgGcpCfgOPT::ID_PNL_TEMP, os1 );
+      if( poPnlOld->m_oPnlTemp.GetParent( ) != NULL )
+      {
+        os1 = poPnlOld->m_oPnlTemp.rosGetValue( );
+        m_oDlgCfgOPT.bSetValue( DlgGnuCapCfgOPT::ID_PNL_TEMP, os1 );
+      }
+    }
+
+    // Transfer the ambient temperature from the OPTIONS dialog to current page
+    if( poPnlNew->m_oPnlTemp.GetParent( ) != NULL )
+    {
+      os1 = m_oDlgCfgOPT.rosGetValue( DlgGnuCapCfgOPT::ID_PNL_TEMP );
+      poPnlNew->m_oPnlTemp.bSetValue( os1 );
     }
   }
 
-  // Transfer the ambient temperature from the OPTIONS dialog to current page
-  poPnlAna = (PnlAnaBase *) GetCurrentPage( );
-  if( poPnlAna->m_oPnlTemp.GetParent( ) != NULL )
+  // Record the signal source value from the old panel
+  if( poPnlOld != NULL )
   {
-    os1 = m_oDlgCfgOPT.rosGetValue( DlgGcpCfgOPT::ID_PNL_TEMP );
-    poPnlAna->m_oPnlTemp.bSetValue( os1 );
+    if( poPnlOld->m_oChoSrcName.GetSelection( ) > 0 )
+    {
+      m_oCpntSigSrc.bSetName( poPnlOld->m_oChoSrcName.GetStringSelection( ) );
+      if( poPnlOld->m_oPnlSrcLvl.GetParent( ) != NULL )
+      {
+        os1 = poPnlOld->m_oPnlSrcLvl.rosGetValue( );
+        m_oCpntSigSrc.bSetValue( os1 );
+      }
+      else if( poPnlOld->eGetAnalysType( ) == eCMD_TR )
+      {
+        os1 = m_poPnlGnuCapTR->m_oDlgCfgGEN.rosGetValue( DlgGnuCapCfgGEN::ID_PNL_AMPLITUDE );
+        m_oCpntSigSrc.bSetValue( os1 );
+      }
+    }
+    else m_oCpntSigSrc.bClear( );
   }
 
-  // Synchronize the sweep sources between the different analysis pages
-  if( m_bSyncSwpSrcs )
+  // Synchronize the signal sources between the different analysis pages
+  if( g_oConfig.bGetSyncSigSrcs( ) )
   {
-    os1 = poPnlAna->m_oCpntSwpSrc.rosGetName( );
+      os1 = m_oCpntSigSrc.rosGetName( );
 
-    if( poPnlAna->m_oChoSrcName.SetStringSelection( os1 ) )
-    { // Set the sweep source value if it's been defined
-      if( poPnlAna->m_oPnlSrcLvl.GetParent( ) != NULL )
+    if( poPnlNew->m_oChoSrcName.SetStringSelection( os1 ) )
+    { // Set the signal source value if it's been defined
+      if( poPnlNew->m_oPnlSrcLvl.GetParent( ) != NULL )
       {
-        poPnlAna->m_oPnlSrcLvl.bSetUnitsType( poPnlAna->m_oCpntSwpSrc.eGetUnitsType( ) );
-        poPnlAna->m_oPnlSrcLvl.bSetValue( poPnlAna->m_oCpntSwpSrc.rosGetValue ( ) );
+        poPnlNew->m_oPnlSrcLvl.bSetUnitsType( m_oCpntSigSrc.eGetUnitsType( ) );
+        poPnlNew->m_oPnlSrcLvl.bSetValue( m_oCpntSigSrc.rosGetValue( ) );
+      }
+      else if( poPnlNew->eGetAnalysType( ) == eCMD_TR )
+      {
+        poPnlNew->m_oPnlSrcLvl.bSetUnitsType( m_oCpntSigSrc.eGetUnitsType( ) );
+        os1 = m_oCpntSigSrc.rosGetValue( );
+        m_poPnlGnuCapTR->m_oDlgCfgGEN.bSetValue( DlgGnuCapCfgGEN::ID_PNL_AMPLITUDE, os1 );
       }
     }
     else
-    { // Couldn't set the sweep source name so clear it
-      poPnlAna->m_oChoSrcName.SetSelection( 0 );
-      if( poPnlAna->m_oPnlSrcLvl.GetParent( ) != NULL )
+    { // Couldn't set the signal source name so clear it
+      poPnlNew->m_oChoSrcName.SetSelection( 0 );
+      if( poPnlNew->m_oPnlSrcLvl.GetParent( ) != NULL )
       {
-        poPnlAna->m_oPnlSrcLvl.bSetUnitsType( eUNITS_NONE );
-        poPnlAna->m_oPnlSrcLvl.bSetValue( 0.0 );
+        poPnlNew->m_oPnlSrcLvl.bSetUnitsType( eUNITS_NONE );
+        poPnlNew->m_oPnlSrcLvl.bSetValue( 0.0 );
       }
     }
 
-    // Update the sweep parameter units
-    if( poPnlAna->eGetAnalysType( ) == eCMD_DC )
+    // Update the signal parameter units
+    if( poPnlNew->eGetAnalysType( ) == eCMD_DC )
       m_poPnlGnuCapDC->OnSrcName( (wxCommandEvent &) roEvtNbk );
   }
 
@@ -384,21 +415,21 @@ void  NbkGnuCap::OnPageChangd( wxNotebookEvent & roEvtNbk )
 // Argument List:
 //   roEvtCmd - An object holding information about the event
 
-void  NbkGnuCap::OnBtnOptions( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  NbkGnuCap::OnBtnOptions( wxCommandEvent & roEvtCmd )
 {
   PnlAnaBase * poPnlAna;
   wxString     os1;
   int          i1;
 
   // Get a pointer to the currently displayed analysis page
-  poPnlAna = (PnlAnaBase *) GetCurrentPage( );
+  poPnlAna = static_cast<PnlAnaBase *>( GetCurrentPage( ) );
   if( poPnlAna == NULL ) return;
 
   // Set the temperature in the OPTIONS dialog
   if( poPnlAna->m_oPnlTemp.GetParent( ) != NULL )
   {
     os1 = poPnlAna->m_oPnlTemp.rosGetValue( );
-    m_oDlgCfgOPT.bSetValue( DlgGcpCfgOPT::ID_PNL_TEMP, os1 );
+    m_oDlgCfgOPT.bSetValue( DlgGnuCapCfgOPT::ID_PNL_TEMP, os1 );
   }
 
   // Display the OPTIONS dialog
@@ -409,7 +440,7 @@ void  NbkGnuCap::OnBtnOptions( wxCommandEvent & WXUNUSED( roEvtCmd ) )
   // Set the temperature in the analysis panel
   if( poPnlAna->m_oPnlTemp.GetParent( ) != NULL )
   {
-    os1 = m_oDlgCfgOPT.rosGetValue( DlgGcpCfgOPT::ID_PNL_TEMP );
+    os1 = m_oDlgCfgOPT.rosGetValue( DlgGnuCapCfgOPT::ID_PNL_TEMP );
     poPnlAna->m_oPnlTemp.bSetValue( os1 );
   }
 }
