@@ -4,8 +4,8 @@
 // Description : Provides a container class for the analysis configuration panels for the          *
 //               different analyses provided by GNU-Cap electronic circuit simulator.              *
 // Started     : 2003-09-05                                                                        *
-// Last Update : 2015-04-15                                                                        *
-// Copyright   : (C) 2003 by MSWaters                                                              *
+// Last Update : 2018-10-03                                                                        *
+// Copyright   : (C) 2003-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -22,8 +22,9 @@
 // Application Includes
 
 #include "TypeDefs.hpp"
+#include "Config.hpp"
 #include "base/NbkSimEngBase.hpp"
-#include "gnucap/dialogs/DlgGcpCfgOPT.hpp"
+#include "gnucap/dialogs/DlgGnuCapCfgOPT.hpp"
 #include "gnucap/panels/PnlGnuCapOP.hpp"
 #include "gnucap/panels/PnlGnuCapDC.hpp"
 #include "gnucap/panels/PnlGnuCapAC.hpp"
@@ -44,30 +45,34 @@ class NbkGnuCap : public NbkSimEngBase
 //    PnlGnuCapFO * m_poPnlGnuCapFO;
 
     // OPTIONS line setup dialog
-    DlgGcpCfgOPT  m_oDlgCfgOPT;
+    DlgGnuCapCfgOPT  m_oDlgCfgOPT;
 
   public:
 
           NbkGnuCap( wxWindow * poParent, wxWindowID oWinID );
          ~NbkGnuCap( );
 
-    bool  bClear( void );
+    bool  bClear( void ) override;
 
-    bool  bLoad( const SimnBase & roSimn );
-    bool  bSave(       SimnBase & roSimn );
+    bool  bLoad( const SimnBase & roSimn ) override;
+    bool  bSave(       SimnBase & roSimn ) override;
 
-    bool  bSetPage(       eTypeCmd     eAnalysis );
-    bool  bSetPage( const wxString & rosAnalysis );
+    bool  bSetPage(       eTypeCmd     eAnalysis ) override;
+    bool  bSetPage( const wxString & rosAnalysis ) override;
 
-    const  wxString & rosGetPage( void );
-           eTypeCmd     eGetPage( void );
+    const  wxString & rosGetPage( void ) override;
+           eTypeCmd     eGetPage( void ) override;
 
     // Event handlers
     void  OnPageChangd( wxNotebookEvent & roEvtNbk );
     void  OnBtnOptions( wxCommandEvent  & roEvtCmd );
 
     // Leave this as the last line as private access is envoked by macro
+#if wxCHECK_VERSION( 3,0,0 )
     wxDECLARE_EVENT_TABLE( );
+#else
+    wxDECLARE_EVENT_TABLE( )
+#endif
 };
 
 //**************************************************************************************************
