@@ -2,8 +2,8 @@
 //                                         CmdGnuCapAC.cpp                                         *
 //                                        -----------------                                        *
 // Started     : 2008-02-21                                                                        *
-// Last Update : 2014-12-23                                                                        *
-// Copyright   : (C) 2008 by MSWaters                                                              *
+// Last Update : 2018-09-25                                                                        *
+// Copyright   : (C) 2008-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -19,7 +19,7 @@
 //**************************************************************************************************
 // Constructor.
 
-CmdGnuCapAC::CmdGnuCapAC( void )
+CmdGnuCapAC::CmdGnuCapAC( void ) : CmdBase( )
 {
   bSetDefaults( );
 }
