@@ -4,8 +4,8 @@
 // Description : This class contains values associated with the GNU-Cap AC command. It inherits    *
 //               from the class CmdBase.                                                           *
 // Started     : 2008-02-21                                                                        *
-// Last Update : 2015-03-07                                                                        *
-// Copyright   : (C) 2008 by MSWaters                                                              *
+// Last Update : 2018-09-23                                                                        *
+// Copyright   : (C) 2008-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -38,7 +38,7 @@ class CmdGnuCapAC : public CmdBase
 {
   private :
 
-    virtual  bool  bValidate( void );
+    bool  bValidate( void ) override;
 
   public :
 
@@ -48,17 +48,17 @@ class CmdGnuCapAC : public CmdBase
     eTypeScale  m_eScale;   // The sweep scale type
     wxString    m_osTempC;  // The analysis temperature
 
-                   CmdGnuCapAC( void );
-    virtual       ~CmdGnuCapAC( );
+          CmdGnuCapAC( void );
+         ~CmdGnuCapAC( );
 
-    virtual  bool  bSetDefaults( void );
+    bool  bSetDefaults( void ) override;
 
-    virtual  bool  bParse ( void );
-    virtual  bool  bFormat( void );
+    bool  bParse ( void ) override;
+    bool  bFormat( void ) override;
 
     CmdGnuCapAC & operator = ( const CmdNgSpiceAC & roCmdAC );
 
-             void  Print( const wxString & rosPrefix=wxT("  ") );
+    void  Print( const wxString & rosPrefix=wxT("  ") ) override;
 };
 
 //**************************************************************************************************
