@@ -1,44 +1,42 @@
-//*****************************************************************************
-//                               CmdGnuCapFO.cpp                              *
-//                              -----------------                             *
-// Started     : 11/03/2008                                                   *
-// Last Update : 16/04/2010                                                   *
-// Copyright   : (C) 2008 by M.S.Waters                                       *
-// Email       : M.Waters@bom.gov.au                                          *
-//*****************************************************************************
+//**************************************************************************************************
+//                                         CmdGnuCapFO.cpp                                         *
+//                                        -----------------                                        *
+// Started     : 2008-03-11                                                                        *
+// Last Update : 2018-09-25                                                                        *
+// Copyright   : (C) 2008-2018 MSWaters                                                            *
+//**************************************************************************************************
 
-//*****************************************************************************
-//                                                                            *
-//    This program is free software; you can redistribute it and/or modify    *
-//    it under the terms of the GNU General Public License as published by    *
-//    the Free Software Foundation; either version 2 of the License, or       *
-//    (at your option) any later version.                                     *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                                                                                 *
+//      This program is free software; you can redistribute it and/or modify it under the          *
+//      terms of the GNU General Public License as published by the Free Software Foundation;      *
+//      either version 3 of the License, or (at your option) any later version.                    *
+//                                                                                                 *
+//**************************************************************************************************
 
-#include "gnucap/commands/CmdGnuCapFO.hpp"
+#include "CmdGnuCapFO.hpp"
 
-//*****************************************************************************
+//**************************************************************************************************
 // Constructor.
 
-CmdGnuCapFO::CmdGnuCapFO( void )
+CmdGnuCapFO::CmdGnuCapFO( void ) : CmdBase( )
 {
-  bClear( );
+  bSetDefaults( );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Destructor.
 
 CmdGnuCapFO::~CmdGnuCapFO( )
 {
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Check that the object attributes are valid.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapFO::bValidate( void )
 {
@@ -47,15 +45,15 @@ bool  CmdGnuCapFO::bValidate( void )
   CmdBase::bValidate( );
 
   // Check the sweep start and stop values
-  if( ! ConvertType::bStrToDFlt( m_osStart, &df1 ) )
+  if( ! CnvtType::bStrToFlt( m_osStart, &df1 ) )
     SetErrMsg( wxT("Invalid sweep start value.") );
-  if( ! ConvertType::bStrToDFlt( m_osStop,  &df2 ) )
+  if( ! CnvtType::bStrToFlt( m_osStop,  &df2 ) )
     SetErrMsg( wxT("Invalid sweep stop value.") );
   if( df2 < df1 )
     SetErrMsg( wxT("Start value greater than stop value.") );
 
   // Check the sweep step value and initial conditions
-  if( ! ConvertType::bStrToDFlt( m_osStep, &df3 ) )
+  if( ! CnvtType::bStrToFlt( m_osStep, &df3 ) )
     SetErrMsg( wxT("Invalid sweep step value.") );
   if( df3 <= 0.0 )
     SetErrMsg( wxT("Step value less than or equal to zero.") );
@@ -68,22 +66,22 @@ bool  CmdGnuCapFO::bValidate( void )
   }
 
   // Set the analysis temperature
-  if( ! ConvertType::bStrToDFlt( m_osTempC, &df3 ) )
+  if( ! CnvtType::bStrToFlt( m_osTempC, &df3 ) )
     SetErrMsg( wxT("Invalid analysis temperature value.") );
 
   return( bIsValid( ) );
 }
 
-//*****************************************************************************
-// Clear the object attributes.
+//**************************************************************************************************
+// Set the object attributes to they're default values.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
-bool  CmdGnuCapFO::bClear( void )
+bool  CmdGnuCapFO::bSetDefaults( void )
 {
-  CmdBase::bClear( );
+  CmdBase::bSetDefaults( );
 
   m_eSimEng  = eSIMR_GNUCAP;
   m_eCmdType = eCMD_FO;
@@ -96,18 +94,18 @@ bool  CmdGnuCapFO::bClear( void )
 
   m_osTempC  = wxT("27.0");
 
-  return( TRUE );
+  return( true );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Parse the command string.
 //
 // Eg.s : .FO 1.00K 100.00K 10.00K TE 27.00 COLD BASIC
 //        .FO 1.00K 100.00K 10.00K TE 27.00 BASIC
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapFO::bParse( void )
 {
@@ -118,7 +116,7 @@ bool  CmdGnuCapFO::bParse( void )
 
   // Clear the object attributes
   os1 = (wxString &) *this;
-  bClear( );
+  bSetDefaults( );
   assign( os1 );
 
   // Tokenize the command string
@@ -132,17 +130,17 @@ bool  CmdGnuCapFO::bParse( void )
 
   // Extract the start time
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStart = os1;
+  if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStart = os1;
   else                                                 return( bValidate( ) );
 
   // Extract the stop time
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStop  = os1;
+  if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStop  = os1;
   else                                                 return( bValidate( ) );
 
   // Extract the step increment
   os1 = ostk1.GetNextToken( );
-  if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osStep  = os1;
+  if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStep  = os1;
   else                                                 return( bValidate( ) );
 
   // Extract the analysis temperature
@@ -150,7 +148,7 @@ bool  CmdGnuCapFO::bParse( void )
   if( os1.Upper( ) == wxT("TE") )
   {
     os1 = ostk1.GetNextToken( );
-    if( ConvertType::bStrToDFlt( os1, &df1 ) ) m_osTempC = os1;
+    if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osTempC = os1;
     else                                               return( bValidate( ) );
   }
 
@@ -171,12 +169,12 @@ bool  CmdGnuCapFO::bParse( void )
   return( bValidate( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Format the command string.
 //
 // Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
+//   true  - Success
+//   false - Failure
 
 bool  CmdGnuCapFO::bFormat( void )
 {
@@ -210,7 +208,7 @@ bool  CmdGnuCapFO::bFormat( void )
   return( bValidate( ) );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 // Print the object attributes.
 //
 // Argument List :
@@ -220,46 +218,36 @@ void  CmdGnuCapFO::Print( const wxString & rosPrefix )
 {
   CmdBase::Print( rosPrefix + wxT("CmdBase::") );
 
-  cout << rosPrefix.mb_str( ) << "m_osStart : "
-       << m_osStart.mb_str( ) << '\n';
-  cout << rosPrefix.mb_str( ) << "m_osStop  : "
-       << m_osStop .mb_str( ) << '\n';
-  cout << rosPrefix.mb_str( ) << "m_osStep  : "
-       << m_osStep .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStart : " << m_osStart.mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStop  : " << m_osStop .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osStep  : " << m_osStep .mb_str( ) << '\n';
 
-  cout << rosPrefix.mb_str( ) << "m_eInitC  : ";
+  std::cout << rosPrefix.mb_str( ) << "m_eInitC  : ";
   switch( m_eInitC )
   {
-    case eINITC_WARM : cout << "eINITC_COLD\n"; break;
-    case eINITC_UICS : cout << "eINITC_UICS\n"; break;
-    case eINITC_COLD : cout << "eINITC_COLD\n"; break;
-    case eINITC_NONE : cout << "eINITC_NONE\n"; break;
-    default :          cout << "Invalid\n";     break;
+    case eINITC_WARM : std::cout << "eINITC_COLD\n"; break;
+    case eINITC_UICS : std::cout << "eINITC_UICS\n"; break;
+    case eINITC_COLD : std::cout << "eINITC_COLD\n"; break;
+    case eINITC_NONE : std::cout << "eINITC_NONE\n"; break;
+    default :          std::cout << "Invalid\n";     break;
   }
 
-  cout << rosPrefix.mb_str( ) << "m_osTempC : "
-       << m_osTempC.mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osTempC : " << m_osTempC.mb_str( ) << '\n';
 }
 
-//*****************************************************************************
-//                                                                            *
-//                                 Test Utility                               *
-//                                                                            *
-//*****************************************************************************
+//**************************************************************************************************
+//                                          Test Utility                                           *
+//**************************************************************************************************
 
-#ifdef TEST_CMDGCPFO
-
-// System include files
-
-
-// Application includes
+#ifdef TEST_CMDGNUCAPFO
 
+using  namespace  std;
 
 // Function prototypes
 
 void  Usage( char * psAppName );
 
-//*****************************************************************************
+//**************************************************************************************************
 
 int  main( int argc, char * argv[ ] )
 {
@@ -279,7 +267,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdGnuCapFO Test Utility"
-       << "\n    Version 1.01 (04/06/2009)\n";
+       << "\n    Version 1.02 (12/08/2011)\n";
 
   // Create a GNU-CAP Transient command object
   CmdGnuCapFO  tCmd_FO;
@@ -288,7 +276,6 @@ int  main( int argc, char * argv[ ] )
   osCmd = wxT(".FO 1.00K 100.00K 10.00K TE 30.00 COLD BASIC");
 
   // Set things up for a formatter test
-  tCmd_FO.bClear( );
   tCmd_FO.m_osStart = wxT("1.00K");
   tCmd_FO.m_osStop  = wxT("100.00K");
   tCmd_FO.m_osStep  = wxT("10.00K");
@@ -300,7 +287,6 @@ int  main( int argc, char * argv[ ] )
   cout << "\ntCmd_FO Contents : " << tCmd_FO.mb_str( ) << '\n';
 
   // Set things up for a parser test
-  tCmd_FO.bClear( );
   tCmd_FO.bSetString( osCmd );
   cout << "\nRun Parser       : " << ( tCmd_FO.bParse( ) ? "OK" : "FAULT" );
   tCmd_FO.bFormat( );
@@ -313,7 +299,7 @@ int  main( int argc, char * argv[ ] )
   exit( EXIT_SUCCESS );
 }
 
-//*****************************************************************************
+//**************************************************************************************************
 
 void  Usage( char * psAppName )
 {
@@ -322,6 +308,6 @@ void  Usage( char * psAppName )
        << "\n  -h : Print usage (this message)\n";
 }
 
-#endif // TEST_CMDGCPFO
+#endif // TEST_CMDGNUCAPFO
 
-//*****************************************************************************
+//**************************************************************************************************
