@@ -4,8 +4,8 @@
 // Description : This class contains values associated with the GNU-Cap FOURIER command. It        *
 //               inherits from the class CmdBase.                                                  *
 // Started     : 2008-03-11                                                                        *
-// Last Update : 2015-03-07                                                                        *
-// Copyright   : (C) 2008 by MSWaters                                                              *
+// Last Update : 2018-09-23                                                                        *
+// Copyright   : (C) 2008-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -35,7 +35,7 @@ class CmdGnuCapFO : public CmdBase
 {
   private :
 
-    virtual  bool  bValidate( void );
+    bool  bValidate( void ) override;
 
   public :
 
@@ -45,15 +45,15 @@ class CmdGnuCapFO : public CmdBase
     eTypeInitC  m_eInitC;   // The sweep scale type
     wxString    m_osTempC;  // The analysis temperature
 
-                   CmdGnuCapFO( void );
-    virtual       ~CmdGnuCapFO( );
+          CmdGnuCapFO( void );
+         ~CmdGnuCapFO( );
 
-    virtual  bool  bSetDefaults( void );
+    bool  bSetDefaults( void ) override;
 
-    virtual  bool  bParse ( void );
-    virtual  bool  bFormat( void );
+    bool  bParse ( void ) override;
+    bool  bFormat( void ) override;
 
-             void  Print( const wxString & rosPrefix=wxT("  ") );
+    void  Print( const wxString & rosPrefix=wxT("  ") ) override;
 };
 
 //**************************************************************************************************
