@@ -2,8 +2,8 @@
 //                                         CmdGnuCapGEN.cpp                                        *
 //                                        ------------------                                       *
 // Started     : 2008-03-11                                                                        *
-// Last Update : 2014-12-23                                                                        *
-// Copyright   : (C) 2008 by MSWaters                                                              *
+// Last Update : 2018-11-03                                                                        *
+// Copyright   : (C) 2008-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -19,7 +19,7 @@
 //**************************************************************************************************
 // Constructor.
 
-CmdGnuCapGEN::CmdGnuCapGEN( void )
+CmdGnuCapGEN::CmdGnuCapGEN( void ) : CmdBase( )
 {
   bSetDefaults( );
 }
@@ -49,21 +49,21 @@ bool  CmdGnuCapGEN::bValidate( void )
     SetErrMsg( wxT("overall amplitude value is invalid") );
 //  if( df1 <= 0.0 ) ??? 05/10/2009
 //    SetErrMsg( wxT("overall amplitude value must be greater than zero") );
-  if( ! CnvtType::bStrToFlt( m_osOffset,    &df1 ) )
+  if( ! CnvtType::bStrToFlt( m_osOffset   , &df1 ) )
     SetErrMsg( wxT("overall offset value is invalid") );
 
   // Sinusoidal source characteristics
-  if( ! CnvtType::bStrToFlt( m_osSinFreq,  &df1 ) )
+  if( ! CnvtType::bStrToFlt( m_osSinFreq  , &df1 ) )
     SetErrMsg( wxT("sinusoid frequency value is invalid") );
-  if( ! CnvtType::bStrToFlt( m_osSinPhase, &df1 ) )
+  if( ! CnvtType::bStrToFlt( m_osSinPhase , &df1 ) )
     SetErrMsg( wxT("sinusoid phase value is invalid") );
 
   // Check the pulse time values
-  if( ! CnvtType::bStrToFlt( m_osPulRise,   &df1 ) )
+  if( ! CnvtType::bStrToFlt( m_osPulRise  , &df1 ) )
     SetErrMsg( wxT("pulse rise time value is invalid") );
-  if( ! CnvtType::bStrToFlt( m_osPulWidth,  &df2 ) )
+  if( ! CnvtType::bStrToFlt( m_osPulWidth , &df2 ) )
     SetErrMsg( wxT("pulse width value is invalid") );
-  if( ! CnvtType::bStrToFlt( m_osPulFall,   &df3 ) )
+  if( ! CnvtType::bStrToFlt( m_osPulFall  , &df3 ) )
     SetErrMsg( wxT("pulse fall time value is invalid") );
   if( ! CnvtType::bStrToFlt( m_osPulPeriod, &df4 ) )
     SetErrMsg( wxT("pulse period value is invalid") );
@@ -77,11 +77,11 @@ bool  CmdGnuCapGEN::bValidate( void )
     SetErrMsg( wxT("pulse period is less then the pulse width") );
 
   // Check the pulse level values
-  if( ! CnvtType::bStrToFlt( m_osPulInitial, &df1 ) )
+  if( ! CnvtType::bStrToFlt( m_osPulInitV , &df1 ) )
     SetErrMsg( wxT("initial pulse value is invalid") );
-  if( ! CnvtType::bStrToFlt( m_osPulMin,     &df2 ) )
+  if( ! CnvtType::bStrToFlt( m_osPulMin   , &df2 ) )
     SetErrMsg( wxT("minimum pulse value is invalid") );
-  if( ! CnvtType::bStrToFlt( m_osPulMax,     &df3 ) )
+  if( ! CnvtType::bStrToFlt( m_osPulMax   , &df3 ) )
     SetErrMsg( wxT("maximum pulse value is invalid") );
   if(      df1 < df2 )
     SetErrMsg( wxT("initial pulse value is less than the minimum pulse value") );
@@ -110,23 +110,23 @@ bool  CmdGnuCapGEN::bSetDefaults( void )
 {
   CmdBase::bSetDefaults( );
 
-  m_eSimEng      = eSIMR_GNUCAP;
-  m_eCmdType     = eCMD_GEN;
+  m_eSimEng     = eSIMR_GNUCAP;
+  m_eCmdType    = eCMD_GEN;
 
-  m_osAmplitude  = GCP_AMPLITUDE;
-  m_osOffset     = GCP_OFFSET;
+  m_osAmplitude = GCP_AMPLITUDE;
+  m_osOffset    = GCP_OFFSET;
 
-  m_osSinFreq    = GCP_SINFREQ;
-  m_osSinPhase   = GCP_SINPHASE;
+  m_osSinFreq   = GCP_SINFREQ;
+  m_osSinPhase  = GCP_SINPHASE;
 
-  m_osPulInitial = GCP_PULINITIAL;
-  m_osPulMin     = GCP_PULMIN;
-  m_osPulMax     = GCP_PULMAX;
-  m_osPulDelay   = GCP_PULDELAY;
-  m_osPulRise    = GCP_PULRISE;
-  m_osPulWidth   = GCP_PULWIDTH;
-  m_osPulFall    = GCP_PULFALL;
-  m_osPulPeriod  = GCP_PULPERIOD;
+  m_osPulInitV  = GCP_PULINITV;
+  m_osPulMin    = GCP_PULMIN;
+  m_osPulMax    = GCP_PULMAX;
+  m_osPulDelay  = GCP_PULDELAY;
+  m_osPulRise   = GCP_PULRISE;
+  m_osPulWidth  = GCP_PULWIDTH;
+  m_osPulFall   = GCP_PULFALL;
+  m_osPulPeriod = GCP_PULPERIOD;
 
   return( true );
 }
@@ -134,9 +134,8 @@ bool  CmdGnuCapGEN::bSetDefaults( void )
 //**************************************************************************************************
 // Parse the command string.
 //
-// Eg.s : .GENERATOR AMP=2.00K OFFSET=1.00 FREQ=1.00K PHASE=50.00 INIT=5.00m
-//                   MIN=2.00m MAX=10.00m DELAY=4.00m RISE=2.00m WIDTH=8.00m
-//                   FALL=1.00m PERIOD=20.00m
+// Eg.s : .GENERATOR AMP=2.00K OFFSET=1.00 FREQ=1.00K PHASE=50.00 INIT=5.00m MIN=2.00m MAX=10.00m
+//                   DELAY=4.00m RISE=2.00m WIDTH=8.00m FALL=1.00m PERIOD=20.00m
 //
 // Return Values :
 //   true  - Success
@@ -176,18 +175,18 @@ bool  CmdGnuCapGEN::bParse( void )
     }
 
     // Set the object attribute values
-    if(      os1 == wxT("AMP")    ) m_osAmplitude  = os2;
-    else if( os1 == wxT("OFFSET") ) m_osOffset     = os2;
-    else if( os1 == wxT("FREQ")   ) m_osSinFreq    = os2;
-    else if( os1 == wxT("PHASE")  ) m_osSinPhase   = os2;
-    else if( os1 == wxT("INIT")   ) m_osPulInitial = os2;
-    else if( os1 == wxT("MIN")    ) m_osPulMin     = os2;
-    else if( os1 == wxT("MAX")    ) m_osPulMax     = os2;
-    else if( os1 == wxT("DELAY")  ) m_osPulDelay   = os2;
-    else if( os1 == wxT("RISE")   ) m_osPulRise    = os2;
-    else if( os1 == wxT("WIDTH")  ) m_osPulWidth   = os2;
-    else if( os1 == wxT("FALL")   ) m_osPulFall    = os2;
-    else if( os1 == wxT("PERIOD") ) m_osPulPeriod  = os2;
+    if(      os1 == wxT("AMP")    ) m_osAmplitude = os2;
+    else if( os1 == wxT("OFFSET") ) m_osOffset    = os2;
+    else if( os1 == wxT("FREQ")   ) m_osSinFreq   = os2;
+    else if( os1 == wxT("PHASE")  ) m_osSinPhase  = os2;
+    else if( os1 == wxT("INIT")   ) m_osPulInitV  = os2;
+    else if( os1 == wxT("MIN")    ) m_osPulMin    = os2;
+    else if( os1 == wxT("MAX")    ) m_osPulMax    = os2;
+    else if( os1 == wxT("DELAY")  ) m_osPulDelay  = os2;
+    else if( os1 == wxT("RISE")   ) m_osPulRise   = os2;
+    else if( os1 == wxT("WIDTH")  ) m_osPulWidth  = os2;
+    else if( os1 == wxT("FALL")   ) m_osPulFall   = os2;
+    else if( os1 == wxT("PERIOD") ) m_osPulPeriod = os2;
     else                   return( bValidate( ) );
   }
 
@@ -224,7 +223,7 @@ bool  CmdGnuCapGEN::bFormat( void )
   b1 = CnvtType::bStrToFlt( m_osPulMax, &f1 );
   if( b1==true && f1!=0.0 )
   {
-    os1 << wxT(" INIT=")   << m_osPulInitial;
+    os1 << wxT(" INIT=")   << m_osPulInitV;
     os1 << wxT(" MIN=")    << m_osPulMin;
     os1 << wxT(" MAX=")    << m_osPulMax;
     os1 << wxT(" DELAY=")  << m_osPulDelay;
@@ -248,9 +247,10 @@ bool  CmdGnuCapGEN::bFormat( void )
 // Return Values :
 //   A reference to this object
 
-CmdGnuCapGEN & CmdGnuCapGEN::operator = ( const CpntNgsIndSrc & roIndSrc )
+CmdGnuCapGEN & CmdGnuCapGEN::operator = ( const CpntNgSpiceIndSrc & roIndSrc )
 {
   double  df1, df2;
+  int     i1;
 
   if( ! roIndSrc.m_osSinAmp.IsEmpty( ) ) m_osAmplitude = roIndSrc.m_osSinAmp;
   else                                   m_osAmplitude = wxT("1.0");
@@ -259,17 +259,27 @@ CmdGnuCapGEN & CmdGnuCapGEN::operator = ( const CpntNgsIndSrc & roIndSrc )
   m_osSinFreq    = roIndSrc.m_osSinFreq;
   if( CnvtType::bStrToFlt( roIndSrc.m_osSinFreq,  &df1 ) &&
       CnvtType::bStrToFlt( roIndSrc.m_osSinDelay, &df2 ) )
-    CnvtType::bFltToStr( 360.0 * df2 * df1, m_osSinPhase );
+  {
+    if( CnvtType::bIsEqual(df1,0.0) || CnvtType::bIsEqual(df2,0.0) ) m_osSinPhase = wxT("0.0m");
+    else
+    {
+      i1 = CnvtType::iGetFltRes( );
+      CnvtType::bSetFltRes( 2 );
+      CnvtType::bFltToStrEng( df1 * df2 * 360.0, m_osSinPhase );
+      CnvtType::bSetFltRes( i1 );
+      m_osSinPhase.Trim( false );
+    }
+  }
   else
-    m_osSinPhase = wxT("0.0");
+    m_osSinPhase = wxT("0.0m");
 
-  m_osPulInitial = roIndSrc.m_osPulInitial;
-  m_osPulMax     = roIndSrc.m_osPulMax;
-  m_osPulDelay   = roIndSrc.m_osPulDelay;
-  m_osPulRise    = roIndSrc.m_osPulRise;
-  m_osPulWidth   = roIndSrc.m_osPulWidth;
-  m_osPulFall    = roIndSrc.m_osPulFall;
-  m_osPulPeriod  = roIndSrc.m_osPulPeriod;
+  m_osPulInitV  = roIndSrc.m_osPulInitV;
+  m_osPulMax    = roIndSrc.m_osPulValue;
+  m_osPulDelay  = roIndSrc.m_osPulDelay;
+  m_osPulRise   = roIndSrc.m_osPulRise;
+  m_osPulWidth  = roIndSrc.m_osPulWidth;
+  m_osPulFall   = roIndSrc.m_osPulFall;
+  m_osPulPeriod = roIndSrc.m_osPulPeriod;
 
   bFormat( );
 
@@ -286,20 +296,20 @@ void  CmdGnuCapGEN::Print( const wxString & rosPrefix )
 {
   CmdBase::Print( rosPrefix + wxT("CmdBase::") );
 
-  std::cout << rosPrefix.mb_str( ) << "m_osAmplitude  : " << m_osAmplitude .mb_str( ) << '\n';
-  std::cout << rosPrefix.mb_str( ) << "m_osOffset     : " << m_osOffset    .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osAmplitude : " << m_osAmplitude.mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osOffset    : " << m_osOffset   .mb_str( ) << '\n';
 
-  std::cout << rosPrefix.mb_str( ) << "m_osSinFreq    : " << m_osSinFreq   .mb_str( ) << '\n';
-  std::cout << rosPrefix.mb_str( ) << "m_osSinPhase   : " << m_osSinPhase  .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osSinFreq   : " << m_osSinFreq  .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osSinPhase  : " << m_osSinPhase .mb_str( ) << '\n';
 
-  std::cout << rosPrefix.mb_str( ) << "m_osPulInitial : " << m_osPulInitial.mb_str( ) << '\n';
-  std::cout << rosPrefix.mb_str( ) << "m_osPulMin     : " << m_osPulMin    .mb_str( ) << '\n';
-  std::cout << rosPrefix.mb_str( ) << "m_osPulMax     : " << m_osPulMax    .mb_str( ) << '\n';
-  std::cout << rosPrefix.mb_str( ) << "m_osPulDelay   : " << m_osPulDelay  .mb_str( ) << '\n';
-  std::cout << rosPrefix.mb_str( ) << "m_osPulRise    : " << m_osPulRise   .mb_str( ) << '\n';
-  std::cout << rosPrefix.mb_str( ) << "m_osPulWidth   : " << m_osPulWidth  .mb_str( ) << '\n';
-  std::cout << rosPrefix.mb_str( ) << "m_osPulFall    : " << m_osPulFall   .mb_str( ) << '\n';
-  std::cout << rosPrefix.mb_str( ) << "m_osPulPeriod  : " << m_osPulPeriod .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osPulInitV  : " << m_osPulInitV .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osPulMin    : " << m_osPulMin   .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osPulMax    : " << m_osPulMax   .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osPulDelay  : " << m_osPulDelay .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osPulRise   : " << m_osPulRise  .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osPulWidth  : " << m_osPulWidth .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osPulFall   : " << m_osPulFall  .mb_str( ) << '\n';
+  std::cout << rosPrefix.mb_str( ) << "m_osPulPeriod : " << m_osPulPeriod.mb_str( ) << '\n';
 }
 
 //**************************************************************************************************
@@ -334,7 +344,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdGnuCapGEN Test Utility"
-       << "\n     Version 1.04 (12/08/2011)\n";
+       << "\n     Version 1.05 (2018-11-03)\n";
 
   // Create a GNU-CAP Transient command object
   CmdGnuCapGEN  tCmd_GEN;
@@ -345,18 +355,18 @@ int  main( int argc, char * argv[ ] )
         << wxT("WIDTH=8.00m FALL=1.00m PERIOD=20.00m");
 
   // Set things up for a formatter test
-  tCmd_GEN.m_osAmplitude  = wxT("2.00K");
-  tCmd_GEN.m_osOffset     = wxT("1.00");
-  tCmd_GEN.m_osSinFreq    = wxT("1.00K");
-  tCmd_GEN.m_osSinPhase   = wxT("50.00");
-  tCmd_GEN.m_osPulInitial = wxT("5.00m");
-  tCmd_GEN.m_osPulMin     = wxT("2.00m");
-  tCmd_GEN.m_osPulMax     = wxT("10.00m");
-  tCmd_GEN.m_osPulDelay   = wxT("4.00m");
-  tCmd_GEN.m_osPulRise    = wxT("2.00m");
-  tCmd_GEN.m_osPulWidth   = wxT("8.00m");
-  tCmd_GEN.m_osPulFall    = wxT("1.00m");
-  tCmd_GEN.m_osPulPeriod  = wxT("20.00m");
+  tCmd_GEN.m_osAmplitude = wxT("2.00K");
+  tCmd_GEN.m_osOffset    = wxT("1.00");
+  tCmd_GEN.m_osSinFreq   = wxT("1.00K");
+  tCmd_GEN.m_osSinPhase  = wxT("50.00");
+  tCmd_GEN.m_osPulInitV  = wxT("5.00m");
+  tCmd_GEN.m_osPulMin    = wxT("2.00m");
+  tCmd_GEN.m_osPulMax    = wxT("10.00m");
+  tCmd_GEN.m_osPulDelay  = wxT("4.00m");
+  tCmd_GEN.m_osPulRise   = wxT("2.00m");
+  tCmd_GEN.m_osPulWidth  = wxT("8.00m");
+  tCmd_GEN.m_osPulFall   = wxT("1.00m");
+  tCmd_GEN.m_osPulPeriod = wxT("20.00m");
   cout << "\nRun Formatter     : " << ( tCmd_GEN.bFormat( ) ? "OK" : "FAULT" );
   cout << "\nTest Cmd Format   : " << ( tCmd_GEN == osCmd   ? "OK" : "FAULT" );
   cout << "\nExample Command   : " << osCmd  .mb_str( );
