@@ -4,8 +4,8 @@
 // Description : This class contains values associated with the GNU-Cap GENERATOR command. It      *
 //               inherits from the class CmdBase.                                                  *
 // Started     : 2008-03-11                                                                        *
-// Last Update : 2015-04-16                                                                        *
-// Copyright   : (C) 2008 by MSWaters                                                              *
+// Last Update : 2018-11-03                                                                        *
+// Copyright   : (C) 2008-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -24,26 +24,26 @@
 #include "TypeDefs.hpp"
 #include "base/CmdBase.hpp"
 #include "utility/CnvtType.hpp"
-#include "netlist/CpntNgsIndSrc.hpp"
+#include "netlist/CpntNgSpiceIndSrc.hpp"
 
-class CpntNgsIndSrc;
+class CpntNgSpiceIndSrc;
 
 // Local Macro and/or Constant Declarations
 
-#define  GCP_AMPLITUDE   wxT("1.0")
-#define  GCP_OFFSET      wxT("0.0")
+#define  GCP_AMPLITUDE  wxT("1.0")
+#define  GCP_OFFSET     wxT("0.0")
 
-#define  GCP_SINFREQ     wxT("1.0K")
-#define  GCP_SINPHASE    wxT("0.0")
+#define  GCP_SINFREQ    wxT("0.0k")
+#define  GCP_SINPHASE   wxT("0.0")
 
-#define  GCP_PULINITIAL  wxT("0.0")
-#define  GCP_PULMIN      wxT("0.0")
-#define  GCP_PULMAX      wxT("0.0")
-#define  GCP_PULDELAY    wxT("0.0m")
-#define  GCP_PULRISE     wxT("0.0m")
-#define  GCP_PULWIDTH    wxT("0.0m")
-#define  GCP_PULFALL     wxT("0.0m")
-#define  GCP_PULPERIOD   wxT("0.0m")
+#define  GCP_PULINITV   wxT("0.0")
+#define  GCP_PULMIN     wxT("0.0")
+#define  GCP_PULMAX     wxT("0.0")
+#define  GCP_PULDELAY   wxT("0.0m")
+#define  GCP_PULRISE    wxT("0.0m")
+#define  GCP_PULWIDTH   wxT("0.0m")
+#define  GCP_PULFALL    wxT("0.0m")
+#define  GCP_PULPERIOD  wxT("0.0m")
 
 //**************************************************************************************************
 
@@ -51,7 +51,7 @@ class CmdGnuCapGEN : public CmdBase
 {
   private :
 
-    virtual  bool  bValidate( void );
+    bool  bValidate( void ) override;
 
   public :
 
@@ -64,7 +64,7 @@ class CmdGnuCapGEN : public CmdBase
     wxString  m_osSinPhase;
 
     // Pulse source characteristics
-    wxString  m_osPulInitial;
+    wxString  m_osPulInitV;
     wxString  m_osPulMin;
     wxString  m_osPulMax;
     wxString  m_osPulDelay;
@@ -73,17 +73,17 @@ class CmdGnuCapGEN : public CmdBase
     wxString  m_osPulFall;
     wxString  m_osPulPeriod;
 
-                   CmdGnuCapGEN( void );
-    virtual       ~CmdGnuCapGEN( );
+          CmdGnuCapGEN( void );
+         ~CmdGnuCapGEN( );
 
-    virtual  bool  bSetDefaults( void );
+    bool  bSetDefaults( void ) override;
 
-    virtual  bool  bParse ( void );
-    virtual  bool  bFormat( void );
+    bool  bParse ( void ) override;
+    bool  bFormat( void ) override;
 
-    CmdGnuCapGEN & operator = ( const CpntNgsIndSrc & roIndSrc );
+    CmdGnuCapGEN & operator = ( const CpntNgSpiceIndSrc & roIndSrc );
 
-             void  Print( const wxString & rosPrefix=wxT("  ") );
+    void  Print( const wxString & rosPrefix=wxT("  ") ) override;
 };
 
 //**************************************************************************************************
