@@ -4,8 +4,8 @@
 // Description : This class contains values associated with the GNU-Cap OP (Operating Point)       *
 //               command. It inherits from the class  CmdBase.                                     *
 // Started     : 2008-03-05                                                                        *
-// Last Update : 2015-03-07                                                                        *
-// Copyright   : (C) 2008 by MSWaters                                                              *
+// Last Update : 2018-09-23                                                                        *
+// Copyright   : (C) 2008-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -34,7 +34,7 @@ class CmdGnuCapOP : public CmdBase
 {
   private :
 
-    virtual  bool  bValidate( void );
+    bool  bValidate( void ) override;
 
   public :
 
@@ -43,17 +43,17 @@ class CmdGnuCapOP : public CmdBase
     wxString    m_osStep;   // Sweep step  value
     eTypeScale  m_eScale;   // The sweep scale type
 
-                   CmdGnuCapOP( void );
-    virtual       ~CmdGnuCapOP( );
+          CmdGnuCapOP( void );
+         ~CmdGnuCapOP( );
 
-    virtual  bool  bSetDefaults( void );
+    bool  bSetDefaults( void ) override;
 
-    virtual  bool  bParse ( void );
-    virtual  bool  bFormat( void );
+    bool  bParse ( void ) override;
+    bool  bFormat( void ) override;
 
     CmdGnuCapOP & operator = ( const CmdNgSpiceDC & roCmdDC );
 
-             void  Print( const wxString & rosPrefix=wxT("  ") );
+    void  Print( const wxString & rosPrefix=wxT("  ") ) override;
 };
 
 //**************************************************************************************************
