@@ -2,8 +2,8 @@
 //                                         CmdGnuCapOPT.cpp                                        *
 //                                        ------------------                                       *
 // Started     : 2006-09-11                                                                        *
-// Last Update : 2015-01-05                                                                        *
-// Copyright   : (C) 2006 by MSWaters                                                              *
+// Last Update : 2018-11-12                                                                        *
+// Copyright   : (C) 2006-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -19,7 +19,7 @@
 //**************************************************************************************************
 // Constructor.
 
-CmdGnuCapOPT::CmdGnuCapOPT( void )
+CmdGnuCapOPT::CmdGnuCapOPT( void ) : CmdBase( )
 {
   bSetDefaults( );
 }
@@ -192,7 +192,7 @@ bool  CmdGnuCapOPT::bParse( void )
 {
   wxStringTokenizer  ostk1;
   wxString           os1, os2;
-  size_t             szt1;
+  size_t             sz1;
 
   // Clear the object attributes
   os1 = (wxString &) *this;
@@ -213,10 +213,10 @@ bool  CmdGnuCapOPT::bParse( void )
     // Extract the field name and the associated value
     os1 = ostk1.GetNextToken( );
     os2 = wxT("");
-    if( ( szt1=os1.find( wxT("=") ) ) != wxString::npos )
+    if( ( sz1=os1.find( wxT("=") ) ) != wxString::npos )
     {
-      os2 = os1.Right( os1.Length( )-szt1-1 );
-      os1 = os1.Left( szt1 );
+      os2 = os1.Right( os1.Length( )-sz1-1 );
+      os1 = os1.Left( sz1 );
     }
 
     // Set the object attribute values
@@ -505,62 +505,62 @@ CmdGnuCapOPT & CmdGnuCapOPT::operator = ( const CmdNgSpiceOPT & roCmdOPT )
 {
   (CmdBase &) *this = (CmdBase &) roCmdOPT;
 
-  if( m_osABSTOL   != GCP_ABSTOL   ) m_osABSTOL   = roCmdOPT.m_osABSTOL;
-  if( m_osCHGTOL   != GCP_CHGTOL   ) m_osCHGTOL   = roCmdOPT.m_osCHGTOL;
-//if( m_osDAMPMAX  != GCP_DAMPMAX  ) m_osDAMPMAX  = roCmdOPT.m_osDAMPMAX;
-//if( m_osDAMPMIN  != GCP_DAMPMIN  ) m_osDAMPMIN  = roCmdOPT.m_osDAMPMIN;
-//if( m_osDAMPST   != GCP_DAMPST   ) m_osDAMPST   = roCmdOPT.m_osDAMPST;
-  if( m_osDEFAD    != GCP_DEFAD    ) m_osDEFAD    = roCmdOPT.m_osDEFAD;
-  if( m_osDEFAS    != GCP_DEFAS    ) m_osDEFAS    = roCmdOPT.m_osDEFAS;
-  if( m_osDEFL     != GCP_DEFL     ) m_osDEFL     = roCmdOPT.m_osDEFL;
-  if( m_osDEFW     != GCP_DEFW     ) m_osDEFW     = roCmdOPT.m_osDEFW;
-//if( m_osDTMIN    != GCP_DTMIN    ) m_osDTMIN    = roCmdOPT.m_osDTMIN;
-//if( m_osDTRATIO  != GCP_DTRATIO  ) m_osDTRATIO  = roCmdOPT.m_osDTRATIO;
-//if( m_osFLOOR    != GCP_FLOOR    ) m_osFLOOR    = roCmdOPT.m_osFLOOR;
-  if( m_osGMIN     != GCP_GMIN     ) m_osGMIN     = roCmdOPT.m_osGMIN;
-  if( m_osRELTOL   != GCP_RELTOL   ) m_osRELTOL   = roCmdOPT.m_osRELTOL;
-//if( m_osROUND    != GCP_ROUND    ) m_osROUND    = roCmdOPT.m_osROUND;
-//if( m_osSHORT    != GCP_SHORT    ) m_osSHORT    = roCmdOPT.m_osSHORT;
-  if( m_osTEMP     != GCP_TEMP     ) m_osTEMP     = roCmdOPT.m_osTEMP;
-  if( m_osTNOM     != GCP_TNOM     ) m_osTNOM     = roCmdOPT.m_osTNOM;
-//if( m_osTRREJECT != GCP_TRREJECT ) m_osTRREJECT = roCmdOPT.m_osTRREJECT;
-//if( m_osTRSTEPG  != GCP_TRSTEPG  ) m_osTRSTEPG  = roCmdOPT.m_osTRSTEPG;
-//if( m_osTRSTEPH  != GCP_TRSTEPH  ) m_osTRSTEPH  = roCmdOPT.m_osTRSTEPH;
-//if( m_osTRSTEPS  != GCP_TRSTEPS  ) m_osTRSTEPS  = roCmdOPT.m_osTRSTEPS;
-  if( m_osTRTOL    != GCP_TRTOL    ) m_osTRTOL    = roCmdOPT.m_osTRTOL;
-//if( m_osVFLOOR   != GCP_VFLOOR   ) m_osVFLOOR   = roCmdOPT.m_osVFLOOR;
-//if( m_osVMAX     != GCP_VMAX     ) m_osVMAX     = roCmdOPT.m_osVMAX;
-//if( m_osVMIN     != GCP_VMIN     ) m_osVMIN     = roCmdOPT.m_osVMIN;
-  if( m_osVNTOL    != GCP_VNTOL    ) m_osVNTOL    = roCmdOPT.m_osVNTOL;
+  m_osABSTOL   = roCmdOPT.m_osABSTOL;
+  m_osCHGTOL   = roCmdOPT.m_osCHGTOL;
+//m_osDAMPMAX  = roCmdOPT.m_osDAMPMAX;
+//m_osDAMPMIN  = roCmdOPT.m_osDAMPMIN;
+//m_osDAMPST   = roCmdOPT.m_osDAMPST;
+  m_osDEFAD    = roCmdOPT.m_osDEFAD;
+  m_osDEFAS    = roCmdOPT.m_osDEFAS;
+  m_osDEFL     = roCmdOPT.m_osDEFL;
+  m_osDEFW     = roCmdOPT.m_osDEFW;
+//m_osDTMIN    = roCmdOPT.m_osDTMIN;
+//m_osDTRATIO  = roCmdOPT.m_osDTRATIO;
+//m_osFLOOR    = roCmdOPT.m_osFLOOR;
+  m_osGMIN     = roCmdOPT.m_osGMIN;
+  m_osRELTOL   = roCmdOPT.m_osRELTOL;
+//m_osROUND    = roCmdOPT.m_osROUND;
+//m_osSHORT    = roCmdOPT.m_osSHORT;
+  m_osTEMP     = roCmdOPT.m_osTEMP;
+  m_osTNOM     = roCmdOPT.m_osTNOM;
+//m_osTRREJECT = roCmdOPT.m_osTRREJECT;
+//m_osTRSTEPG  = roCmdOPT.m_osTRSTEPG;
+//m_osTRSTEPH  = roCmdOPT.m_osTRSTEPH;
+//m_osTRSTEPS  = roCmdOPT.m_osTRSTEPS;
+  m_osTRTOL    = roCmdOPT.m_osTRTOL;
+//m_osVFLOOR   = roCmdOPT.m_osVFLOOR;
+//m_osVMAX     = roCmdOPT.m_osVMAX;
+//m_osVMIN     = roCmdOPT.m_osVMIN;
+  m_osVNTOL    = roCmdOPT.m_osVNTOL;
 
-//if( m_osHARMS    != GCP_HARMS    ) m_osHARMS    = roCmdOPT.m_osHARMS;
-  if( m_osITL1     != GCP_ITL1     ) m_osITL1     = roCmdOPT.m_osITL1;
-  if( m_osITL2     != GCP_ITL2     ) m_osITL2     = roCmdOPT.m_osITL2;
-  if( m_osITL3     != GCP_ITL3     ) m_osITL3     = roCmdOPT.m_osITL3;
-  if( m_osITL4     != GCP_ITL4     ) m_osITL4     = roCmdOPT.m_osITL4;
-  if( m_osITL5     != GCP_ITL5     ) m_osITL5     = roCmdOPT.m_osITL5;
-  if( m_osITL6     != GCP_ITL6     ) m_osITL6     = roCmdOPT.m_osITL6;
-//if( m_osITL7     != GCP_ITL7     ) m_osITL7     = roCmdOPT.m_osITL7;
-//if( m_osITL8     != GCP_ITL8     ) m_osITL8     = roCmdOPT.m_osITL8;
-//if( m_osITERMIN  != GCP_ITERMIN  ) m_osITERMIN  = roCmdOPT.m_osITERMIN;
-//if( m_osNUMDGT   != GCP_NUMDGT   ) m_osNUMDGT   = roCmdOPT.m_osNUMDGT;
-//if( m_osRECURS   != GCP_RECURS   ) m_osRECURS   = roCmdOPT.m_osRECURS;
-//if( m_osTRANSITS != GCP_TRANSITS ) m_osTRANSITS = roCmdOPT.m_osTRANSITS;
+//m_osHARMS    = roCmdOPT.m_osHARMS;
+  m_osITL1     = roCmdOPT.m_osITL1;
+  m_osITL2     = roCmdOPT.m_osITL2;
+  m_osITL3     = roCmdOPT.m_osITL3;
+  m_osITL4     = roCmdOPT.m_osITL4;
+  m_osITL5     = roCmdOPT.m_osITL5;
+  m_osITL6     = roCmdOPT.m_osITL6;
+//m_osITL7     = roCmdOPT.m_osITL7;
+//m_osITL8     = roCmdOPT.m_osITL8;
+//m_osITERMIN  = roCmdOPT.m_osITERMIN;
+//m_osNUMDGT   = roCmdOPT.m_osNUMDGT;
+//m_osRECURS   = roCmdOPT.m_osRECURS;
+//m_osTRANSITS = roCmdOPT.m_osTRANSITS;
 
-  if( m_osMETHOD   != GCP_METHOD   ) m_osMETHOD   = roCmdOPT.m_osMETHOD;
-//if( m_osMODE     != GCP_MODE     ) m_osMODE     = roCmdOPT.m_osMODE;
-//if( m_osORDER    != GCP_ORDER    ) m_osORDER    = roCmdOPT.m_osORDER;
-//if( m_osPHASE    != GCP_PHASE    ) m_osPHASE    = roCmdOPT.m_osPHASE;
+  m_osMETHOD   = roCmdOPT.m_osMETHOD;
+//m_osMODE     = roCmdOPT.m_osMODE;
+//m_osORDER    = roCmdOPT.m_osORDER;
+//m_osPHASE    = roCmdOPT.m_osPHASE;
 
-//if( m_bBYPASS    != GCP_BYPASS   ) m_bBYPASS    = roCmdOPT.m_osBYPASS;
-//if( m_bCSTRAY    != GCP_CSTRAY   ) m_bCSTRAY    = roCmdOPT.m_osCSTRAY;
-//if( m_bFBBYPASS  != GCP_FBBYPASS ) m_bFBBYPASS  = roCmdOPT.m_osFBBYPASS;
-//if( m_bINCMODE   != GCP_INCMODE  ) m_bINCMODE   = roCmdOPT.m_osINCMODE;
-//if( m_bLUBYPASS  != GCP_LUBYPASS ) m_bLUBYPASS  = roCmdOPT.m_osLUBYPASS;
-//if( m_bOPTS      != GCP_OPTS     ) m_bOPTS      = roCmdOPT.m_osOPTS;
-//if( m_bQUITCONV  != GCP_QUITCONV ) m_bQUITCONV  = roCmdOPT.m_osQUITCONV;
-//if( m_bRSTRAY    != GCP_RSTRAY   ) m_bRSTRAY    = roCmdOPT.m_osRSTRAY;
-//if( m_bTRACEL    != GCP_TRACEL   ) m_bTRACEL    = roCmdOPT.m_osTRACEL;
+//m_bBYPASS    = roCmdOPT.m_osBYPASS;
+//m_bCSTRAY    = roCmdOPT.m_osCSTRAY;
+//m_bFBBYPASS  = roCmdOPT.m_osFBBYPASS;
+//m_bINCMODE   = roCmdOPT.m_osINCMODE;
+//m_bLUBYPASS  = roCmdOPT.m_osLUBYPASS;
+//m_bOPTS      = roCmdOPT.m_osOPTS;
+//m_bQUITCONV  = roCmdOPT.m_osQUITCONV;
+//m_bRSTRAY    = roCmdOPT.m_osRSTRAY;
+//m_bTRACEL    = roCmdOPT.m_osTRACEL;
 
   bFormat( );
 
