@@ -2,8 +2,8 @@
 //                                         CmdGnuCapPR.cpp                                         *
 //                                        -----------------                                        *
 // Started     : 2008-03-17                                                                        *
-// Last Update : 2015-03-21                                                                        *
-// Copyright   : (C) 2008 by MSWaters                                                              *
+// Last Update : 2018-09-25                                                                        *
+// Copyright   : (C) 2008-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -19,7 +19,7 @@
 //**************************************************************************************************
 // Constructor.
 
-CmdGnuCapPR::CmdGnuCapPR( void )
+CmdGnuCapPR::CmdGnuCapPR( void ) : CmdBase( )
 {
   bSetDefaults( );
 }
@@ -47,7 +47,7 @@ bool  CmdGnuCapPR::bValidate( void )
 
   if( ( m_osaNodes.GetCount( ) + m_osaCpnts.GetCount( ) ) <= 0 )
     SetErrMsg( wxT("No components or nodes have been selected.") );
-  for( sz1=(size_t)ePARAM_FST, b1=false; sz1<=(size_t)ePARAM_LST; sz1++ )
+  for( sz1=0, b1=false; sz1<(size_t)ePARAM_NONE; sz1++ )
     if( m_bParams[ sz1 ] ) b1 = true;
   if( ! b1 )
     SetErrMsg( wxT("No parameters selected.") );
@@ -76,8 +76,8 @@ bool  CmdGnuCapPR::bSetDefaults( void )
   m_osaNodes.Empty( );
   m_osaCpnts.Empty( );
 
-  for( i1=(int)ePARAM_FST; i1<=(int)ePARAM_LST; i1++ ) m_bParams[ i1 ] = false;
-  for( i1=(int)eCPXPT_FST; i1<=(int)eCPXPT_LST; i1++ ) m_bCpxPts[ i1 ] = false;
+  for( i1=0; i1<(int)ePARAM_NONE; i1++ ) m_bParams[ i1 ] = false;
+  for( i1=0; i1<(int)eCPXPT_NONE; i1++ ) m_bCpxPts[ i1 ] = false;
 
   return( true );
 }
@@ -184,6 +184,7 @@ bool  CmdGnuCapPR::bParse( void )
             m_bCpxPts[ eCPXPT_MAGDB ] = true;
             break;
           }
+          else                   return( bValidate( ) );
         default :                return( bValidate( ) );
       }
     }
@@ -217,9 +218,8 @@ bool  CmdGnuCapPR::bParse( void )
 
 bool  CmdGnuCapPR::bFormat( void )
 {
-  wxString           osCmd, osParam, osCpxPt, os1;
-  wxStringTokenizer  ostk1;
-  int                i1, i2, i3;
+  wxString  osCmd, osParam, osCpxPt, os1;
+  int       i1, i2, i3;
 
   // Set the command name
   osCmd = wxT(".PRINT ");
@@ -237,7 +237,7 @@ bool  CmdGnuCapPR::bFormat( void )
 
   // Sequence through the various parameter types
   osCmd << wxT(' ');
-  for( i1=ePARAM_FST; i1<=ePARAM_LST; i1++ )
+  for( i1=0; i1<ePARAM_NONE; i1++ )
   {
     if( ! m_bParams[ i1 ] ) continue;
 
@@ -251,7 +251,7 @@ bool  CmdGnuCapPR::bFormat( void )
     }
 
     // Sequence through the various complex parts
-    for( i2=eCPXPT_FST; i2<eCPXPT_LST; i2++ )
+    for( i2=0; i2<(int)eCPXPT_NONE-1; i2++ )
     {
       if( m_eAnaType == eCMD_AC )
       {
@@ -305,10 +305,8 @@ CmdGnuCapPR & CmdGnuCapPR::operator = ( const CmdNgSpicePR & roCmdPR )
   m_osaNodes = roCmdPR.m_osaNodes;
   m_osaCpnts = roCmdPR.m_osaCpnts;
 
-  for( i1=(int)ePARAM_FST; i1<=(int)ePARAM_LST; i1++ )
-    m_bParams[ i1 ] = roCmdPR.m_bParams[ i1 ];
-  for( i1=(int)eCPXPT_FST; i1<=(int)eCPXPT_LST; i1++ )
-    m_bCpxPts[ i1 ] = roCmdPR.m_bCpxPts[ i1 ];
+  for( i1=0; i1<(int)ePARAM_NONE; i1++ ) m_bParams[ i1 ] = roCmdPR.m_bParams[ i1 ];
+  for( i1=0; i1<(int)eCPXPT_NONE; i1++ ) m_bCpxPts[ i1 ] = roCmdPR.m_bCpxPts[ i1 ];
 
   bFormat( );
 
@@ -357,12 +355,12 @@ void  CmdGnuCapPR::Print( const wxString & rosPrefix )
   std::cout << '\n';
 
   std::cout << rosPrefix.mb_str( ) << "m_bParams [ n ] :";
-  for( i1=(int)ePARAM_FST; i1<=(int)ePARAM_LST; i1++ )
+  for( i1=0; i1<(int)ePARAM_NONE; i1++ )
     std::cout << ( m_bParams[ i1 ] ? " true " : " false" );
   std::cout << '\n';
 
   std::cout << rosPrefix.mb_str( ) << "m_bCpxPts [ n ] :";
-  for( i1=(int)eCPXPT_FST; i1<=(int)eCPXPT_LST; i1++ )
+  for( i1=0; i1<(int)eCPXPT_NONE; i1++ )
     std::cout << ( m_bCpxPts[ i1 ] ? " true " : " false" );
   std::cout << '\n';
 }
@@ -399,7 +397,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdGnuCapPR Test Utility"
-       << "\n    Version 1.02 (04/04/2014)\n";
+       << "\n    Version 1.03 (2016-09-29)\n";
 
   // Create a NG-SPICE PRINT command object
   CmdGnuCapPR  oCmd_PR;
@@ -408,7 +406,7 @@ int  main( int argc, char * argv[ ] )
   osCmd = wxT(".PRINT AC VM(C1) VM(R1) VM(2) VP(C1) VP(R1) VP(2)");
 
   // Set things up for a formatter test
-  oCmd_PR.m_eAnaType = eCMD_AC;
+  oCmd_PR.bSetAnaType( eCMD_AC );
   oCmd_PR.m_osaCpnts.Add( wxT("C1") );
   oCmd_PR.m_osaCpnts.Add( wxT("R1") );
   oCmd_PR.m_osaNodes.Add( wxT("2") );
