@@ -4,8 +4,8 @@
 // Description : This class contains values associated with the GNU-Cap PRINT command. It inherits *
 //               from the class CmdBase.                                                           *
 // Started     : 2008-03-17                                                                        *
-// Last Update : 2015-03-07                                                                        *
-// Copyright   : (C) 2008 by MSWaters                                                              *
+// Last Update : 2018-09-23                                                                        *
+// Copyright   : (C) 2008-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -35,31 +35,31 @@ class CmdGnuCapPR : public CmdBase
 {
   private :
 
-         eTypeCmd  m_eAnaType;
+    eTypeCmd  m_eAnaType;
 
-    virtual  bool  bValidate( void );
+    bool  bValidate( void ) override;
 
   public :
 
     wxArrayString  m_osaNodes;
     wxArrayString  m_osaCpnts;
-    bool           m_bParams[ ePARAM_LST+1 ];
-    bool           m_bCpxPts[ eCPXPT_LST+1 ];
+    bool           m_bParams[ ePARAM_NONE ];
+    bool           m_bCpxPts[ eCPXPT_NONE ];
 
-                   CmdGnuCapPR( void );
-    virtual       ~CmdGnuCapPR( );
+          CmdGnuCapPR( void );
+         ~CmdGnuCapPR( );
 
-    virtual  bool  bSetDefaults( void );
-             bool  bSetAnaType ( eTypeCmd eAnaType );
+    bool  bSetDefaults( void ) override;
+    bool  bSetAnaType ( eTypeCmd eAnaType );
 
-         eTypeCmd  eGetAnaType( void ) const { return( m_eAnaType ); }
+    eTypeCmd  eGetAnaType( void ) const { return( m_eAnaType ); }
 
-    virtual  bool  bParse ( void );
-    virtual  bool  bFormat( void );
+    bool  bParse ( void ) override;
+    bool  bFormat( void ) override;
 
-     CmdGnuCapPR & operator = ( const CmdNgSpicePR & roCmdPR );
+    CmdGnuCapPR & operator = ( const CmdNgSpicePR & roCmdPR );
 
-             void  Print( const wxString & rosPrefix=wxT("  ") );
+    void  Print( const wxString & rosPrefix=wxT("  ") ) override;
 };
 
 //**************************************************************************************************
