@@ -2,8 +2,8 @@
 //                                         CmdGnuCapTR.cpp                                         *
 //                                        -----------------                                        *
 // Started     : 2008-03-07                                                                        *
-// Last Update : 2014-12-23                                                                        *
-// Copyright   : (C) 2008 by MSWaters                                                              *
+// Last Update : 2018-09-25                                                                        *
+// Copyright   : (C) 2008-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -19,7 +19,7 @@
 //**************************************************************************************************
 // Constructor.
 
-CmdGnuCapTR::CmdGnuCapTR( void )
+CmdGnuCapTR::CmdGnuCapTR( void ) : CmdBase( )
 {
   bSetDefaults( );
 }
@@ -197,7 +197,7 @@ bool  CmdGnuCapTR::bFormat( void )
   switch( m_eInitC )
   {
     case eINITC_COLD : osCmd << wxT(" COLD"); break;
-    case eINITC_UICS : osCmd << wxT(" UICS"); break;
+    case eINITC_UICS : osCmd << wxT(" UIC");  break;
     case eINITC_WARM :                        break;
     default          : break;
   }
