@@ -2,8 +2,8 @@
 //                                         PnlGnuCapAC.cpp                                         *
 //                                        -----------------                                        *
 // Started     : 2003-08-18                                                                        *
-// Last Update : 2015-03-30                                                                        *
-// Copyright   : (C) 2003 by MSWaters                                                              *
+// Last Update : 2018-11-01                                                                        *
+// Copyright   : (C) 2003-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -31,11 +31,9 @@ wxEND_EVENT_TABLE( )
 
 PnlGnuCapAC::PnlGnuCapAC( wxWindow * poWin ) : PnlAnaBase( poWin )
 {
-  bSetAnalysType( eCMD_AC );
-
-  Create( );  // Create the analysis panel
-
-  bClear( );  // Clear all object attributes
+  bSetAnalysType( eCMD_AC );  // Set the analysis panel type
+  Create( );                  // Create the analysis panel
+  bClear( );                  // Clear all object attributes
 }
 
 //**************************************************************************************************
@@ -50,16 +48,23 @@ PnlGnuCapAC::~PnlGnuCapAC( )
 
 void  PnlGnuCapAC::Create( void )
 {
-  PnlAnaBase::CreateBase( );   // Create the base controls
-  PnlAnaBase::CreateScale( );  // Create the scale controls
-  PnlAnaBase::CreateCpxPrt( ); // Create the parameter complex part check boxes
-  PnlAnaBase::CreateSigSrc( ); // Create the input signal source controls
-  PnlAnaBase::CreateTemp( );   // Create the analysis temperature controls
+  PnlAnaBase::CreateBase( );    // Create the base controls
+  PnlAnaBase::CreateScale( );   // Create the scale controls
+  PnlAnaBase::CreateCpxPrt( );  // Create the parameter complex part check boxes
+  PnlAnaBase::CreateTemp( );    // Create the analysis temperature controls
+  PnlAnaBase::CreateSigSrc( );  // Create the input signal source controls
+              CreateSigSrc( );  // Create additional input signal source controls
 
-  PnlAnaBase::DoLayout( );     // Layout the panel's GUI objects
+#ifdef LAYOUT_MNGR
+  PnlAnaBase::DoLayout( );      // Layout the panel's GUI objects
+#endif // LAYOUT_MNGR
 
   // Set the frequency sweep parameter labels
+#ifdef LAYOUT_MNGR
+  bSetSwpParsLbl( wxT("AC Sweep") );
+#else
   m_oSbxSwpPars.SetLabel( wxT(" AC Sweep ") );
+#endif // LAYOUT_MNGR
   m_oPnlStart  .bSetName( wxT("Start Frequency") );
   m_oPnlStop   .bSetName( wxT("Stop Frequency") );
 
@@ -69,6 +74,24 @@ void  PnlGnuCapAC::Create( void )
   m_oPnlStep .bSetUnitsType( eUNITS_FREQ );
 }
 
+//**************************************************************************************************
+// Create the source component display objects.
+
+void  PnlGnuCapAC::CreateSigSrc( void )
+{
+  wxPanel * poPnl;
+
+  poPnl = static_cast< wxPanel * >( m_oChoSrcName.GetParent( ) );
+
+  // Create and add signal source controls
+#ifdef LAYOUT_MNGR
+  m_oPnlSrcLvl.bCreate( poPnl, ID_PNL_SRCLVL, -1, 95, 82 );
+#else
+  m_oSbxSigSrc.SetSize( wxSize( 330, 60 ) );
+  m_oPnlSrcLvl.bCreate( poPnl, ID_PNL_SRCLVL, -1, 95, 82, wxPoint( 142, 200 ) );
+#endif // LAYOUT_MNGR
+}
+
 //**************************************************************************************************
 // Initialize the step scale.
 
@@ -188,7 +211,7 @@ bool  PnlGnuCapAC::bLoad( SimnGnuCap & roSimn )
   if( ! roSimn.m_oCmdAC.bIsValid( ) )                        return( false );
 
   // Set the source component
-  if( ! PnlAnaBase::bSetSrcCpnt( roSimn.m_oCpntSwpSrc ) )    bRtn = false;
+  if( ! PnlAnaBase::bSetSrcCpnt( roSimn.m_oCpntSigSrc ) )    bRtn = false;
 
   // Set the step scale (do this before setting the sweep step)
   if( roSimn.m_oCmdAC.m_eScale != eSCALE_NONE )
@@ -258,8 +281,11 @@ bool  PnlGnuCapAC::bSave( SimnGnuCap & roSimn )
   else
   {
     os1 = m_oChoSrcName.GetStringSelection( );
-    roSimn.m_oCpntSwpSrc = roSimn.NetList::roGetCpnt( os1 );
-    roSimn.m_oCpntSwpSrc.bSetValue( wxT("GENERATOR(1) AC ") + m_oPnlSrcLvl.rosGetValue( ) );
+    roSimn.m_oCpntSigSrc = roSimn.NetList::roGetCpnt( os1 );
+    os1 = wxT("GENERATOR(1) AC ") + m_oPnlSrcLvl.rosGetValue( );
+    if( roSimn.m_oCpntSigSrc.eGetType( ) == eCPNT_IVS ) os1 += wxT('V');
+    if( roSimn.m_oCpntSigSrc.eGetType( ) == eCPNT_ICS ) os1 += wxT('A');
+    roSimn.m_oCpntSigSrc.bSetValue( os1 );
   }
 
   // Store the parameters to derive
@@ -302,7 +328,7 @@ bool  PnlGnuCapAC::bSave( SimnGnuCap & roSimn )
 // Argument List :
 //   roEvtCmd - An object holding information about the event
 
-void  PnlGnuCapAC::OnScale( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  PnlGnuCapAC::OnScale( wxCommandEvent & roEvtCmd )
 {
   InitScale( );
 }
@@ -317,9 +343,6 @@ void  PnlGnuCapAC::OnSrcName( wxCommandEvent & roEvtCmd )
 {
   wxString  os1;
 
-  // Execute the base class event handler first
-  PnlAnaBase::OnSrcName( roEvtCmd );
-
   if( m_oChoSrcName.GetStringSelection( ) != wxT("None") )
   {
     // Set the units type
