@@ -1,11 +1,11 @@
 //**************************************************************************************************
 //                                         PnlGnuCapAC.hpp                                         *
 //                                        -----------------                                        *
-// Description : This class derives from the Analysis Panel base class and provides a GUI for a    *
-//               user to configure a AC Analysis for GNU-Cap electronic circuit simulator.         *
+// Description : This class derives from the PnlAnaBase base class and provides a GUI for the user *
+//               to configure an AC Analysis for GNU-Cap electronic circuit simulation engine.     *
 // Started     : 2003-08-18                                                                        *
-// Last Update : 2015-01-05                                                                        *
-// Copyright   : (C) 2003 by MSWaters                                                              *
+// Last Update : 2018-09-29                                                                        *
+// Copyright   : (C) 2003-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -31,16 +31,17 @@ class PnlGnuCapAC : public PnlAnaBase
 {
   private :
 
-    void  Create( void );
+    void  Create      ( void );
+    void  CreateSigSrc( void ) override;
 
-    void  InitScale( void );
+    void  InitScale( void ) override;
 
   public :
 
-          PnlGnuCapAC( wxWindow * poWin );
-         ~PnlGnuCapAC( );
+    explicit  PnlGnuCapAC( wxWindow * poWin );
+             ~PnlGnuCapAC( );
 
-    bool  bClear( void );
+    bool  bClear( void ) override;
 
     bool  bLoad( SimnGnuCap & roSimn );
     bool  bSave( SimnGnuCap & roSimn );
@@ -50,7 +51,11 @@ class PnlGnuCapAC : public PnlAnaBase
     void  OnSrcName( wxCommandEvent & roEvtCmd );
 
     // Leave this as the last line as private access is envoked by macro
+#if wxCHECK_VERSION( 3,0,0 )
     wxDECLARE_EVENT_TABLE( );
+#else
+    wxDECLARE_EVENT_TABLE( )
+#endif
 };
 
 //**************************************************************************************************
