@@ -1,11 +1,11 @@
 //**************************************************************************************************
 //                                         PnlGnuCapDC.hpp                                         *
 //                                        -----------------                                        *
-// Description : This class derives from the Analysis Panel base class and provides a GUI for a    *
-//                user to configure a DC Analysis for GNU-Cap electronic circuit simulator.        *
-// Started     : 2003-08-18                                                                                  *
-// Last Update : 2015-01-05                                                                        *
-// Copyright   : (C) 2003 by MSWaters                                                              *
+// Description : This class derives from the PnlAnaBase base class and provides a GUI for the user *
+//               to configure a DC Analysis for GNU-Cap electronic circuit simulation engine.      *
+// Started     : 2003-08-18                                                                        *
+// Last Update : 2018-10-06                                                                        *
+// Copyright   : (C) 2003-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -32,20 +32,17 @@ class PnlGnuCapDC : public PnlAnaBase
   private :
 
     // Functions to create the display objects
-    void  Create      ( void );
-    void  CreateSigSrc( void );
-
-    void  DoLayout( void );
+    void  Create( void );
 
     void  InitSwpUnits( void );
-    void  InitScale   ( void );
+    void  InitScale   ( void ) override;
 
   public :
 
-          PnlGnuCapDC( wxWindow * poWin );
-         ~PnlGnuCapDC( );
+    explicit  PnlGnuCapDC( wxWindow * poWin );
+             ~PnlGnuCapDC( );
 
-    bool  bClear( void );
+    bool  bClear( void ) override;
 
     bool  bLoad( SimnGnuCap & roSimn );
     bool  bSave( SimnGnuCap & roSimn );
@@ -55,7 +52,11 @@ class PnlGnuCapDC : public PnlAnaBase
     void  OnSrcName( wxCommandEvent & roEvtCmd );
 
     // Leave this as the last line as private access is envoked by macro
+#if wxCHECK_VERSION( 3,0,0 )
     wxDECLARE_EVENT_TABLE( );
+#else
+    wxDECLARE_EVENT_TABLE( )
+#endif
 };
 
 //**************************************************************************************************
