@@ -2,8 +2,8 @@
 //                                         PnlGnuCapFO.cpp                                         *
 //                                        -----------------                                        *
 // Started     : 2004-04-26                                                                        *
-// Last Update : 2015-03-29                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-10-05                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -28,13 +28,11 @@ wxEND_EVENT_TABLE( )
 //**************************************************************************************************
 // Constructor.
 
-PnlGnuCapFO::PnlGnuCapFO( wxWindow * poWin )
-                        : PnlAnaBase( poWin ), m_oDlgCfgGEN( poWin )
+PnlGnuCapFO::PnlGnuCapFO( wxWindow * poWin ) : PnlAnaBase( poWin ), m_oDlgCfgGEN( poWin )
 {
-  bSetAnalysType( eCMD_FO );
-
-  Create( );  // Create the analysis panel
-  bClear( );  // Clear all object attributes
+  bSetAnalysType( eCMD_FO );  // Set the analysis panel type
+  Create( );                  // Create the analysis panel
+  bClear( );                  // Clear all object attributes
 }
 
 //**************************************************************************************************
@@ -50,15 +48,22 @@ PnlGnuCapFO::~PnlGnuCapFO( )
 void  PnlGnuCapFO::Create( void )
 {
   PnlAnaBase::CreateBase( );     // Create the base controls
-  PnlAnaBase::CreateInitC( );    // Create and add the initial condtns controls
-  PnlAnaBase::CreateTemp( );     // Create and add the analysis temp. controls
-              CreateSigSrc( );   // Create and add generator controls
-              CreateOutputs( );  // Create and add output parameters
+  PnlAnaBase::CreateInitC( );    // Create the initial condtns controls
+  PnlAnaBase::CreateTemp( );     // Create the analysis temp. controls
+  PnlAnaBase::CreateSigSrc( );   // Create the input signal source controls
+              CreateSigSrc( );   // Create the additional input signal source controls
+              CreateOutputs( );  // Create the output parameters
 
+#ifdef LAYOUT_MNGR
   PnlAnaBase::DoLayout( );     // Layout the panel's GUI objects
+#endif // LAYOUT_MNGR
 
   // Set the frequency sweep parameter labels
+#ifdef LAYOUT_MNGR
+  bSetSwpParsLbl( wxT("Frequency Sweep") );
+#else
   m_oSbxSwpPars.SetLabel( wxT(" Frequency Sweep ") );
+#endif // LAYOUT_MNGR
   m_oPnlStart  .bSetName( wxT("Start Frequency") );
   m_oPnlStop   .bSetName( wxT("Stop Frequency") );
   m_oPnlStep   .bSetName( wxT("Step Increment") );
@@ -70,23 +75,45 @@ void  PnlGnuCapFO::Create( void )
 }
 
 //**************************************************************************************************
-// Create the source component display objects.
+// Create the additional source component display objects.
 
 void  PnlGnuCapFO::CreateSigSrc( void )
 {
-  // Create and add generator controls
-  m_oSbxSigSrc .Create( this, ID_UNUSED   , wxT(" Signal Source "),
-                        wxPoint(   6, 178 ), wxSize( 255, 60 ) );
-  m_oChoSrcName.Create( this, ID_CHO_SRCNAME,
-                        wxPoint(  18, 200 ), wxSize( 121, GUI_CTRL_HT ) );
-  m_oBtnSetup  .Create( this, ID_BTN_SETUP, wxT("Setup ..."),
-                        wxPoint( 143, 200 ), wxSize( 105, GUI_CTRL_HT ) );
+  wxPanel * poPnl;
 
-  // Set static box font
-  m_oSbxSigSrc.SetOwnFont( FONT_SLANT );
+  poPnl = static_cast< wxPanel * >( m_oPnlStart.GetParent( ) );
+
+#ifdef LAYOUT_MNGR
+  m_oBtnSetup.Create( poPnl, ID_BTN_SETUP, wxT("Setup ...") );
+#else
+  m_oSbxSigSrc.SetSize( wxSize( 255, 60 ) );
+  m_oBtnSetup.Create( poPnl, ID_BTN_SETUP, wxT("Setup ..."),
+                      wxPoint( 143, 200 ), wxSize( 105, GUI_CTRL_HT ) );
+#endif // LAYOUT_MNGR
 }
 
 //**************************************************************************************************
+// Create the parameters to included in the results file output.
+
+void  PnlGnuCapFO::CreateOutputs( void )
+{
+  // Create and add output parameters
+  m_oSbxOutputs.Create( this, ID_UNUSED,     wxT(" Outputs "),
+                        wxPoint( 455,  5 ), wxSize( 110, 122 ) );
+  m_oCbxMag    .Create( this, ID_CBX_MAG,    wxT("Magnitude"),
+                        wxPoint( 461, 24 ) );
+  m_oCbxPhase  .Create( this, ID_CBX_PHASE,  wxT("Phase"),
+                        wxPoint( 461, 49 ) );
+  m_oCbxMagDb  .Create( this, ID_CBX_MAGDB,  wxT("Mag. in dB"),
+                        wxPoint( 461, 74 ) );
+  m_oCbxMagRel .Create( this, ID_CBX_MAGREL, wxT("Mag. is Rel."),
+                        wxPoint( 461, 99 ) );
+
+  m_oSbxOutputs.SetOwnFont( FONT_SLANT );
+}
+
+//**************************************************************************************************
+// ???
 
 void  PnlGnuCapFO::GetConfig( void )
 {
@@ -113,6 +140,7 @@ void  PnlGnuCapFO::GetConfig( void )
 }
 
 //**************************************************************************************************
+// ???
 
 void  PnlGnuCapFO::SetConfig( void )
 {
@@ -129,26 +157,6 @@ void  PnlGnuCapFO::SetConfig( void )
   poConfig->Write( wxT("FO_MagDB") , m_oCbxMagDb .GetValue( ) );
 }
 
-//**************************************************************************************************
-// Create the parameters to included in the results file output.
-
-void  PnlGnuCapFO::CreateOutputs( void )
-{
-  // Create and add output parameters
-  m_oSbxOutputs.Create( this, ID_UNUSED,     wxT(" Outputs "),
-                        wxPoint( 455,  5 ), wxSize( 110, 122 ) );
-  m_oCbxMag    .Create( this, ID_CBX_MAG,    wxT("Magnitude"),
-                        wxPoint( 461, 24 ) );
-  m_oCbxPhase  .Create( this, ID_CBX_PHASE,  wxT("Phase"),
-                        wxPoint( 461, 49 ) );
-  m_oCbxMagDb  .Create( this, ID_CBX_MAGDB,  wxT("Mag. in dB"),
-                        wxPoint( 461, 74 ) );
-  m_oCbxMagRel .Create( this, ID_CBX_MAGREL, wxT("Mag. is Rel."),
-                        wxPoint( 461, 99 ) );
-
-  m_oSbxOutputs.SetOwnFont( FONT_SLANT );
-}
-
 //**************************************************************************************************
 // Clear the object attributes.
 //
@@ -219,7 +227,7 @@ bool  PnlGnuCapFO::bLoad( SimnGnuCap & roSimn )
   if( ! roSimn.m_oCmdFO.bIsValid( ) )                        return( false );
 
   // Set the sweep source (a sweep source is not mandatory for a FO analysis)
-  PnlAnaBase::bSetSrcCpnt( roSimn.m_oCpntSwpSrc );
+  PnlAnaBase::bSetSrcCpnt( roSimn.m_oCpntSigSrc );
 
   // Set the sweep values
   if( ! m_oPnlStart.bSetValue( roSimn.m_oCmdFO.m_osStart ) ) bRtn = false;
@@ -280,8 +288,8 @@ bool  PnlGnuCapFO::bSave( SimnGnuCap & roSimn )
   {
     // Get the unmodified signal source component, set it as the signal source
     os1 = m_oChoSrcName.GetStringSelection( );
-    (Component &) roSimn.m_oCpntSwpSrc = roSimn.roGetCpnt( os1 );
-    roSimn.m_oCpntSwpSrc.bSetValue( wxT("GENERATOR(1)") );
+    (Component &) roSimn.m_oCpntSigSrc = roSimn.roGetCpnt( os1 );
+    roSimn.m_oCpntSigSrc.bSetValue( wxT("GENERATOR(1)") );
     // Get the GENERATOR command from the Generator Setup dialog
     m_oDlgCfgGEN.bGetValues( roSimn.m_oCmdGEN );
     if( ! roSimn.m_oCmdGEN.bIsValid( ) )
@@ -293,7 +301,7 @@ bool  PnlGnuCapFO::bSave( SimnGnuCap & roSimn )
   }
   else
   {
-    roSimn.m_oCpntSwpSrc.bClear( );
+    roSimn.m_oCpntSigSrc.bClear( );
     roSimn.m_oCmdGEN    .bSetDefaults( );
   }
 
@@ -331,7 +339,7 @@ bool  PnlGnuCapFO::bSave( SimnGnuCap & roSimn )
 // Argument List :
 //   roEvtCmd - An object holding information about the event
 
-void  PnlGnuCapFO::OnBtnSetup( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  PnlGnuCapFO::OnBtnSetup( wxCommandEvent & roEvtCmd )
 {
   m_oDlgCfgGEN.CenterOnParent( );
   m_oDlgCfgGEN.ShowModal( );
