@@ -1,12 +1,12 @@
 //**************************************************************************************************
 //                                         PnlGnuCapOP.hpp                                         *
 //                                        -----------------                                        *
-// Description : This class derives from the Analysis Panel base class and provides a GUI for a    *
-//               user to configure a Operating Point Analysis for GNU-Cap electronic circuit       *
-//               simulator.                                                                        *
+// Description : This class derives from the PnlAnaBase base class and provides a GUI for the user *
+//               to configure an Operating Point Analysis for GNU-Cap electronic circuit           *
+//               simulation engine.                                                                *
 // Started     : 2003-11-06                                                                        *
-// Last Update : 2015-01-05                                                                        *
-// Copyright   : (C) 2003 by MSWaters                                                              *
+// Last Update : 2018-10-03                                                                        *
+// Copyright   : (C) 2003-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -32,16 +32,17 @@ class PnlGnuCapOP : public PnlAnaBase
 {
   private :
 
-    void  Create( void );
+    void  Create      ( void );
+    void  CreateSigSrc( void ) override;
 
-    void  InitScale( void );
+    void  InitScale( void ) override;
 
   public :
 
-          PnlGnuCapOP( wxWindow * poWin );
-         ~PnlGnuCapOP( );
+    explicit  PnlGnuCapOP( wxWindow * poWin );
+             ~PnlGnuCapOP( );
 
-    bool  bClear( void );
+    bool  bClear( void ) override;
 
     bool  bLoad( SimnGnuCap & roSimn );
     bool  bSave( SimnGnuCap & roSimn );
@@ -51,7 +52,11 @@ class PnlGnuCapOP : public PnlAnaBase
     void  OnSrcName( wxCommandEvent & roEvtCmd );
 
     // Leave this as the last line as private access is envoked by macro
+#if wxCHECK_VERSION( 3,0,0 )
     wxDECLARE_EVENT_TABLE( );
+#else
+    wxDECLARE_EVENT_TABLE( )
+#endif
 };
 
 //**************************************************************************************************
