@@ -2,8 +2,8 @@
 //                                         PnlGnuCapTR.cpp                                         *
 //                                        -----------------                                        *
 // Started     : 2004-02-22                                                                        *
-// Last Update : 2015-03-29                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-10-20                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -28,13 +28,11 @@ wxEND_EVENT_TABLE( )
 //**************************************************************************************************
 // Constructor.
 
-PnlGnuCapTR::PnlGnuCapTR( wxWindow * poWin )
-                        : PnlAnaBase( poWin ), m_oDlgCfgGEN( poWin )
+PnlGnuCapTR::PnlGnuCapTR( wxWindow * poWin ) : PnlAnaBase( poWin ), m_oDlgCfgGEN( poWin )
 {
-  bSetAnalysType( eCMD_TR );
-
-  Create( );  // Create the analysis panel
-  bClear( );  // Clear all object attributes
+  bSetAnalysType( eCMD_TR );  // Set the analysis panel type
+  Create( );                  // Create the analysis panel
+  bClear( );                  // Clear all object attributes
 }
 
 //**************************************************************************************************
@@ -50,14 +48,27 @@ PnlGnuCapTR::~PnlGnuCapTR( )
 void  PnlGnuCapTR::Create( void )
 {
   PnlAnaBase::CreateBase( );    // Create the base controls
-  PnlAnaBase::CreateInitC( );   // Create and add the initial condtns controls
-  PnlAnaBase::CreateTemp( );    // Create and add the analysis temp. controls
-              CreateSigSrc( );  // Create and add generator controls
+  PnlAnaBase::CreateInitC( );   // Create the initial conditions controls
+  PnlAnaBase::CreateTemp( );    // Create the analysis temperature controls
+  PnlAnaBase::CreateSigSrc( );  // Create the input signal source controls
+              CreateSigSrc( );  // Create the additional input signal source controls
 
+#ifdef LAYOUT_MNGR
   PnlAnaBase::DoLayout( );      // Layout the panel's GUI objects
+#endif // LAYOUT_MNGR
+
+  // The following block of code is required to circumvent a bug in wxWidgets. All declared wxChoice
+  // controls attempt a clear( ) operation in their destructor whether or not thay have actually
+  // been created. Causes a null pointer warning. ??? 2018-10-20
+  m_oPnlSrcLvl.bCreate( m_oChoSrcName.GetParent( ), ID_PNL_SRCLVL, -1, 95, 82 );
+  m_oPnlSrcLvl.Hide( );
 
   // Set the time sweep parameter labels
+#ifdef LAYOUT_MNGR
+  bSetSwpParsLbl( wxT("Time Sweep") );
+#else
   m_oSbxSwpPars.SetLabel( wxT(" Time Sweep ") );
+#endif // LAYOUT_MNGR
   m_oPnlStart  .bSetName( wxT("Start Time") );
   m_oPnlStop   .bSetName( wxT("Stop Time") );
   m_oPnlStep   .bSetName( wxT("Step Increment") );
@@ -73,16 +84,19 @@ void  PnlGnuCapTR::Create( void )
 
 void  PnlGnuCapTR::CreateSigSrc( void )
 {
-  // Create and add generator controls
-  m_oSbxSigSrc .Create( this, ID_UNUSED   , wxT(" Signal Source "),
-                        wxPoint(   6, 178 ), wxSize( 255, 60 ) );
-  m_oChoSrcName.Create( this, ID_CHO_SRCNAME,
-                        wxPoint(  18, 200 ), wxSize( 121, GUI_CTRL_HT ) );
-  m_oBtnSetup  .Create( this, ID_BTN_SETUP, wxT("Setup ..."),
-                        wxPoint( 143, 200 ), wxSize( 105, GUI_CTRL_HT ) );
+  wxPanel * poPnl;
 
-  // Set static box font
-  m_oSbxSigSrc.SetOwnFont( FONT_SLANT );
+  poPnl = static_cast< wxPanel * >( m_oChoSrcName.GetParent( ) );
+
+  // Create and add generator controls
+#ifdef LAYOUT_MNGR
+  m_oBtnSetup.Create( poPnl, ID_BTN_SETUP, wxT("Setup ...") );
+  m_oBtnSetup.SetMinSize( wxSize( 105, GUI_CTRL_HT ) );
+#else
+  m_oSbxSigSrc.SetSize( wxSize( 255, 60 ) );
+  m_oBtnSetup.Create( poPnl, ID_BTN_SETUP, wxT("Setup ..."),
+                      wxPoint( 143, 200 ), wxSize( 105, GUI_CTRL_HT ) );
+#endif // LAYOUT_MNGR
 }
 
 //**************************************************************************************************
@@ -149,7 +163,7 @@ bool  PnlGnuCapTR::bLoad( SimnGnuCap & roSimn )
   if( ! roSimn.m_oCmdTR.bIsValid( ) )                        return( false );
 
   // Set the sweep source (a sweep source is not mandatory for a TR analysis)
-  PnlAnaBase::bSetSrcCpnt( roSimn.m_oCpntSwpSrc );
+  PnlAnaBase::bSetSrcCpnt( roSimn.m_oCpntSigSrc );
 
   // Set the sweep values
   if( ! m_oPnlStart.bSetValue( roSimn.m_oCmdTR.m_osStart ) ) bRtn = false;
@@ -207,8 +221,8 @@ bool  PnlGnuCapTR::bSave( SimnGnuCap & roSimn )
   {
     // Get the unmodified signal source component, set it as the signal source
     os1 = m_oChoSrcName.GetStringSelection( );
-    (Component &) roSimn.m_oCpntSwpSrc = roSimn.roGetCpnt( os1 );
-    roSimn.m_oCpntSwpSrc.bSetValue( wxT("GENERATOR(1)") );
+    (Component &) roSimn.m_oCpntSigSrc = roSimn.roGetCpnt( os1 );
+    roSimn.m_oCpntSigSrc.bSetValue( wxT("GENERATOR(1)") );
     // Get the GENERATOR command from the Generator Setup dialog
     m_oDlgCfgGEN.bGetValues( roSimn.m_oCmdGEN );
     if( ! roSimn.m_oCmdGEN.bIsValid( ) )
@@ -220,7 +234,7 @@ bool  PnlGnuCapTR::bSave( SimnGnuCap & roSimn )
   }
   else
   {
-    roSimn.m_oCpntSwpSrc.bClear( );
+    roSimn.m_oCpntSigSrc.bClear( );
     roSimn.m_oCmdGEN    .bSetDefaults( );
   }
 
@@ -254,10 +268,11 @@ bool  PnlGnuCapTR::bSave( SimnGnuCap & roSimn )
 // Argument List :
 //   roEvtCmd - An object holding information about the event
 
-void  PnlGnuCapTR::OnBtnSetup( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  PnlGnuCapTR::OnBtnSetup( wxCommandEvent & roEvtCmd )
 {
+  // Display the signal source setup dialogue
   m_oDlgCfgGEN.CenterOnParent( );
-  m_oDlgCfgGEN.ShowModal( );
+  if( m_oDlgCfgGEN.ShowModal( ) != wxID_OK ) return;
 }
 
 //**************************************************************************************************
