@@ -2,8 +2,8 @@
 //                                          DlgPrefs.cpp                                           *
 //                                         --------------                                          *
 // Started     : 2006-10-17                                                                        *
-// Last Update : 2015-03-23                                                                        *
-// Copyright   : (C) 2006 by MSWaters                                                              *
+// Last Update : 2018-11-14                                                                        *
+// Copyright   : (C) 2006-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -29,16 +29,13 @@ wxEND_EVENT_TABLE( )
 //**************************************************************************************************
 // Constructor.
 //
-// Argument List:
+// Argument List :
 //   poWin - A pointer to the dialog parent window
 
 DlgPrefs::DlgPrefs( wxWindow * poWin ) :
                     wxDialog( poWin, -1, wxT(""), wxDefaultPosition, wxDefaultSize,
                               wxDEFAULT_DIALOG_STYLE, wxDialogNameStr )
 {
-  // Get the global configuration object
-  m_poCfg = (wxConfig *) wxConfig::Get( );
-
   // Construct the display objects
   Initialize( );
 
@@ -76,7 +73,7 @@ void  DlgPrefs::Create( void )
   wxPanel * poPnlPrefs, * poPnlBtns;
 //  wxPanel * poPnlLHS, * poPnlRHS;
   wxSize    oSizeCbx;
-  int       iWdName=145, iWdValue=130;
+  int       iWdName=170, iWdValue=130;
 
   // Create the various underlying panel objects
   poPnlPrefs = new wxPanel( this );
@@ -85,10 +82,16 @@ void  DlgPrefs::Create( void )
   poPnlBtns  = new wxPanel( this );
 
   // Create the waveform viewer choice control
-  m_oChoViewerUtil.bCreate( poPnlPrefs, ID_CHO_VIEWERUTIL, iWdName, iWdValue );
-  m_oChoViewerUtil.m_oLblName.SetLabel( wxT("Waveform viewer") );
-  m_oChoViewerUtil.m_oChoice.Append( CLP_GAW   );
-  m_oChoViewerUtil.m_oChoice.Append( CLP_GWAVE );
+  m_oChoEdaSuite.bCreate( poPnlPrefs, ID_CHO_EDASUITE    , iWdName, iWdValue );
+  m_oChoEdaSuite.m_oLblName.SetLabel( wxT("EDA Tool Suite") );
+  m_oChoEdaSuite.m_oChoice.Append( rosEnumEdaToStr( eEDA_LEPTON ) );
+  m_oChoEdaSuite.m_oChoice.Append( rosEnumEdaToStr( eEDA_GEDA   ) );
+
+  // Create the waveform viewer choice control
+  m_oChoDataViewer.bCreate( poPnlPrefs, ID_CHO_DATAVIEWER, iWdName, iWdValue );
+  m_oChoDataViewer.m_oLblName.SetLabel( wxT("Waveform data viewer") );
+  m_oChoDataViewer.m_oChoice.Append( rosEnumVwrToStr( eVIEW_GAW   ) );
+  m_oChoDataViewer.m_oChoice.Append( rosEnumVwrToStr( eVIEW_GWAVE ) );
 
   // Create the temporary file management strategy choice control
   m_oChoTmpFileMgt.bCreate( poPnlPrefs, ID_CHO_TMPFILEMGT, iWdName, iWdValue );
@@ -104,10 +107,10 @@ void  DlgPrefs::Create( void )
   m_oChoFrmLayout.m_oChoice.Append( wxT("Wide Console") );
 
   // Create the phase / angle units choice control
-  m_oChoUnitsPhase.bCreate( poPnlPrefs, ID_CHO_PHASEUNITS, iWdName, iWdValue );
-  m_oChoUnitsPhase.m_oLblName.SetLabel( wxT("Phase / angle units") );
-  m_oChoUnitsPhase.m_oChoice.Append( wxT("Degrees") );
-  m_oChoUnitsPhase.m_oChoice.Append( wxT("Radians") );
+  m_oChoPhaseUnits.bCreate( poPnlPrefs, ID_CHO_PHASEUNITS, iWdName, iWdValue );
+  m_oChoPhaseUnits.m_oLblName.SetLabel( wxT("Phase / angle units") );
+  m_oChoPhaseUnits.m_oChoice.Append( wxT("Degrees") );
+  m_oChoPhaseUnits.m_oChoice.Append( wxT("Radians") );
 
   // Create the results precision choice control
   m_oChoPrecision.bCreate( poPnlPrefs, ID_CHO_PRECISION  , iWdName, iWdValue );
@@ -119,7 +122,13 @@ void  DlgPrefs::Create( void )
   m_oChoPrecision.m_oChoice.Append( wxT("%7.5E") );
   m_oChoPrecision.m_oChoice.Append( wxT("%8.6E") );
 
-  // Create the PnlValue controls
+  // Create the Guile procedure choice control
+  m_oChoGuileProc.bCreate( poPnlPrefs, ID_CHO_GUILEPROC  , iWdName, iWdValue );
+  m_oChoGuileProc.m_oLblName.SetLabel( wxT("gnetlist Guile backend") );
+  m_oChoGuileProc.m_oChoice.Append( PrcGNetList::roasGetGuileProcs( ) );
+  m_oChoGuileProc.m_oChoice.Delete( 0 ); // The first item is an empty string
+
+  // Create the wxNotebook maximum line PnlValue control
   m_oPnlNbkMaxLns.bCreate( poPnlPrefs, ID_VAL_NBKMAXLNS  , iWdName, iWdValue-45, 45,
                            wxDefaultPosition, PnlValue::eSHOW_LBL );
   m_oPnlNbkMaxLns.bSetName( wxT("Max text control size") );
@@ -129,8 +138,8 @@ void  DlgPrefs::Create( void )
   m_oPnlNbkMaxLns.bSetSpnIncSz( 10, 10000 );
   m_oPnlNbkMaxLns.bSetUnits( wxT("Lines") );
 
-  // Create the PnlValue controls
-  m_oPnlSpnPeriod.bCreate( poPnlPrefs, ID_VAL_SPINPERIOD, iWdName, iWdValue-45, 45,
+  // Create the spin control period PnlValue control
+  m_oPnlSpnPeriod.bCreate( poPnlPrefs, ID_VAL_SPINPERIOD , iWdName, iWdValue-45, 45,
                            wxDefaultPosition, PnlValue::eSHOW_LBL );
   m_oPnlSpnPeriod.bSetName( wxT("Spin control period") );
   m_oPnlSpnPeriod.bSetValueType( eVALUE_INT );
@@ -139,23 +148,60 @@ void  DlgPrefs::Create( void )
   m_oPnlSpnPeriod.bSetSpnIncSz( 1, 10 );
   m_oPnlSpnPeriod.bSetUnits( wxT("mSec") );
 
+  // Create the spin control period PnlValue control
+  m_oPnlToolTipDly.bCreate( poPnlPrefs, ID_VAL_TOOLTIPDLY, iWdName, iWdValue-45, 45,
+                            wxDefaultPosition, PnlValue::eSHOW_LBL );
+  m_oPnlToolTipDly.bSetName( wxT("Tool tip delay") );
+  m_oPnlToolTipDly.bSetValueType( eVALUE_INT );
+  m_oPnlToolTipDly.bSetDefValue( CFG_DEF_TOOLTIPDLY );
+  m_oPnlToolTipDly.bSetSpnRange( 0, 2000 );
+  m_oPnlToolTipDly.bSetSpnIncSz( 100, 100 );
+  m_oPnlToolTipDly.bSetUnits( wxT("mSec") );
+
   // Set height of check box controls according to size of PnlValue object
   oSizeCbx = m_oPnlNbkMaxLns.GetSize( );
   oSizeCbx.SetWidth( 250 );
 
-  // Create the synchronize sweep sources check box
-  m_oCbxSyncSwpSrcs.Create( poPnlPrefs, ID_CBX_SYNCSWPSRCS, wxT("Sync sweep sources \t   "),
-                            wxDefaultPosition, oSizeCbx, wxALIGN_RIGHT );
-
   // Create the tool tips check box
 #if wxCHECK_VERSION( 3,0,0 )
-  m_oCbxToolTips.Create( poPnlPrefs, ID_CBX_TOOLTIPS,       wxT("Show tool tips \t\t   ")  ,
-                         wxDefaultPosition, oSizeCbx, wxALIGN_RIGHT );
+  m_oCbxToolTips   .Create( poPnlPrefs, ID_CBX_TOOLTIPS   , wxT("Show tool tips \t\t\t"),
+                            wxDefaultPosition, oSizeCbx   , wxALIGN_RIGHT );
 #else
-  m_oCbxToolTips.Create( poPnlPrefs, ID_CBX_TOOLTIPS,       wxT("Show tool tips \t\t\t   ")  ,
-                         wxDefaultPosition, oSizeCbx, wxALIGN_RIGHT );
+  m_oCbxToolTips   .Create( poPnlPrefs, ID_CBX_TOOLTIPS   , wxT("Show tool tips \t\t\t\t"),
+                            wxDefaultPosition, oSizeCbx   , wxALIGN_RIGHT );
 #endif
 
+  // Create the synchronize sweep sources check box
+  m_oCbxSyncSigSrcs.Create( poPnlPrefs, ID_CBX_SYNCSIGSRCS, wxT("Sync. signal sources \t\t"),
+                            wxDefaultPosition, oSizeCbx, wxALIGN_RIGHT );
+
+  m_oCbxSyncTemps  .Create( poPnlPrefs, ID_CBX_SYNCTEMPS  , wxT("Sync. temperatures \t\t"),
+                            wxDefaultPosition, oSizeCbx, wxALIGN_RIGHT );
+
+  // Create the synchronize sweep sources check box
+  m_oCbxKeepNetLst .Create( poPnlPrefs, ID_CBX_KEEPNETLST , wxT("Keep the netlist file \t\t"),
+                            wxDefaultPosition, oSizeCbx, wxALIGN_RIGHT );
+
+  // Create the include model files check box
+  m_oCbxVerboseMode.Create( poPnlPrefs, ID_CBX_VERBOSEMODE, wxT("gnetlist verbose mode \t\t"),
+                            wxDefaultPosition, oSizeCbx, wxALIGN_RIGHT );
+
+  // Create the include model files check box
+  m_oCbxIncludeMode.Create( poPnlPrefs, ID_CBX_INCLUDEMODE, wxT("Include model defs. \t\t"),
+                            wxDefaultPosition, oSizeCbx, wxALIGN_RIGHT );
+
+  // Create the include model files check box
+  m_oCbxEmbedMode  .Create( poPnlPrefs, ID_CBX_EMBEDMODE  , wxT("Embed include files \t\t"),
+                            wxDefaultPosition, oSizeCbx, wxALIGN_RIGHT );
+
+  // Create the include model files check box
+  m_oCbxNoMungeMode.Create( poPnlPrefs, ID_CBX_NOMUNGEMODE, wxT("Fix component prefixes \t\t"),
+                            wxDefaultPosition, oSizeCbx, wxALIGN_RIGHT );
+
+  // Create the automatic reload of schematic file/s check box
+  m_oCbxAutoRegen  .Create( poPnlPrefs, ID_CBX_AUTOREGEN  , wxT("Auto. regenerate netlist \t"),
+                            wxDefaultPosition, oSizeCbx, wxALIGN_RIGHT );
+
   // Create the application path text controls
 //  m_oTxtGschem .bCreate( poPnlRight, ID_TXT_GSCHEM , 80, 250 );
 //  m_oTxtGnetlst.bCreate( poPnlRight, ID_TXT_GNETLST, 80, 250 );
@@ -182,23 +228,33 @@ void  DlgPrefs::Create( void )
 
 void  DlgPrefs::ToolTips( void )
 {
-  m_oChoViewerUtil .SetToolTip( wxT("Select the waveform viewing utility") );
-  m_oChoTmpFileMgt .SetToolTip( wxT("The temporary file management strategy to be used") );
-  m_oChoFrmLayout  .SetToolTip( wxT("The main frame layout to be used") );
-  m_oChoUnitsPhase .SetToolTip( wxT("The phase / angle units to be used") );
-  m_oChoPrecision  .SetToolTip( wxT("Select the precision of the analysis results") );
-  m_oPnlNbkMaxLns  .SetToolTip( wxT("The maximum number of lines that can be displayed in a text control") );
-  m_oPnlSpnPeriod  .SetToolTip( wxT("The period between successive spin button control updates") );
-  m_oCbxSyncSwpSrcs.SetToolTip( wxT("Enable or disable synchronization of sweep sources") );
-  m_oCbxToolTips   .SetToolTip( wxT("Enable or disable tool tips") );
+  m_oChoEdaSuite   .SetToolTip( wxT(" The EDA Tool Suite ") );
+  m_oChoDataViewer .SetToolTip( wxT(" The waveform data viewing utility ") );
+  m_oChoTmpFileMgt .SetToolTip( wxT(" The temporary file management strategy ") );
+  m_oChoFrmLayout  .SetToolTip( wxT(" The main frame layout ") );
+  m_oChoPhaseUnits .SetToolTip( wxT(" The phase / angle units ") );
+  m_oChoPrecision  .SetToolTip( wxT(" The precision of the analysis results ") );
+  m_oChoGuileProc  .SetToolTip( wxT(" The gnetlist Guile procedure for backend processing ") );
+  m_oPnlNbkMaxLns  .SetToolTip( wxT(" The maximum number of lines that can be displayed in a text control ") );
+  m_oPnlSpnPeriod  .SetToolTip( wxT(" The period between successive spin button control updates ") );
+  m_oPnlToolTipDly .SetToolTip( wxT(" The delay before a tool tip is displayed ") );
+  m_oCbxToolTips   .SetToolTip( wxT(" Enable tool tips ") );
+  m_oCbxSyncSigSrcs.SetToolTip( wxT(" Synchronize signal sources between analysis pages " ) );
+  m_oCbxSyncTemps  .SetToolTip( wxT(" Synchronize temperature values between analysis pages ") );
+  m_oCbxKeepNetLst .SetToolTip( wxT(" Exclude the netlist file from the list of temporary files (which may be deleted) ") );
+  m_oCbxVerboseMode.SetToolTip( wxT(" Enable gnetlist verbose mode ") );
+  m_oCbxIncludeMode.SetToolTip( wxT(" Include model file contents in netlist file (gnetlist include_mode) ") );
+  m_oCbxEmbedMode  .SetToolTip( wxT(" Embed file contents in netlist file when .INCLUDE encountered (gnetlist embedd_mode) ") );
+  m_oCbxNoMungeMode.SetToolTip( wxT(" Automatically test and fix incorrect component label prefixes (gnetlist nomunge_mode) ") );
+  m_oCbxAutoRegen  .SetToolTip( wxT(" Automatically regenerate the netlist file if the schematic file/s are newer ") );
 
-//m_oTxtGschem     .SetToolTip( wxT("The path to the binary for gschem (schematic capture application)") );
-//m_oTxtGnetlst    .SetToolTip( wxT("The path to the binary for gnetlist (schematic to netlist converter)") );
-//m_oTxtNgspice    .SetToolTip( wxT("The path to the binary for NG-Spice (simulation engine)") );
-//m_oTxtGnucap     .SetToolTip( wxT("The path to the binary for GNU-Cap (simulation engine)") );
-//m_oTxtGaw        .SetToolTip( wxT("The path to the binary for Gaw (waveform viewer)") );
-//m_oTxtGwave      .SetToolTip( wxT("The path to the binary for Gwave (waveform viewer)") );
-//m_oTxtCalc       .SetToolTip( wxT("The path to the binary for the calculator utility") );
+//m_oTxtGschem     .SetToolTip( wxT(" The path to the binary for gschem (schematic capture application) ") );
+//m_oTxtGnetlst    .SetToolTip( wxT(" The path to the binary for gnetlist (schematic to netlist converter) ") );
+//m_oTxtNgspice    .SetToolTip( wxT(" The path to the binary for NG-Spice (simulation engine) ") );
+//m_oTxtGnucap     .SetToolTip( wxT(" The path to the binary for GNU-Cap (simulation engine) ") );
+//m_oTxtGaw        .SetToolTip( wxT(" The path to the binary for Gaw (waveform viewer) ") );
+//m_oTxtGwave      .SetToolTip( wxT(" The path to the binary for Gwave (waveform viewer) ") );
+//m_oTxtCalc       .SetToolTip( wxT(" The path to the binary for the calculator utility ") );
 }
 
 //**************************************************************************************************
@@ -228,18 +284,28 @@ void  DlgPrefs::DoLayout( void )
   // Layout the preferences controls
   oFlags.Align( wxALIGN_LEFT );
   oFlags.Border( wxLEFT | wxRIGHT | wxTOP, 10 );
-  poSzrPrefs->Add( &m_oChoViewerUtil , oFlags );
-  oFlags.Border( wxLEFT                  , 10 );
+  poSzrPrefs->Add( &m_oChoEdaSuite   , oFlags );
+  oFlags.Border( wxLEFT              ,     10 );
+  poSzrPrefs->Add( &m_oChoDataViewer , oFlags );
   poSzrPrefs->Add( &m_oChoTmpFileMgt , oFlags );
   poSzrPrefs->Add( &m_oChoFrmLayout  , oFlags );
-  poSzrPrefs->Add( &m_oChoUnitsPhase , oFlags );
+  poSzrPrefs->Add( &m_oChoPhaseUnits , oFlags );
   poSzrPrefs->Add( &m_oChoPrecision  , oFlags );
+  poSzrPrefs->Add( &m_oChoGuileProc  , oFlags );
   poSzrPrefs->Add( &m_oPnlNbkMaxLns  , oFlags );
   poSzrPrefs->Add( &m_oPnlSpnPeriod  , oFlags );
-  oFlags.Border( wxLEFT                  ,  7 );
-  poSzrPrefs->Add( &m_oCbxSyncSwpSrcs, oFlags );
-  oFlags.Border( wxLEFT | wxBOTTOM       ,  7 );
+  poSzrPrefs->Add( &m_oPnlToolTipDly , oFlags );
+  oFlags.Border( wxLEFT              ,      7 );
   poSzrPrefs->Add( &m_oCbxToolTips   , oFlags );
+  poSzrPrefs->Add( &m_oCbxSyncSigSrcs, oFlags );
+  poSzrPrefs->Add( &m_oCbxSyncTemps  , oFlags );
+  poSzrPrefs->Add( &m_oCbxKeepNetLst , oFlags );
+  poSzrPrefs->Add( &m_oCbxVerboseMode, oFlags );
+  poSzrPrefs->Add( &m_oCbxIncludeMode, oFlags );
+  poSzrPrefs->Add( &m_oCbxEmbedMode  , oFlags );
+  poSzrPrefs->Add( &m_oCbxNoMungeMode, oFlags );
+  oFlags.Border( wxLEFT | wxBOTTOM   ,      7 );
+  poSzrPrefs->Add( &m_oCbxAutoRegen  , oFlags );
 
   // Layout the buttons
   oFlags.Border( wxTOP | wxBOTTOM, 10 );
@@ -267,53 +333,29 @@ void  DlgPrefs::DoLayout( void )
 
 void  DlgPrefs::Load( void )
 {
-  wxString  os1;
-  long      li1;
-
   SetEvtHandlerEnabled( false );
 
-  m_poCfg->SetPath( wxT("/Viewer") );
+  m_oChoEdaSuite   .m_oChoice.SetSelection( (int) g_oConfig.eGetEdaSuite   ( )     );
+  m_oChoDataViewer .m_oChoice.SetSelection( (int) g_oConfig.eGetDataViewer ( )     );
+  m_oChoTmpFileMgt .m_oChoice.SetSelection( (int) g_oConfig.eGetTmpFileMgt ( )     );
+  m_oChoFrmLayout  .m_oChoice.SetSelection( (int) g_oConfig.uiGetFrmLayout ( )     );
+  m_oChoPhaseUnits .m_oChoice.SetSelection( (int) g_oConfig.eGetPhaseUnits ( )     );
+  m_oChoPrecision  .m_oChoice.SetSelection( (int) g_oConfig.uiGetPrecision ( ) - 1 );
+  m_oChoGuileProc  .m_oChoice.SetStringSelection( g_oConfig.rosGetGuileProc( )     );
 
-  m_poCfg->Read( wxT("Name"),        &os1, CLP_GWAVE );
-  for( li1=0; (uint)li1<m_oChoViewerUtil.m_oChoice.GetCount( ); li1++ )
-  {
-    if( m_oChoViewerUtil.m_oChoice.GetString( (uint) li1 ) == os1 )
-    {
-      m_oChoViewerUtil.m_oChoice.SetSelection( (uint) li1 );
-      break;
-    }
-  }
+  m_oPnlNbkMaxLns  .bSetValue( (long)   g_oConfig.uiGetNbkMaxLns ( ) );
+  m_oPnlSpnPeriod  .bSetValue( (double) g_oConfig.uiGetSpnPeriod ( ), -3 );
+  m_oPnlToolTipDly .bSetValue( (double) g_oConfig.uiGetToolTipDly( ), -3 );
 
-  m_poCfg->SetPath( wxT("/Main") );
-
-  m_poCfg->Read( wxT("TmpFileMgt")   , &li1, eTFM_DELETE );
-  m_oChoTmpFileMgt .m_oChoice.SetSelection( li1 );
-
-  m_poCfg->Read( wxT("MainFrmLayout"), &li1, 0 );
-  m_oChoFrmLayout  .m_oChoice.SetSelection( li1 );
-
-  m_poCfg->Read( wxT("Precision")    , &li1, CNVT_DEF_FLT_RES );
-  m_oChoPrecision  .m_oChoice.SetSelection( li1-1 );
-
-  m_poCfg->Read( wxT("NbkMaxLns")    , &li1, TXT_LNSDEF );
-  m_oPnlNbkMaxLns  .bSetValue( li1 );
-
-  m_poCfg->Read( wxT("SpnPeriod")    , &li1, SPN_PERIOD_DEF );
-  m_oPnlSpnPeriod  .bSetValue( double( li1 ), -3 );
-
-  m_poCfg->Read( wxT("ToolTips")     , &li1, 0 );
-  m_oCbxToolTips   .SetValue( li1 != 0 ? true : false );
-
-//  m_poCfg->Read( wxT("TipDelay")    , &li1, 0 ); // ??? MSW 2015-03-23
-//  m_oPnlTipDelay   .bSetValue( li1 );
-
-  m_poCfg->SetPath( wxT("/Simulator") );
-
-  m_poCfg->Read( wxT("PhaseUnits")   , &li1, 0 );
-  m_oChoUnitsPhase .m_oChoice.SetSelection( li1 );
-
-  m_poCfg->Read( wxT("SyncSwpSrcs")  , &li1, 0 );
-  m_oCbxSyncSwpSrcs.SetValue( li1 != 0 ? true : false );
+  m_oCbxToolTips   .SetValue(   g_oConfig.bGetToolTips   ( ) );
+  m_oCbxSyncSigSrcs.SetValue(   g_oConfig.bGetSyncSigSrcs( ) );
+  m_oCbxSyncTemps  .SetValue(   g_oConfig.bGetSyncTemps  ( ) );
+  m_oCbxKeepNetLst .SetValue(   g_oConfig.bGetKeepNetLst ( ) );
+  m_oCbxVerboseMode.SetValue(   g_oConfig.bGetVerboseMode( ) );
+  m_oCbxIncludeMode.SetValue(   g_oConfig.bGetIncludeMode( ) );
+  m_oCbxEmbedMode  .SetValue(   g_oConfig.bGetEmbedMode  ( ) );
+  m_oCbxNoMungeMode.SetValue( ! g_oConfig.bGetNoMungeMode( ) );
+  m_oCbxAutoRegen  .SetValue(   g_oConfig.bGetAutoRegen  ( ) );
 
   SetEvtHandlerEnabled( true );
 }
@@ -325,26 +367,29 @@ void  DlgPrefs::Save( void )
 {
   SetEvtHandlerEnabled( false );
 
-  m_poCfg->SetPath( wxT("/Viewer") );
+  g_oConfig.bSetEdaSuite   ( (eTypeEDA)        m_oChoEdaSuite  .m_oChoice.GetSelection( ) );
+  g_oConfig.bSetDataViewer ( (eTypeViewer)     m_oChoDataViewer.m_oChoice.GetSelection( ) );
+  g_oConfig.bSetTmpFileMgt ( (eTypeTmpFileMgt) m_oChoTmpFileMgt.m_oChoice.GetSelection( ) );
+  g_oConfig.bSetFrmLayout  (                   m_oChoFrmLayout .m_oChoice.GetSelection( ) );
+  g_oConfig.bSetPhaseUnits ( (eTypeUnits)      m_oChoPhaseUnits.m_oChoice.GetSelection( ) );
+  g_oConfig.bSetPrecision  (                   m_oChoPrecision .m_oChoice.GetSelection( ) + 1 );
+  g_oConfig.bSetGuileProc  (                   m_oChoGuileProc .m_oChoice.GetStringSelection( ) );
 
-  m_poCfg->Write( wxT("Name")         , rosGetViewerUtil( ) );
+  g_oConfig.bSetNbkMaxLns  ( (uint)           m_oPnlNbkMaxLns .liGetValue( )  );
+  g_oConfig.bSetSpnPeriod  ( (uint) (1000.0 * m_oPnlSpnPeriod .dfGetValue( )) );
+  g_oConfig.bSetToolTipDly ( (uint) (1000.0 * m_oPnlToolTipDly.dfGetValue( )) );
 
-  m_poCfg->SetPath( wxT("/Main") );
+  g_oConfig.bSetToolTips   (   m_oCbxToolTips   .IsChecked( ) );
+  g_oConfig.bSetSyncSigSrcs(   m_oCbxSyncSigSrcs.IsChecked( ) );
+  g_oConfig.bSetSyncTemps  (   m_oCbxSyncTemps  .IsChecked( ) );
+  g_oConfig.bSetKeepNetLst (   m_oCbxKeepNetLst .IsChecked( ) );
+  g_oConfig.bSetVerboseMode(   m_oCbxVerboseMode.IsChecked( ) );
+  g_oConfig.bSetIncludeMode(   m_oCbxIncludeMode.IsChecked( ) );
+  g_oConfig.bSetEmbedMode  (   m_oCbxEmbedMode  .IsChecked( ) );
+  g_oConfig.bSetNoMungeMode( ! m_oCbxNoMungeMode.IsChecked( ) );
+  g_oConfig.bSetAutoRegen  (   m_oCbxAutoRegen  .IsChecked( ) );
 
-  m_poCfg->Write( wxT("TmpFileMgt")   , (long) iGetTmpFileMgt( ) );
-  m_poCfg->Write( wxT("MainFrmLayout"), (long) iGetFrmLayout( ) );
-  m_poCfg->Write( wxT("Precision")    , (long) iGetPrecision( ) );
-  m_poCfg->Write( wxT("NbkMaxLns")    , (long) iGetNbkMaxLns( ) );
-  m_poCfg->Write( wxT("SpnPeriod")    , (long) iGetSpnPeriod( ) );
-  m_poCfg->Write( wxT("ToolTips")     , (long) ( bGetToolTips( ) ? 1 : 0 ) );
-//  m_poCfg->Write( wxT("TipDelay")    , (long) iGetTipDelay( ) ); // ??? MSW 2015-03-23
-
-  m_poCfg->SetPath( wxT("/Simulator") );
-
-  m_poCfg->Write( wxT("PhaseUnits")   , (long) iGetUnitsPhase( ) );
-  m_poCfg->Write( wxT("SyncSwpSrcs")  , (long) ( bGetSyncSwpSrcs( ) ? 1 : 0 ) );
-
-  m_poCfg->Flush( );
+  g_oConfig.bFlush( );
 
   SetEvtHandlerEnabled( true );
 }
@@ -352,7 +397,7 @@ void  DlgPrefs::Save( void )
 //**************************************************************************************************
 // Reset all dialog settings to defaults.
 //
-// Return Values:
+// Return Values :
 //   true  - Success
 //   false - Failure
 
@@ -368,10 +413,10 @@ bool  DlgPrefs::bClear( void )
 //**************************************************************************************************
 // Ok button event handler.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - An object holding information about the event (not used)
 
-void  DlgPrefs::OnBtnOk( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  DlgPrefs::OnBtnOk( wxCommandEvent & roEvtCmd )
 {
   Save( );
 
@@ -381,10 +426,10 @@ void  DlgPrefs::OnBtnOk( wxCommandEvent & WXUNUSED( roEvtCmd ) )
 //**************************************************************************************************
 // Cancel button event handler.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - An object holding information about the event (not used)
 
-void  DlgPrefs::OnBtnCancel( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  DlgPrefs::OnBtnCancel( wxCommandEvent & roEvtCmd )
 {
   Load( );
 
