@@ -3,8 +3,8 @@
 //                                         --------------                                          *
 // Description : This dialogue is used to enter applications preferences.                          *
 // Started     : 2006-10-17                                                                        *
-// Last Update : 2015-04-18                                                                        *
-// Copyright   : (C) 2006 by MSWaters                                                              *
+// Last Update : 2018-10-28                                                                        *
+// Copyright   : (C) 2006-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -21,12 +21,14 @@
 // Application Includes
 
 #include "TypeDefs.hpp"
+#include "Config.hpp"
 #include "CmdLinePcr.hpp"
 #include "utility/PnlValue.hpp"
 #include "utility/TextCtrl.hpp"
 #include "utility/PnlLblCho.hpp"
 #include "utility/PnlLblTxt.hpp"
 #include "utility/PnlTxtSpn.hpp"
+#include "process/PrcGNetList.hpp"
 
 // wxWidgets Includes
 
@@ -38,22 +40,28 @@ class DlgPrefs : public wxDialog
 {
   private :
 
-    // Pointer to global configuration object
-    wxConfig  * m_poCfg;
-
     // Display controls
-    PnlLblCho   m_oChoViewerUtil;
+    PnlLblCho   m_oChoEdaSuite;
+    PnlLblCho   m_oChoDataViewer;
     PnlLblCho   m_oChoTmpFileMgt;
     PnlLblCho   m_oChoFrmLayout;
-    PnlLblCho   m_oChoUnitsPhase;
+    PnlLblCho   m_oChoPhaseUnits;
     PnlLblCho   m_oChoPrecision;
+    PnlLblCho   m_oChoGuileProc;
     PnlValue    m_oPnlNbkMaxLns;
     PnlValue    m_oPnlSpnPeriod;
-//  PnlLblCho   m_oPnlTipDelay;    // ??? MSW 2015-03-23 Tool tip delay
+    PnlValue    m_oPnlToolTipDly;
     wxCheckBox  m_oCbxToolTips;
-    wxCheckBox  m_oCbxSyncSwpSrcs;
-//  wxCheckBox  m_oCbxSubcktCpnts; // ??? MSW 2015-04-18 Include sub-circuit components in Components list
-//  PnlLblTxt   m_oTxtBinGschem;   // ??? MSW 2014-03-11 Allow binary names to be specified
+    wxCheckBox  m_oCbxSyncSigSrcs;
+    wxCheckBox  m_oCbxSyncTemps;
+    wxCheckBox  m_oCbxKeepNetLst;
+    wxCheckBox  m_oCbxVerboseMode;
+    wxCheckBox  m_oCbxIncludeMode;
+    wxCheckBox  m_oCbxEmbedMode;
+    wxCheckBox  m_oCbxNoMungeMode;
+    wxCheckBox  m_oCbxAutoRegen;
+//  wxCheckBox  m_oCbxSubcktCpnts;  // ??? MSW 2015-04-18 Include sub-circuit components in Components list
+//  PnlLblTxt   m_oTxtBinGschem;    // ??? MSW 2014-03-11 Allow binary names to be specified
 //  PnlLblTxt   m_oTxtBinGnetlst;
 //  PnlLblTxt   m_oTxtBinNgspice;
 //  PnlLblTxt   m_oTxtBinGnucap;
@@ -78,38 +86,18 @@ class DlgPrefs : public wxDialog
 
   public :
 
-          DlgPrefs( wxWindow * poWin );
-         ~DlgPrefs( );
+    explicit  DlgPrefs( wxWindow * poWin );
+             ~DlgPrefs( );
 
     bool  bClear( void );
 
-    const  wxString  rosGetViewerUtil ( void )
-                                      { return( m_oChoViewerUtil.m_oChoice.GetStringSelection() ); }
-           int         iGetTmpFileMgt ( void )
-                                      { return( m_oChoTmpFileMgt.m_oChoice.GetSelection( ) ); }
-           int         iGetFrmLayout  ( void )
-                                      { return( m_oChoFrmLayout .m_oChoice.GetSelection( ) ); }
-           int         iGetUnitsPhase ( void )
-                                      { return( m_oChoUnitsPhase.m_oChoice.GetSelection( ) ); }
-           int         iGetPrecision  ( void )
-                                      { return( m_oChoPrecision .m_oChoice.GetSelection( ) + 1 ); }
-           int         iGetNbkMaxLns  ( void )
-                                      { return( (int) m_oPnlNbkMaxLns.liGetValue( ) ); }
-           int         iGetSpnPeriod  ( void )
-                                      { return( (int) (1000.0 * m_oPnlSpnPeriod.dfGetValue( )) ); }
-//         int         iGetTipDelay   ( void ) // ??? MSW 2015-03-23
-//                                    { return( m_oPnlTipDelay .liGetValue( ) ); }
-           bool        bGetSyncSwpSrcs( void )
-                                      { return( m_oCbxSyncSwpSrcs.IsChecked( ) ); }
-           bool        bGetToolTips   ( void )
-                                      { return( m_oCbxToolTips   .IsChecked( ) ); }
-
   private :
 
     // Event handlers
     void  OnBtnOk    ( wxCommandEvent & roEvtCmd );
     void  OnBtnCancel( wxCommandEvent & roEvtCmd );
 
+    // Declare friend classes
     friend  class  FrmMain;
 
     // In order to be able to react to a menu command, it must be given a unique identifier such as
@@ -117,18 +105,27 @@ class DlgPrefs : public wxDialog
     enum eDlgItemID
     {
       ID_CHO_SIMENG,
-      ID_CHO_VIEWERUTIL,
+      ID_CHO_EDASUITE,
+      ID_CHO_DATAVIEWER,
       ID_CHO_TMPFILEMGT,
       ID_CHO_FRMLAYOUT,
       ID_CHO_PHASEUNITS,
       ID_CHO_PRECISION,
+      ID_CHO_GUILEPROC,
 
       ID_VAL_NBKMAXLNS,
       ID_VAL_SPINPERIOD,
-//      ID_VAL_TIPDELAY, // ??? MSW 2015-03-23
+      ID_VAL_TOOLTIPDLY,
 
-      ID_CBX_SYNCSWPSRCS,
       ID_CBX_TOOLTIPS,
+      ID_CBX_SYNCSIGSRCS,
+      ID_CBX_SYNCTEMPS,
+      ID_CBX_KEEPNETLST,
+      ID_CBX_VERBOSEMODE,
+      ID_CBX_INCLUDEMODE,
+      ID_CBX_EMBEDMODE,
+      ID_CBX_NOMUNGEMODE,
+      ID_CBX_AUTOREGEN,
 
       ID_TXT_GSCHEM,
       ID_TXT_GNETLST,
@@ -142,13 +139,14 @@ class DlgPrefs : public wxDialog
       ID_BTN_CANCEL,
 
       ID_UNUSED,      // Assigned to controls for which events are not used
-
-      ID_FST = ID_CHO_SIMENG,
-      ID_LST = ID_BTN_CANCEL
     };
 
     // Leave this as the last line as private access is envoked by macro
+#if wxCHECK_VERSION( 3,0,0 )
     wxDECLARE_EVENT_TABLE( );
+#else
+    wxDECLARE_EVENT_TABLE( )
+#endif
 };
 
 //**************************************************************************************************
