@@ -1,9 +1,9 @@
 //**************************************************************************************************
-//                                          FileTasks.cpp                                          *
-//                                         ---------------                                         *
+//                                         FileTasks.cpp                                           *
+//                                        ---------------                                          *
 // Started     : 2005-05-28                                                                        *
-// Last Update : 2015-04-09                                                                        *
-// Copyright   : (C) 2005 by MSWaters                                                              *
+// Last Update : 2018-10-28                                                                        *
+// Copyright   : (C) 2005-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -23,13 +23,10 @@
 // Argument List :
 //   poFrmMain - A pointer to the parent frame
 
-FileTasks::FileTasks( FrmMain * poFrmMain )
+FileTasks::FileTasks( FrmMain * poFrmMain ) : m_oPrc_gnetlist( )
 {
   // Set the pointer to the parent frame
   m_poFrmMain = poFrmMain;
-
-  // Get the global configuration object
-  m_poCfg = (wxConfig *) wxConfig::Get( );
 }
 
 //**************************************************************************************************
@@ -55,18 +52,18 @@ bool  FileTasks::bExecImport( void )
   m_poFrmMain->m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_CONSOLE );
 
   // Convert the schematic file/s to a netlist file
-  bRtn = m_oPrcGNetList.bExec( );
+  bRtn = m_oPrc_gnetlist.bExec( );
 
   // Print the results
   poTxtCtl = m_poFrmMain->m_oNbkTxtCtls.poGetPage( );
-  m_oPrcGNetList.Print( *poTxtCtl );
+  m_oPrc_gnetlist.PrintIO( *poTxtCtl );
 
   // Check for errors in the gnetlist output
-  if( poTxtCtl->GetValue( ).Contains( wxT("ERROR") ) )     bRtn = false;
+  if( poTxtCtl->GetValue( ).Contains( wxT("ERROR") )     ) bRtn = false;
   if( poTxtCtl->GetValue( ).Contains( wxT("Backtrace") ) ) bRtn = false;
 
   // Delete the process log file
-  m_oPrcGNetList.bDelLogFile( );
+  m_oPrc_gnetlist.bDelLogFile( );
 
   return( bRtn );
 }
@@ -76,12 +73,12 @@ bool  FileTasks::bExecImport( void )
 
 void  FileTasks::InitGuileProc( void )
 {
-  wxString  os1;
+  // Get the Guile procedure name
+  const wxString & ros1 = g_oConfig.rosGetGuileProc( );
+  if( ros1.IsEmpty( ) ) return;
 
   // Set the Guile procedure name
-  m_poCfg->SetPath( wxT("/gnetlist") );
-  os1 = m_poCfg->Read( wxT("GuileProc"), wxT("spice-sdb") );
-  bSetGuileProc( os1 );
+  bSetGuileProc( ros1 );
 }
 
 //**************************************************************************************************
@@ -89,19 +86,16 @@ void  FileTasks::InitGuileProc( void )
 
 void  FileTasks::InitSchemFiles( void )
 {
-  wxString  os1;
-
   // Get the schematic file name/s
-  m_poCfg->SetPath( wxT("/Files") );
-  os1 = m_poCfg->Read( wxT("Schematics"), wxT("") );
-  if( os1.IsEmpty( ) )          return;
+  const wxArrayString & roas1 = g_oConfig.roasGetSchemFiles( );
+  if( roas1.IsEmpty( ) )          return;
 
   // Set the schematic file name/s
-  if( ! bSetSchemFiles( os1 ) ) return;
+  if( ! bSetSchemFiles( roas1 ) ) return;
 
   // Return if a netlist file has also been specified
-  os1 = m_poCfg->Read( wxT("NetList"), wxT("") );
-  if( ! os1.IsEmpty( ) )        return;
+  const wxString & ros1 = g_oConfig.rosGetNetLstFile( );
+  if( ! ros1.IsEmpty( ) )         return;
 
   // Import the schematic file/s
   bImport( );
@@ -112,32 +106,30 @@ void  FileTasks::InitSchemFiles( void )
 
 void  FileTasks::InitNetLstFile( void )
 {
-  wxString  os1;
-
   // Return if a netlist file has already been loaded
   if( ! m_poFrmMain->m_oNetLst.bIsEmpty( ) ) return;
 
   // Get the netlist file name
-  m_poCfg->SetPath( wxT("/Files") );
-  os1 = m_poCfg->Read( wxT("NetList"), wxT("") );
-  if( os1.IsEmpty( ) )                       return;
+  const wxString & ros1 = g_oConfig.rosGetNetLstFile( );
+  if( ros1.IsEmpty( ) )                      return;
 
   // Set the netlist file name
-  if( ! bSetNetLstFile( os1 ) )              return;
+    if( ! bSetNetLstFile( ros1 ) )           return;
 
   // Open the netlist file
   bOpen( );
 
   // Does the netlist file contain simulator specific information?
-  m_poCfg->SetPath( wxT("/Simulator") );
   if(      m_poFrmMain->m_oSimnNgSp.m_oCmdPR.bIsValid( ) )
   {
-    m_poCfg->Write( wxT("Engine"), CLP_NGSPICE );
+    g_oConfig.bSetSimEng( eSIMR_NGSPICE );
+    g_oConfig.bFlush( );
     m_poFrmMain->m_oSimnGCap = m_poFrmMain->m_oSimnNgSp;
   }
   else if( m_poFrmMain->m_oSimnGCap.m_oCmdPR.bIsValid( ) )
   {
-    m_poCfg->Write( wxT("Engine"), CLP_GNUCAP  );
+    g_oConfig.bSetSimEng( eSIMR_GNUCAP );
+    g_oConfig.bFlush( );
     m_poFrmMain->m_oSimnNgSp = m_poFrmMain->m_oSimnGCap;
   }
 }
@@ -150,9 +142,8 @@ void  FileTasks::DlgErrSchems( void )
   wxString  os1, os2, os3;
   size_t    sz1;
 
-  for( sz1=0; sz1<m_oPrcGNetList.roaGetSchemFiles( ).GetCount( ); sz1++ )
-    os2 << wxT("     ") << m_oPrcGNetList.rofnGetSchemFile( sz1 ).GetFullPath( )
-        << wxT("\n");
+  for( sz1=0; sz1<m_oPrc_gnetlist.roaGetSchemFiles( ).GetCount( ); sz1++ )
+    os2 << wxT("     ") << m_oPrc_gnetlist.roGetSchemFile( sz1 ).GetFullPath( ) << wxT("\n");
 
   if( sz1 > 1 ) os3 = wxT("s were");
   else          os3 = wxT(" was");
@@ -177,8 +168,9 @@ void  FileTasks::DlgErrNetLst( void )
   wxString  os1;
 
   os1 << wxT("The netlist file wasn't loaded correctly :\n")
-      << wxT("\n     ") << m_oPrcGNetList.rofnGetNetLstFile( ).GetFullPath( )
-      << wxT("\n\n")
+      << wxT("\n")
+      << wxT("     ") << m_oPrc_gnetlist.roGetNetLstFile( ).GetFullPath( ) << wxT("\n")
+      << wxT("\n")
       << wxT("This is often because the file is in-complete, empty or  \n")
       << wxT("doesn't exist.\n");
 
@@ -207,11 +199,11 @@ bool  FileTasks::bIsOk_gnetlist( void )
   wxString  os1;
 
   // Check that gnetlist exists and is accessible
-  if( ! m_oPrcGNetList.bBinExists( ) )
+  if( ! m_oPrc_gnetlist.bBinExists( ) )
   {
     if( m_poFrmMain != NULL )
     {
-      os1 << wxT("Can't find the binary \"") << m_oPrcGNetList.roGetBinary( ).GetFullName( )
+      os1 << wxT("Can't find the binary \"") << m_oPrc_gnetlist.roGetBinFile( ).GetFullName( )
                                                                     << wxT("\" which is required\n")
           << wxT("to import schematic file/s. The path is unknown   \n")
           << wxT("or gnetlist hasn't been installed.\n");
@@ -262,19 +254,18 @@ bool  FileTasks::bSetTitle( void )
 // Set a Guile procedure name to be used for importing schematic files using gNetList.
 //
 // Argument List :
-//   rosPName - The Guile procedure name
-//              (Refer to gNetList documentation for list of procedure names)
+//   rosProcName - The Guile procedure name
+//                 (Refer to gNetList documentation for list of procedure names)
 
-bool  FileTasks::bSetGuileProc( const wxString & rosPName )
+bool  FileTasks::bSetGuileProc( const wxString & rosProcName )
 {
-  if( ! m_oPrcGNetList.bSetGuileProc( rosPName ) ) return( false );
+  if( ! m_oPrc_gnetlist.bSetGuileProc( rosProcName ) ) return( false );
 
   // Record the Guile procedure name currently selected
-  m_poCfg->SetPath( wxT("/gNetList") );
-  m_poCfg->Write( wxT("GuileProc"), rosGetGuileProc( ) );
+  g_oConfig.bSetGuileProc( rosGetGuileProc( ) );
 
   // Write any changes to the configuration file
-  m_poCfg->Flush( );
+  g_oConfig.bFlush( );
 
   return( true );
 }
@@ -283,41 +274,56 @@ bool  FileTasks::bSetGuileProc( const wxString & rosPName )
 // Set the schematic file name/s.
 //
 // Argument List :
-//   rosFNames - A string containing the full path and file name/s
+//   roasFileNames - A string containing the full path and file name/s
 //
 // Return Values :
 //   true  - Success
 //   false - Failure
 
-bool  FileTasks::bSetSchemFiles( const wxString & rosFNames )
+bool  FileTasks::bSetSchemFiles( const wxString & rosFileNames )
 {
-  wxString  os1;
-  size_t    sz1;
+  wxStringTokenizer  ostk1;
+  wxArrayString      osa1;
 
-  if( rosFNames.IsEmpty( ) )
+  ostk1.SetString( rosFileNames );
+  while( ostk1.HasMoreTokens( ) )
+    osa1.Add( ostk1.GetNextToken( ) );
+
+  return( bSetSchemFiles( osa1 ) );
+}
+
+//**************************************************************************************************
+// Set the schematic file name/s.
+//
+// Argument List :
+//   roasFileNames - A string array containing the full path and file name/s
+//
+// Return Values :
+//   true  - Success
+//   false - Failure
+
+bool  FileTasks::bSetSchemFiles( const wxArrayString & roasFileNames )
+{
+  wxArrayString  oas1;
+  wxString       os1;
+
+  if( roasFileNames.IsEmpty( ) )
   {
     // Clear the schematic file name/s in the configuration object
-    m_poCfg->SetPath( wxT("/Files") );
-    m_poCfg->Write( wxT("Schematics"), os1 );
-    m_poCfg->Flush( );
+    oas1.Empty( );
+    g_oConfig.bSetSchemFiles( oas1 );
+    g_oConfig.bFlush( );
   }
 
   // Attempt to set the schematic file name/s in the gnetlist process object
-  if( ! m_oPrcGNetList.bSetSchemFiles( rosFNames ) ) return( false );
+  if( ! m_oPrc_gnetlist.bSetSchemFiles( roasFileNames ) ) return( false );
 
   // Set the schematic file name/s
-  if( m_poFrmMain != NULL ) m_poFrmMain->m_oNetLst.bSetSchemFiles( rosFNames );
+  if( m_poFrmMain != NULL ) m_poFrmMain->m_oNetLst.bSetSchemFiles( roasFileNames );
 
   // Record the schematic file name/s in the configuration object
-  const wxArrayString & rosa1=rosaGetSchemFiles( );
-  for( sz1=0; sz1<rosa1.GetCount( ); sz1++ )
-  {
-    if( sz1 > 0 ) os1 += wxT(' ');
-    os1 += rosa1[ sz1 ];
-  }
-  m_poCfg->SetPath( wxT("/Files") );
-  m_poCfg->Write( wxT("Schematics"), os1 );
-  m_poCfg->Flush( );
+  g_oConfig.bSetSchemFiles( rosaGetSchemFiles( ) );
+  g_oConfig.bFlush( );
 
   return( true );
 }
@@ -326,39 +332,37 @@ bool  FileTasks::bSetSchemFiles( const wxString & rosFNames )
 // Set the netlist file name.
 //
 // Argument List :
-//   psFileName - A string containing the full path and file name
+//   rosFileName - A string containing the full path and file name
 //
 // Return Values :
 //   true  - Success
 //   false - Failure
 
-bool  FileTasks::bSetNetLstFile( const wxString & rosFName )
+bool  FileTasks::bSetNetLstFile( const wxString & rosFileName )
 {
   wxString  os1;
 
-  if( rosFName.IsEmpty( ) )
+  if( rosFileName.IsEmpty( ) )
   {
     // Clear the netlist file name in the configuration object
-    m_poCfg->SetPath( wxT("/Files") );
-    m_poCfg->Write( wxT("NetList"), os1 );
-    m_poCfg->Flush( );
+    g_oConfig.bSetNetLstFile( wxEmptyString );
+    g_oConfig.bFlush( );
   }
 
   // Attempt to set the netlist file name in the gNetList process object
-  if( ! m_oPrcGNetList.bSetNetLstFile( rosFName ) ) return( false );
+  if( ! m_oPrc_gnetlist.bSetNetLstFile( rosFileName ) ) return( false );
 
   // Configure stuff in the main frame
   if( m_poFrmMain != NULL )
   {
-    m_poFrmMain->m_oNetLst.bSetLoadFile( rosFName );  // Set load file path
-    m_poFrmMain->m_oNetLst.bSetSaveFile( rosFName );  // Set save file path
+    m_poFrmMain->m_oNetLst.bSetLoadFile( rosFileName );  // Set load file path
+    m_poFrmMain->m_oNetLst.bSetSaveFile( rosFileName );  // Set save file path
   }
 
   // Record the netlist file name in the configuration object
   os1 = rosGetNetLstFile( );
-  m_poCfg->SetPath( wxT("/Files") );
-  m_poCfg->Write( wxT("NetList"), os1 );
-  m_poCfg->Flush( );
+  g_oConfig.bSetNetLstFile( os1 );
+  g_oConfig.bFlush( );
 
   return( true );
 }
@@ -371,7 +375,7 @@ bool  FileTasks::bSetNetLstFile( const wxString & rosFName )
 
 const wxString & FileTasks::rosGetGuileProc( void )
 {
-  return( m_oPrcGNetList.rosGetGuileProc( ) );
+  return( m_oPrc_gnetlist.rosGetGuileProc( ) );
 }
 
 //**************************************************************************************************
@@ -388,9 +392,9 @@ const wxArrayString & FileTasks::rosaGetSchemFiles( void )
 
   osa1.Clear( );
 
-  for( szt1=0; szt1<m_oPrcGNetList.roaGetSchemFiles( ).GetCount( ); szt1++ )
+  for( szt1=0; szt1<m_oPrc_gnetlist.roaGetSchemFiles( ).GetCount( ); szt1++ )
   {
-    os1 = m_oPrcGNetList.rofnGetSchemFile( szt1 ).GetFullPath( );
+    os1 = m_oPrc_gnetlist.roGetSchemFile( szt1 ).GetFullPath( );
     if( ! os1.IsEmpty( ) ) osa1.Add( os1 );
   }
 
@@ -407,11 +411,26 @@ const wxString & FileTasks::rosGetNetLstFile( void )
 {
   static  wxString  osNetLstFile;
 
-  osNetLstFile = m_oPrcGNetList.rofnGetNetLstFile( ).GetFullPath( );
+  osNetLstFile = m_oPrc_gnetlist.roGetNetLstFile( ).GetFullPath( );
 
   return( osNetLstFile );
 }
 
+//**************************************************************************************************
+// Get the log file name.
+//
+// Return Values :
+//   The log file name
+
+const wxString & FileTasks::rosGetLogFile( void )
+{
+  static  wxString  osLogFile;
+
+  osLogFile = m_oPrc_gnetlist.roGetLogFile( ).GetFullPath( );
+
+  return( osLogFile );
+}
+
 //**************************************************************************************************
 // Display an open file dialog and set the netlist file name.
 //
@@ -435,8 +454,7 @@ bool  FileTasks::bDlgOpen( void )
       << wxT("Netlist files (*.net)|*.net");
 
   // Get the file path from the global configuration object
-  m_poCfg->SetPath( wxT("/Directories") );
-  os2 = m_poCfg->Read( wxT("LastAccess"), wxGetHomeDir( ) );
+  os2 = g_oConfig.rosGetDirLastAcc( );
 
   // Set the style bit pattern
 #if wxCHECK_VERSION( 2,8,0 )
@@ -446,8 +464,7 @@ bool  FileTasks::bDlgOpen( void )
 #endif
 
   // Create and configure the file open dialog
-  poDlgOpen = new wxFileDialog( m_poFrmMain, wxT(""), wxT(""), wxT(""),
-                                wxT(""), li1 );
+  poDlgOpen = new wxFileDialog( m_poFrmMain, wxT(""), wxT(""), wxT(""), wxT(""), li1 );
   poDlgOpen->SetMessage( wxT("Open a Circuit Description File") );
   poDlgOpen->SetWildcard( os1 );
   poDlgOpen->SetFilterIndex( 1 );
@@ -464,9 +481,10 @@ bool  FileTasks::bDlgOpen( void )
   if( ! bSetNetLstFile( os1 ) )            return( false );
 
   // Set the path last accessed in the global configuration object
-  m_poCfg->SetPath( wxT("/Directories") );
-  m_poCfg->Write( wxT("LastAccess"), poDlgOpen->GetDirectory( ) );
-  m_poCfg->Flush( );
+  g_oConfig.bSetDirLastAcc( poDlgOpen->GetDirectory( ) );
+
+  // Write any changes to the configuration file
+  g_oConfig.bFlush( );
 
   return( true );
 }
@@ -481,10 +499,9 @@ bool  FileTasks::bDlgOpen( void )
 bool  FileTasks::bDlgImport( void )
 {
   wxFileDialog * poDlgImport;
-  wxArrayString  osa1;
+  wxArrayString  oas1;
   wxString       os1, os2;
   long           li1;
-  size_t         sz1;
 
   // Can't display dialogue unless the application main frame has been created
   if( m_poFrmMain == NULL )                  return( false );
@@ -494,8 +511,7 @@ bool  FileTasks::bDlgImport( void )
       << wxT("Protel II files (*.\?\?\?)|*.\?\?\?");
 
   // Get the file path from the global configuration object
-  m_poCfg->SetPath( wxT("/Directories") );
-  os2 = m_poCfg->Read( wxT("LastAccess"), wxGetHomeDir( ) );
+  os2 = g_oConfig.rosGetDirLastAcc( );
 
   // Set the style bit pattern
 #if wxCHECK_VERSION( 2,8,0 )
@@ -517,23 +533,18 @@ bool  FileTasks::bDlgImport( void )
   // Delete temporary files
   bDelTmpFiles( );
 
-  // Set the guile procedure name
-  bSetGuileProc( wxT("spice-sdb") );
-
   // Set the schematic file name/s
-  poDlgImport->GetPaths( osa1 );
-  os1 = osa1.Item( 0 );
-  for( sz1=1; sz1<osa1.GetCount( ); sz1++ )
-    os1 << osa1.Item( sz1 ) << wxT(' ');
-  if( ! bSetSchemFiles( os1 ) )              return( false );
+  poDlgImport->GetPaths( oas1 );
+  if( ! bSetSchemFiles( oas1 ) )             return( false );
 
   // Set the netlist file name (derive it from the schematic file name)
   bSetNetLstFile( );
 
   // Set the path last accessed in the global configuration object
-  m_poCfg->SetPath( wxT("/Directories") );
-  m_poCfg->Write( wxT("LastAccess"), poDlgImport->GetDirectory( ) );
-  m_poCfg->Flush( );
+  g_oConfig.bSetDirLastAcc( poDlgImport->GetDirectory( ) );
+
+  // Write any changes to the configuration file
+  g_oConfig.bFlush( );
 
   return( true );
 }
@@ -541,71 +552,97 @@ bool  FileTasks::bDlgImport( void )
 //**************************************************************************************************
 // Delete temporary files which may have been generated by this application.
 //
-// Ie. given the circuit description file "<netlist>.ckt" delete files of the following form :
-//       <netlist>.ngspice.dc, <netlist>.ngspice.ac, ... etc.
-//       <netlist>.gnucap.op,  <netlist>.gnucap.dc, .... etc.
-//       gnetlist.log
+// Eg. given the circuit description file "test-cct.sch" delete files of the form :
+//       test-cct.ckt
+//       test-cct.sch~
+//       gspiceui.log
+//       test-cct.ngspice.dc, test-cct.ngspice.ac, ... etc.
+//       test-cct.gnucap.op,  test-cct.gnucap.dc,  ... etc.
 
 bool  FileTasks::bDelTmpFiles( void )
 {
-  wxArrayString  osa1;
-  wxFileName     ofn1;
-  wxString       os1, os2;
-  long           liTmpFileMgt;
-  int            i1;
+  eTypeTmpFileMgt  eTmpFileMgt;
+  wxArrayString    osaDelFiles;       // A list of files to delete
+  bool             bDelNetLst=false;  // Is the netlist file being deleted?
+  wxFileName       ofn1;
+  wxString         os1, os2;
+  size_t           sz1;
+  int              i1;
 
-  // Determine the current temporary file management strategy
-  m_poCfg->SetPath( wxT("/Main") );
-  m_poCfg->Read( wxT("TmpFileMgt"), &liTmpFileMgt, (long) eTFM_DELETE );
+  // Check the current temporay file management strategy and return if nothing needs to be done
+  eTmpFileMgt = g_oConfig.eGetTmpFileMgt( );
+  if( eTmpFileMgt == eTFM_KEEP )         return( true );
 
-  // Return if nothing needs to be done
-  if( liTmpFileMgt == (long) eTFM_KEEP )    return( true );
-
-  // Get the path to the schematic or circuit description file
-  ofn1 = m_oPrcGNetList.rofnGetNetLstFile( );
-  ofn1.Normalize( );
+  // Before looking for files to delete, get the path to the files
+  const wxArrayString & roasSchems = rosaGetSchemFiles( );
+  os1 = rosGetNetLstFile( );
+  if(      ! os1.IsEmpty( )           ) ofn1.Assign( os1 );
+  else if( roasSchems.GetCount( ) > 0 ) ofn1.Assign( roasSchems[ 0 ] );
   if( !ofn1.IsOk( ) || !ofn1.FileExists( ) ) return( false );
 
-  // Look for the gnetlist log file
-  os1 = ofn1.GetPath( ) + wxT("/gnetlist.log");
-  if( wxFileExists( os1 ) ) osa1.Add( os1 );
+  // If there is a schematic file add the netlist file and the schematic backup file/s to the list
+  // of files to be deleted
+  if( roasSchems.GetCount( ) > 0 )
+  {
+    if( ! g_oConfig.bGetKeepNetLst( ) )
+    {
+      osaDelFiles.Add( ofn1.GetFullPath( ) );  // Add the netlist file to the delete list
+      bDelNetLst = true;
+    }
 
-  // Look for files containing simulation results
-  os1 = ofn1.GetName( );
-  i1 = os1.Find( wxT(".gspiceui") );
-  if( i1 > 0 ) os1 = os1.Truncate( (size_t) i1 );
-  ofn1.SetFullName( os1 );
+    for( sz1=0; sz1<roasSchems.GetCount( ); sz1++ )
+    {
+      os1 = roasSchems[ sz1 ] + wxT('~');
+      if( wxFileExists( os1 ) )
+        osaDelFiles.Add( os1 );                // Add a schematic backup file to delete list
+    }
+  }
 
-  // Look for any GNU-Cap results file
-  os1 = ofn1.GetFullPath( ) + wxT(".gnucap.??");
-  for( os2=wxFindFirstFile( os1 ); !os2.IsEmpty( ); os2=wxFindNextFile( ) )
-    osa1.Add( os2 );
+  // Look for the gspiceui log file and add it to the files to be deleted
+  os1 = rosGetLogFile( );
+  if( wxFileExists( os1 ) ) osaDelFiles.Add( os1 );
 
-  // Look for any NG-Spice results files
+  // Now look for simulation results files
+  ofn1.ClearExt( );
+
+  // Look for any NG-Spice results files and add them to the delete list
   os1 = ofn1.GetFullPath( ) + wxT(".ngspice.??");
   for( os2=wxFindFirstFile( os1 ); !os2.IsEmpty( ); os2=wxFindNextFile( ) )
-    osa1.Add( os2 );
+    osaDelFiles.Add( os2 );
+
+  // Look for any GNU-Cap results files and add them to the delete list
+  os1 = ofn1.GetFullPath( ) + wxT(".gnucap.??");
+  for( os2=wxFindFirstFile( os1 ); !os2.IsEmpty( ); os2=wxFindNextFile( ) )
+    osaDelFiles.Add( os2 );
 
   // If necessary prompt the user for permission to delete temporary files
-  if( osa1.GetCount( ) > 0 )
+  if( osaDelFiles.GetCount( ) > 0 )
   {
     if( m_poFrmMain!=NULL && m_poFrmMain->IsShown( ) )
     {
       // Prompt the user
-      if( liTmpFileMgt == (long) eTFM_PROMPT )
+      if( eTmpFileMgt == eTFM_PROMPT )
       {
         os1 = wxT("Delete Temporary Files");
         os2 = wxT("\nDelete the following temporary files :\n\n");
-        for( i1=0; i1<(int)osa1.GetCount( ); i1++ )
-          os2 << wxT("  ") << osa1.Item( i1 ) << wxT("   \n");
+        for( i1=0; i1<(int)osaDelFiles.GetCount( ); i1++ )
+          os2 << wxT("     ") << osaDelFiles[ i1 ] << wxT("   \n");
         i1 = wxMessageBox( os2, os1, wxYES_NO|wxICON_QUESTION, m_poFrmMain );
       }
       else i1 = wxYES;
 
       // Delete the temporary files
       if( i1 == wxYES )
-        for( i1=0; i1<(int)osa1.GetCount( ); i1++ )
-          wxRemoveFile( osa1.Item( i1 ) );
+      {
+        for( i1=0; i1<(int)osaDelFiles.GetCount( ); i1++ )
+          wxRemoveFile( osaDelFiles[ i1 ] );
+
+        if( bDelNetLst )
+        {
+          g_oConfig.bSetNetLstFile( wxEmptyString );
+          g_oConfig.bFlush( );
+        }
+      }
     }
   }
 
@@ -613,8 +650,7 @@ bool  FileTasks::bDelTmpFiles( void )
 }
 
 //**************************************************************************************************
-// Open and load a circuit description (netlist) file into the m_poFrmMain attribute's simulation
-// objects.
+// Open and load a circuit description (netlist) file into the simulation objects of m_poFrmMain.
 //
 // Return Values :
 //   true  - Success
@@ -622,8 +658,7 @@ bool  FileTasks::bDelTmpFiles( void )
 
 bool  FileTasks::bOpen( void )
 {
-  bool      bRtn=true;
-  wxString  os1;
+  bool  bRtn=true;
 
   // Attempt to load the circuit description file
   NetList::bLoadFile( );
@@ -642,16 +677,18 @@ bool  FileTasks::bOpen( void )
   else
     m_poFrmMain->SetStatusText( wxT(" Netlist file opened successfully"), FrmMain::ePANE_MESAGE );
 
-  // Set the main frame title and the schematic file name/s if supplied
+  // Set the schematic file name/s if supplied
+  const wxArrayString & roas1 = m_poFrmMain->m_oNetLst.roasGetSchemFiles( );
+  if( ! roas1.IsEmpty( ) ) bSetSchemFiles( roas1 );
+
+  // Set the main frame title
   bSetTitle( );
-  os1 = m_poFrmMain->m_oNetLst.rosGetSchemFiles( );
-  if( ! os1.IsEmpty( ) ) bSetSchemFiles( os1 );
 
   return( bRtn );
 }
 
 //**************************************************************************************************
-// Import a schematic file by converting it to a netlist using gNetList and then loading it into the
+// Import a schematic file by converting it to a netlist using gnetlist and then loading it into the
 // FrmMain simulation object.
 //
 // Return Values :
@@ -662,13 +699,13 @@ bool  FileTasks::bImport( void )
 {
   bool  bRtn=true;
 
-  // Check that gnetList binary exists and is accessible
+  // Check that gnetlist binary exists and is accessible
   if( ! bIsOk_gnetlist( ) ) return( false );
 
   // Convert the schematic file/s to a netlist file and load it
   if( bExecImport( ) )
   {
-    bSetNetLstFile( m_oPrcGNetList.rofnGetNetLstFile( ).GetFullPath( ) );
+    bSetNetLstFile( m_oPrc_gnetlist.roGetNetLstFile( ).GetFullPath( ) );
 
     // Attempt to load the circuit description file
     NetList::bLoadFile( );
@@ -683,7 +720,9 @@ bool  FileTasks::bImport( void )
     else
     {
       DlgErrNetLst( );
-      m_poFrmMain->m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_NETLIST );
+      if( ! m_poFrmMain->m_oNbkTxtCtls.poGetPage( NbkTxtCtls::ePAGE_NETLIST )->bIsEmpty( ) )
+           m_poFrmMain->m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_NETLIST );
+      else m_poFrmMain->m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_CONSOLE );
       bRtn = false;
     }
   }
@@ -716,23 +755,20 @@ bool  FileTasks::bReload( void )
   m_poFrmMain->m_oNbkTxtCtls.bInitialize( );
 
   // Attempt to perform the reload operation
-  if( ! m_oPrcGNetList.roaGetSchemFiles( ).IsEmpty( ) )
+  if( ! m_oPrc_gnetlist.roaGetSchemFiles( ).IsEmpty( ) )
   { // Reload schematic file/s
     bRtn = bImport( );
-    if( bRtn )
-      m_poFrmMain->SetStatusText( wxT(" Schematic file/s re-imported successfully"),
-                                  FrmMain::ePANE_MESAGE );
+    if( bRtn ) m_poFrmMain->SetStatusText( wxT(" Schematic file/s re-imported successfully"),
+                                           FrmMain::ePANE_MESAGE );
   }
-  else if( m_oPrcGNetList.rofnGetNetLstFile( ).IsOk( ) )
+  else if( m_oPrc_gnetlist.roGetNetLstFile( ).IsOk( ) )
   { // Reload a netlist file
     bRtn = bOpen( );
-    if( bRtn )
-      m_poFrmMain->SetStatusText( wxT(" Netlist file reloaded successfully"),
-                                  FrmMain::ePANE_MESAGE );
+    if( bRtn ) m_poFrmMain->SetStatusText( wxT(" Netlist file reloaded successfully"),
+                                           FrmMain::ePANE_MESAGE );
   }
   else
-  {
-    // There's no open schematic or netlist to reload, display an error message
+  { // There's no open schematic or netlist to reload, display an error message
     m_poFrmMain->DlgErrMsg( wxT("Reload Operation Error"), wxT("No file is currently open.") );
     bRtn = false;
   }
@@ -750,7 +786,7 @@ bool  FileTasks::bReload( void )
 bool  FileTasks::bClose( void )
 {
   // Is there a file currently open?
-  if( m_oPrcGNetList.roaGetSchemFiles().IsEmpty() && !m_oPrcGNetList.rofnGetNetLstFile().IsOk() )
+  if( m_oPrc_gnetlist.roaGetSchemFiles( ).IsEmpty() && ! m_oPrc_gnetlist.roGetNetLstFile( ).IsOk() )
   {
     // There's no open schematic or netlist to close, display an error message
     m_poFrmMain->DlgErrMsg( wxT("Close Operation Error"), wxT("No file is currently open.") );
@@ -761,7 +797,7 @@ bool  FileTasks::bClose( void )
   bDelTmpFiles( );
 
   // Clear file names
-  m_oPrcGNetList.bClear( );
+  m_oPrc_gnetlist.bClear( );
   bSetNetLstFile( wxT("") );
   bSetSchemFiles( wxT("") );
 
@@ -790,3 +826,57 @@ bool  FileTasks::bExit( void )
 }
 
 //**************************************************************************************************
+// Compare the modification times of the schematic file/s and the netlist file. If the schematic
+// file/s are newer than the netlist a reload operation is required (ie. generate a new netlist file
+// from the schematic file/s).
+//
+// Return Values :
+//   true  - A reload operation is    required
+//   false - A reload operation isn't required
+
+bool  FileTasks::bReloadReqd( void )
+{
+  wxDateTime     oModSchems;
+  wxDateTime     oModNetLst;
+  wxDateTime     oDtTm1;
+  wxFileName     ofn1;
+  wxArrayString  osa1;
+  wxString       os1;
+  size_t         sz1;
+  bool           bRtn;
+
+  // Initialize the file modification time objects
+  oModSchems = wxInvalidDateTime;
+  oModNetLst = wxInvalidDateTime;
+
+  // Determine the lastest modification time for the schematic file/s
+  osa1 = rosaGetSchemFiles( );
+  if( ! osa1.IsEmpty( ) )
+  {
+    for( sz1=0; sz1<osa1.GetCount( ); sz1++ )
+    {
+      ofn1 = osa1.Item( sz1 );
+      oDtTm1 = ofn1.GetModificationTime( );
+      if(    ! oModSchems.IsValid( )              ) oModSchems = oDtTm1;
+      else if( oModSchems.IsEarlierThan( oDtTm1 ) ) oModSchems = oDtTm1;
+    }
+  }
+
+  // Determine the modification time for the netlist file
+  os1 = rosGetNetLstFile( );
+  if( ! os1.IsEmpty( ) )
+  {
+    ofn1 = os1;
+    oModNetLst = ofn1.GetModificationTime( );
+  }
+
+  // Compare the modification times and set the function return value
+  bRtn = false;
+  if( oModSchems.IsValid( ) && oModNetLst.IsValid( ) )
+    if( oModNetLst.IsEarlierThan( oModSchems ) )
+      bRtn = true;
+
+  return( bRtn );
+}
+
+//**************************************************************************************************
