@@ -1,10 +1,10 @@
 //**************************************************************************************************
-//                                          FileTasks.hpp                                          *
-//                                         ---------------                                         *
+//                                         FileTasks.hpp                                           *
+//                                        ---------------                                          *
 // Description : This is a helper class for FrmMain, it handles most of the file operations.       *
 // Started     : 2005-05-28                                                                        *
-// Last Update : 2015-04-01                                                                        *
-// Copyright   : (C) 2005 by MSWaters                                                              *
+// Last Update : 2018-10-28                                                                        *
+// Copyright   : (C) 2005-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -23,6 +23,7 @@
 class FrmMain;
 
 #include "TypeDefs.hpp"
+#include "Config.hpp"
 #include "base/SimnBase.hpp"
 #include "process/PrcGSchem.hpp"
 #include "process/PrcGNetList.hpp"
@@ -37,9 +38,8 @@ class FileTasks
 {
   private :
 
-    FrmMain    * m_poFrmMain;     // Pointer to application main frame
-    wxConfig   * m_poCfg;         // Pointer to global configuration object
-    PrcGNetList  m_oPrcGNetList;  // gnetlist file conversion utility
+    FrmMain    * m_poFrmMain;      // Pointer to application main frame
+    PrcGNetList  m_oPrc_gnetlist;  // Netlist file conversion utility
 
     // Object initialization functions
     void  InitGuileProc ( void );
@@ -53,23 +53,25 @@ class FileTasks
 
   public :
 
-          FileTasks( FrmMain * poFrmMain );
-         ~FileTasks( );
+    explicit  FileTasks( FrmMain * poFrmMain );
+             ~FileTasks( );
 
-    void  Initialize( void ); // This function calls all the initialization fns
+    void  Initialize( void );  // This function calls all the initialization fns
 
     bool  bIsOk_gnetlist( void );
 
     bool  bSetTitle     ( void );
-    bool  bSetGuileProc ( const wxString & rosPName  );
-    bool  bSetSchemFiles( const wxString & rosFNames );
-    bool  bSetNetLstFile( const wxString & rosFName=GNETLST_USE_SCHEM );
-    bool  bSetLogFile   ( const wxString & rosFName  )
-                                               { return( m_oPrcGNetList.bSetLogFile( rosFName ) ); }
+    bool  bSetGuileProc ( const wxString      &  rosProcName  );
+    bool  bSetSchemFiles( const wxString      & roasFileNames );
+    bool  bSetSchemFiles( const wxArrayString & roasFileNames );
+    bool  bSetNetLstFile( const wxString      &  rosFileName=GNETLST_USE_SCHEM );
+    bool  bSetLogFile   ( const wxString      &  rosFileName  )
+                                           { return( m_oPrc_gnetlist.bSetLogFile( rosFileName ) ); }
 
     const wxString      &  rosGetGuileProc ( void );
     const wxArrayString & rosaGetSchemFiles( void );
     const wxString      &  rosGetNetLstFile( void );
+    const wxString      &  rosGetLogFile   ( void );
 
     bool  bDlgOpen    ( void );
     bool  bDlgImport  ( void );
@@ -80,6 +82,11 @@ class FileTasks
     bool  bReload( void );
     bool  bClose ( void );
     bool  bExit  ( void );
+
+    bool  bReloadReqd( void );
+
+    // Declare friend classes
+    friend  class  FrmMain;
 };
 
 //**************************************************************************************************
