@@ -2,8 +2,8 @@
 //                                          HelpTasks.cpp                                          *
 //                                         ---------------                                         *
 //  Started     : 2005-06-03                                                                       *
-//  Last Update : 2015-01-28                                                                       *
-//  Copyright   : (C) 2005 by MSWaters                                                             *
+//  Last Update : 2018-10-16                                                                       *
+//  Copyright   : (C) 2005-2018 MSWaters                                                           *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -30,11 +30,11 @@
 
 wxBEGIN_EVENT_TABLE( HelpTasks, wxFrame )
 
-  EVT_TOOL( HelpTasks::ID_TBR_FORWARD, HelpTasks::OnForward )
-  EVT_TOOL( HelpTasks::ID_TBR_BACK   , HelpTasks::OnBack    )
-  EVT_TOOL( HelpTasks::ID_TBR_CLOSE  , HelpTasks::OnClose   )
+  EVT_TOOL( HelpTasks::ID_TBR_FORWD, HelpTasks::OnToolForwd )
+  EVT_TOOL( HelpTasks::ID_TBR_BCKWD, HelpTasks::OnToolBckwd )
+  EVT_TOOL( HelpTasks::ID_TBR_CLOSE, HelpTasks::OnToolClose )
 
-  EVT_CLOSE(                           HelpTasks::OnClose   )
+  EVT_CLOSE(                         HelpTasks::OnFrmClose  )
 
 wxEND_EVENT_TABLE( )
 
@@ -45,16 +45,13 @@ wxEND_EVENT_TABLE( )
 //   poFrmMain - A pointer to the parent frame
 
 HelpTasks::HelpTasks( FrmMain * poFrmMain ) :
-                  wxFrame( poFrmMain, -1, wxT(""), wxDefaultPosition,
-                           wxDefaultSize, wxDEFAULT_FRAME_STYLE ),
-                  m_oHtmlWin( this )
+                      wxFrame( poFrmMain, -1, wxT(""), wxDefaultPosition, wxDefaultSize,
+                               wxDEFAULT_FRAME_STYLE ),
+                      m_oHtmlWin( this )
 {
   // Set the pointer to the parent frame
   m_poFrmMain = poFrmMain;
 
-  // Get the global configuration object
-  m_poCfg = (wxConfig *) wxConfig::Get( );
-
   // Initialize the help viewer
   Initialize( );
 }
@@ -78,9 +75,41 @@ void  HelpTasks::Initialize( void )
   SetTitle( );
 
   // Call all the initialization functions
-  InitToolBar( );
-  InitHtmlWin( );
+  InitInstPath( );
+  InitToolBar ( );
+  InitHtmlWin ( );
   InitPosnSize( );
+
+  // Reduce the standard fonts sizes a bit
+  m_oHtmlWin.SetStandardFonts( -1 );
+}
+
+//**************************************************************************************************
+// Determine the path to the applications base installation path.
+
+void  HelpTasks::InitInstPath( void )
+{
+  wxPathList  opl1;
+  wxFileName  ofn1;
+  wxString    os1;
+
+  // Get the command used to envoke this process
+  ofn1 = wxTheApp->argv[ 0 ];
+
+  if( ! ofn1.GetPath( ).IsEmpty( ) )
+  { // Extract the desired part of the path
+    ofn1.Normalize( );  // Expand abbreviations eg. "..", "~', etc.
+  }
+  else
+  { // Search env. var. PATH for the first occurrence of the app. name
+    opl1.AddEnvList( wxT("PATH") );
+    os1 = opl1.FindAbsoluteValidPath( ofn1.GetFullName( ) );
+    ofn1 = os1;
+  }
+
+  m_rosInstallPath = ofn1.GetPath( );
+  if( m_rosInstallPath.AfterLast( wxT('/') ) == wxT("bin") )
+    m_rosInstallPath = m_rosInstallPath.BeforeLast( wxT('/') );
 }
 
 //**************************************************************************************************
@@ -100,12 +129,9 @@ void  HelpTasks::InitToolBar( void )
   poPixMap[ 2 ] = new wxBitmap( html_close_xpm   );
 
   // Add the tools to the toolbar
-  poToolBar->AddTool( ID_TBR_BACK   , wxT(""), *(poPixMap[ 0 ]),
-                      wxT("Back") );
-  poToolBar->AddTool( ID_TBR_FORWARD, wxT(""), *(poPixMap[ 1 ]),
-                      wxT("Forward") );
-  poToolBar->AddTool( ID_TBR_CLOSE  , wxT(""), *(poPixMap[ 2 ]),
-                      wxT("Close") );
+  poToolBar->AddTool( ID_TBR_BCKWD, wxT(""), *(poPixMap[ 0 ]), wxT("Back")    );
+  poToolBar->AddTool( ID_TBR_FORWD, wxT(""), *(poPixMap[ 1 ]), wxT("Forward") );
+  poToolBar->AddTool( ID_TBR_CLOSE, wxT(""), *(poPixMap[ 2 ]), wxT("Close")   );
 
   // Realize the toolbar
   poToolBar->Realize( );
@@ -132,54 +158,17 @@ void  HelpTasks::InitHtmlWin( void )
 
 void  HelpTasks::InitPosnSize( void )
 {
-  int  ix, iy, iw, ih;
+  int  iPosnX, iPosnY, iSizeW, iSizeH;
 
-  // Set the position and size from the configuration object
-  m_poCfg->SetPath( wxT("/Help") );
-  ix = m_poCfg->Read( wxT("PosnX"), 500 );
-  iy = m_poCfg->Read( wxT("PosnY"),   1 );
-  iw = m_poCfg->Read( wxT("SizeW"), 500 );
-  ih = m_poCfg->Read( wxT("SizeH"), 700 );
+  // Get the position and size from the configuration object
+  iPosnX = g_oConfig.iGetHelpPosnX( );
+  iPosnY = g_oConfig.iGetHelpPosnY( );
+  iSizeW = g_oConfig.iGetHelpSizeW( );
+  iSizeH = g_oConfig.iGetHelpSizeH( );
 
-  if( ix>0 && iy>0 ) Move( ix, iy );
-  if( iw>0 && ih>0 ) SetClientSize( iw, ih );
-}
-
-//**************************************************************************************************
-// Determine the path to the applications base installation point.
-//
-// Return Values :
-//   Success - The path to the installation point
-//   Failure - An empty string
-
-wxString & HelpTasks::rosGetInstallPath( void )
-{
-  static  wxString  osPath;
-  wxPathList  opl1;
-  wxFileName  ofn1;
-  wxString    os1;
-
-  osPath.Empty( );
-
-  // Get the command used to envoke this process
-  ofn1 = wxTheApp->argv[ 0 ];
-
-  if( ! ofn1.GetPath( ).IsEmpty( ) )
-  { // Extract the desired part of the path
-    ofn1.Normalize( );  // Expand abbreviations eg. "..", "~', etc.
-  }
-  else
-  { // Search env. var. PATH for the first occurrence of the app. name
-    opl1.AddEnvList( wxT("PATH") );
-    os1 = opl1.FindAbsoluteValidPath( ofn1.GetFullName( ) );
-    ofn1 = os1;
-  }
-
-  osPath = ofn1.GetPath( );
-  if( osPath.AfterLast( wxT('/') ) == wxT("bin") )
-    osPath = osPath.BeforeLast( wxT('/') );
-
-  return( osPath );
+  // Set the position and size
+  if( iPosnX>0 && iPosnY>0 ) Move( iPosnX, iPosnY );
+  if( iSizeW>0 && iSizeH>0 ) SetClientSize( iSizeW, iSizeH );
 }
 
 //**************************************************************************************************
@@ -209,10 +198,9 @@ void  HelpTasks::ManualUser( void )
   if( m_oHtmlWin.GetOpenedPage( ).IsEmpty( ) )
   {
     // Specify the two locations to search
-    os1 = rosGetInstallPath( );
-    if( os1.IsEmpty( ) ) return;
-    ofn1 = os1 + wxT("/share/gspiceui/html/User-Manual.html");
-    ofn2 = os1 + wxT("/html/User-Manual.html");
+    if( m_rosInstallPath.IsEmpty( ) ) return;
+    ofn1 = m_rosInstallPath + wxT("/share/gspiceui/html/User-Manual.html");
+    ofn2 = m_rosInstallPath + wxT("/html/User-Manual.html");
 
     // Search for the manual
     if(      ofn1.FileExists( ) ) os1 = ofn1.GetFullPath( );
@@ -249,7 +237,7 @@ void  HelpTasks::About( void )
   os1 << wxT("\n                                     " ) << APP_NAME
       << wxT("\n                     Version ")          << APP_VERSION
                                             << wxT(" (") << APP_DATE << wxT(")")
-      << wxT("\n                    ")                   << APP_COPYRIGHT
+      << wxT("\n               ")                        << APP_COPYRIGHT
       << wxT("\n\n")
 
       << wxT("\nThis application is intended to provide a GUI for various")
@@ -258,13 +246,13 @@ void  HelpTasks::About( void )
       << wxT("\n                 - GNU-Cap\n")
 
       << wxT("\nSchematic files are imported using gnetlist and waveform     ")
-      << wxT("\ndata can be viewed using either ") << CLP_GWAVE << wxT(" or ")
-      << CLP_GAW << wxT(".\n")
+      << wxT("\ndata can be viewed using either ") << rosEnumEngToStr( eSIMR_NGSPICE )
+      << wxT(" or ") << rosEnumEngToStr( eSIMR_GNUCAP ) << wxT(".\n")
 
       << wxT("\nThis application is written in C++ and uses the wxWidgets")
       << wxT("\nlibrary which is a free and open source widget toolkit and")
       << wxT("\ntools library. wxWidgets version ")
-      << wxMAJOR_VERSION << '.' << wxMINOR_VERSION << '.' << wxRELEASE_NUMBER
+      << wxMAJOR_VERSION << wxT('.') << wxMINOR_VERSION << wxT('.') << wxRELEASE_NUMBER
       << wxT(" was used in this")
       << wxT("\nbuild of ") << APP_NAME << wxT(".\n")
 
@@ -290,7 +278,7 @@ void  HelpTasks::About( void )
 // Argument List :
 //   roEvtCmd - The event to be processed
 
-void  HelpTasks::OnForward( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  HelpTasks::OnToolForwd( wxCommandEvent & roEvtCmd )
 {
   if( m_oHtmlWin.HistoryCanForward( ) )
     m_oHtmlWin.HistoryForward( );
@@ -302,7 +290,7 @@ void  HelpTasks::OnForward( wxCommandEvent & WXUNUSED( roEvtCmd ) )
 // Argument List :
 //   roEvtCmd - The event to be processed
 
-void  HelpTasks::OnBack( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  HelpTasks::OnToolBckwd( wxCommandEvent & roEvtCmd )
 {
   if( m_oHtmlWin.HistoryCanBack( ) )
     m_oHtmlWin.HistoryBack( );
@@ -314,21 +302,21 @@ void  HelpTasks::OnBack( wxCommandEvent & WXUNUSED( roEvtCmd ) )
 // Argument List :
 //   roEvtCmd - The event to be processed
 
-void  HelpTasks::OnClose( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  HelpTasks::OnToolClose( wxCommandEvent & roEvtCmd )
 {
-  int  ix, iy, iw, ih;
+  int  iPosnX, iPosnY, iSizeW, iSizeH;
 
   // Save the frame size and position
-  GetPosition( &ix, &iy );
-  GetClientSize( &iw, &ih );
-  m_poCfg->SetPath( wxT("/Help") );
-  m_poCfg->Write( wxT("PosnX"), (long) ix );
-  m_poCfg->Write( wxT("PosnY"), (long) iy );
-  m_poCfg->Write( wxT("SizeW"), (long) iw );
-  m_poCfg->Write( wxT("SizeH"), (long) ih );
-  m_poCfg->Flush( );
+  GetPosition( &iPosnX, &iPosnY );
+  GetClientSize( &iSizeW, &iSizeH );
+  g_oConfig.bSetHelpPosnX( iPosnX );
+  g_oConfig.bSetHelpPosnY( iPosnY );
+  g_oConfig.bSetHelpSizeW( iSizeW );
+  g_oConfig.bSetHelpSizeH( iSizeH );
 
-  Show( false );  // Hide the frame
+  g_oConfig.bFlush( );  // Write changes to the configuration file
+
+  Show( false );        // Hide the frame
 
   // Reset the HTML Window settings
   while( m_oHtmlWin.HistoryCanBack( ) )
@@ -343,11 +331,11 @@ void  HelpTasks::OnClose( wxCommandEvent & WXUNUSED( roEvtCmd ) )
 // Argument List :
 //   roEvtClose - The event to be processed
 
-void  HelpTasks::OnClose( wxCloseEvent & WXUNUSED( roEvtClose ) )
+void  HelpTasks::OnFrmClose( wxCloseEvent & roEvtClose )
 {
   wxCommandEvent  oEvtCmd;
 
-  OnClose( oEvtCmd );
+  OnToolClose( oEvtCmd );
 }
 
 //**************************************************************************************************
