@@ -3,7 +3,7 @@
 //                                        ----------------                                         *
 // Started     : 2005-06-14                                                                        *
 // Last Update : 2015-04-01                                                                        *
-// Copyright   : (C) 2005 by MSWaters                                                              *
+// Copyright   : (C) 2005-2016 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -226,7 +226,7 @@ bool  NbkTxtCtls::bSetPosn( long liPosn )
   if( ! bIsCreated( ) )  return( false );
 
   // Get a pointer to the currently displayed page
-  poTxtCtl = (TextCtrl *) GetCurrentPage( );
+  poTxtCtl = static_cast<TextCtrl *>( GetCurrentPage( ) );
 
   if( poTxtCtl == NULL ) return( false );
 
@@ -285,7 +285,7 @@ TextCtrl * NbkTxtCtls::poGetPage( NbkTxtCtls::ePageType ePage )
   if( GetPageCount( ) < ((size_t) ePage + 1) ) return( NULL );
 
   // Return a pointer to the requested page
-  return( (TextCtrl *) GetPage( (size_t) ePage ) );
+  return( static_cast<TextCtrl *>( GetPage( (size_t) ePage ) ) );
 }
 
 //**************************************************************************************************
