@@ -4,8 +4,8 @@
 // Description : This class extends wxNotebook, it contains all text control objects which appear  *
 //               at the bottom of the GUI.                                                         *
 // Started     : 2005-06-14                                                                        *
-// Last Update : 2015-04-01                                                                        *
-// Copyright   : (C) 2005 by MSWaters                                                              *
+// Last Update : 2018-10-08                                                                        *
+// Copyright   : (C) 2005-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -28,6 +28,13 @@
 
 #include <wx/notebook.h>
 
+// Local Constant Declarations
+
+#ifndef LAYOUT_MNGR
+  #define  NBKTXTCTLS_WIDTH   572
+  #define  NBKTXTCTLS_HEIGHT  179
+#endif // LAYOUT_MNGR
+
 //**************************************************************************************************
 
 class NbkTxtCtls : public wxNotebook
@@ -54,7 +61,7 @@ class NbkTxtCtls : public wxNotebook
           NbkTxtCtls( void );
          ~NbkTxtCtls( );
 
-    bool  bCreate( wxWindow * poWin, wxWindowID oWinID );
+    bool  bCreate   ( wxWindow * poWin, wxWindowID oWinID );
     bool  bIsCreated( void ) { return( GetParent( )!=NULL ? true : false ); }
 
     bool  bClear     ( ePageType ePage=ePAGE_ALL );
