@@ -2,8 +2,8 @@
 //                                         NbkNgSpice.cpp                                          *
 //                                        ----------------                                         *
 // Started     : 2004-05-08                                                                        *
-// Last Update : 2015-03-20                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-10-17                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -36,17 +36,17 @@ wxEND_EVENT_TABLE( )
 //   roPosn   - The notebook position
 //   roSize   - The notebook size
 
-NbkNgSpice::NbkNgSpice( wxWindow * poParent, wxWindowID oWinID ) :
-                      NbkSimEngBase( poParent, oWinID ), m_oDlgCfgOPT( poParent )
+NbkNgSpice::NbkNgSpice( wxWindow * poParent, wxWindowID oWinID )
+                      : NbkSimEngBase( poParent, oWinID ), m_oDlgCfgOPT( poParent )
 {
   // Set the simulator engine type specifier
   m_eSimEng = eSIMR_NGSPICE;
 
   // Create the various display objects
+  m_poPnlNgSpiceOP = new PnlNgSpiceOP( this );
   m_poPnlNgSpiceDC = new PnlNgSpiceDC( this );
   m_poPnlNgSpiceAC = new PnlNgSpiceAC( this );
   m_poPnlNgSpiceTR = new PnlNgSpiceTR( this );
-  m_poPnlNgSpiceOP = new PnlNgSpiceOP( this );
 
   // Add the display objects to the note book
   AddPage( m_poPnlNgSpiceOP, wxT( " Quiescent  "     ) );
@@ -106,8 +106,6 @@ bool  NbkNgSpice::bLoad( const SimnBase & roSimn )
 
   if( roSimn.eGetSimEng( ) != eSIMR_NGSPICE )            return( false );
 
-  PnlAnaBase::m_oCpntSwpSrc = roSimn.m_oCpntSwpSrc;
-
   SimnNgSpice & roSimnNgs = (SimnNgSpice &) roSimn;
 
   if( ! bSetPage( roSimnNgs.eGetAnaType( ) ) )           bRtn = false;
@@ -309,55 +307,88 @@ eTypeCmd  NbkNgSpice::eGetPage( void )
 
 void  NbkNgSpice::OnPageChangd( wxNotebookEvent & roEvtNbk )
 {
-  PnlAnaBase * poPnlAna;
+  PnlAnaBase * poPnlOld=NULL;
+  PnlAnaBase * poPnlNew=NULL;
   wxString     os1;
   int          i1;
 
-  // Transfer the ambient temperature from the previous page to OPTIONS dialog
+  // Get pointers to the old and new (current) analysis panels
   i1 = roEvtNbk.GetOldSelection( );
-  if( i1 != -1 )
+  if( i1 != wxNOT_FOUND ) poPnlOld = static_cast< PnlAnaBase * >( GetPage( (size_t) i1 ) );
+  poPnlNew = static_cast< PnlAnaBase * >( GetCurrentPage( ) );
+
+  // Synchronize the ambient temperature values between the different analysis pages
+  if( g_oConfig.bGetSyncTemps( ) )
   {
-    poPnlAna = (PnlAnaBase *) GetPage( (size_t) i1 );
-    if( poPnlAna->m_oPnlTemp.GetParent( ) != NULL )
+    // Transfer the ambient temperature from the previous page to the OPTIONS dialog
+    if( poPnlOld != NULL )
     {
-      os1 = poPnlAna->m_oPnlTemp.rosGetValue( );
-      m_oDlgCfgOPT.bSetValue( DlgNgsCfgOPT::ID_PNL_TEMP, os1 );
+      if( poPnlOld->m_oPnlTemp.GetParent( ) != NULL )
+      {
+        os1 = poPnlOld->m_oPnlTemp.rosGetValue( );
+        m_oDlgCfgOPT.bSetValue( DlgNgSpiceCfgOPT::ID_PNL_TEMP, os1 );
+      }
+    }
+
+    // Transfer the ambient temperature from the OPTIONS dialog to current page
+    if( poPnlNew->m_oPnlTemp.GetParent( ) != NULL )
+    {
+      os1 = m_oDlgCfgOPT.rosGetValue( DlgNgSpiceCfgOPT::ID_PNL_TEMP );
+      poPnlNew->m_oPnlTemp.bSetValue( os1 );
     }
   }
 
-  // Transfer the ambient temperature from the OPTIONS dialog to current page
-  poPnlAna = (PnlAnaBase *) GetCurrentPage( );
-  if( poPnlAna->m_oPnlTemp.GetParent( ) != NULL )
+  // Record the signal source value from the old panel
+  if( poPnlOld != NULL )
   {
-    os1 = m_oDlgCfgOPT.rosGetValue( DlgNgsCfgOPT::ID_PNL_TEMP );
-    poPnlAna->m_oPnlTemp.bSetValue( os1 );
+    if( poPnlOld->m_oChoSrcName.GetSelection( ) > 0 )
+    {
+      m_oCpntSigSrc.bSetName( poPnlOld->m_oChoSrcName.GetStringSelection( ) );
+      if( poPnlOld->m_oPnlSrcLvl.GetParent( ) != NULL )
+      {
+        os1 = poPnlOld->m_oPnlSrcLvl.rosGetValue( );
+        m_oCpntSigSrc.bSetValue( os1 );
+      }
+      else if( poPnlOld->eGetAnalysType( ) == eCMD_TR )
+      {
+        os1 = m_poPnlNgSpiceTR->m_oDlgCfgSrc.rosGetValue( DlgNgSpiceCfgSrc::ID_PNL_SIN_AMP );
+        m_oCpntSigSrc.bSetValue( os1 );
+      }
+    }
+    else m_oCpntSigSrc.bClear( );
   }
 
-  // Synchronize the sweep sources between the different analysis pages
-  if( m_bSyncSwpSrcs )
+  // Synchronize the signal sources between the old and new analysis pages
+  if( g_oConfig.bGetSyncSigSrcs( ) )
   {
-    os1 = poPnlAna->m_oCpntSwpSrc.rosGetName( );
+    os1 = m_oCpntSigSrc.rosGetName( );
 
-    if( poPnlAna->m_oChoSrcName.SetStringSelection( os1 ) )
-    { // Set the sweep source value if it's been defined
-      if( poPnlAna->m_oPnlSrcLvl.GetParent( ) != NULL )
+    if( poPnlNew->m_oChoSrcName.SetStringSelection( os1 ) )
+    { // Set the signal source value if it's been defined
+      if( poPnlNew->m_oPnlSrcLvl.GetParent( ) != NULL )
       {
-        poPnlAna->m_oPnlSrcLvl.bSetUnitsType( poPnlAna->m_oCpntSwpSrc.eGetUnitsType( ) );
-        poPnlAna->m_oPnlSrcLvl.bSetValue( poPnlAna->m_oCpntSwpSrc.rosGetValue( ) );
+        poPnlNew->m_oPnlSrcLvl.bSetUnitsType( m_oCpntSigSrc.eGetUnitsType( ) );
+        poPnlNew->m_oPnlSrcLvl.bSetValue( m_oCpntSigSrc.rosGetValue( ) );
+      }
+      else if( poPnlNew->eGetAnalysType( ) == eCMD_TR )
+      {
+        poPnlNew->m_oPnlSrcLvl.bSetUnitsType( m_oCpntSigSrc.eGetUnitsType( ) );
+        os1 = m_oCpntSigSrc.rosGetValue( );
+        m_poPnlNgSpiceTR->m_oDlgCfgSrc.bSetValue( DlgNgSpiceCfgSrc::ID_PNL_SIN_AMP, os1 );
       }
     }
     else
-    { // Couldn't set the sweep source name so clear it
-      poPnlAna->m_oChoSrcName.SetSelection( 0 );
-      if( poPnlAna->m_oPnlSrcLvl.GetParent( ) != NULL )
+    { // Couldn't set the signal source name so clear it
+      poPnlNew->m_oChoSrcName.SetSelection( 0 );
+      if( poPnlNew->m_oPnlSrcLvl.GetParent( ) != NULL )
       {
-        poPnlAna->m_oPnlSrcLvl.bSetUnitsType( eUNITS_NONE );
-        poPnlAna->m_oPnlSrcLvl.bSetValue( 0.0 );
+        poPnlNew->m_oPnlSrcLvl.bSetUnitsType( eUNITS_NONE );
+        poPnlNew->m_oPnlSrcLvl.bSetValue( 0.0 );
       }
     }
 
-    // Update the sweep parameter units
-    if( poPnlAna->eGetAnalysType( ) == eCMD_DC )
+    // Update the signal parameter units
+    if( poPnlNew->eGetAnalysType( ) == eCMD_DC )
       m_poPnlNgSpiceDC->OnSrcName( (wxCommandEvent &) roEvtNbk );
   }
 
@@ -371,21 +402,21 @@ void  NbkNgSpice::OnPageChangd( wxNotebookEvent & roEvtNbk )
 // Argument List :
 //   roEvtCmd - An object holding information about the event
 
-void  NbkNgSpice::OnBtnOptions( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  NbkNgSpice::OnBtnOptions( wxCommandEvent & roEvtCmd )
 {
   PnlAnaBase * poPnlAna;
   wxString     os1;
   int          i1;
 
   // Get a pointer to the currently displayed analysis page
-  poPnlAna = (PnlAnaBase *) GetCurrentPage( );
+  poPnlAna = static_cast< PnlAnaBase * >( GetCurrentPage( ) );
   if( poPnlAna == NULL ) return;
 
   // Set the temperature in the OPTIONS dialog
   if( poPnlAna->m_oPnlTemp.GetParent( ) != NULL )
   {
     os1 = poPnlAna->m_oPnlTemp.rosGetValue( );
-    m_oDlgCfgOPT.bSetValue( DlgNgsCfgOPT::ID_PNL_TEMP, os1 );
+    m_oDlgCfgOPT.bSetValue( DlgNgSpiceCfgOPT::ID_PNL_TEMP, os1 );
   }
 
   // Display the OPTIONS dialog
@@ -396,7 +427,7 @@ void  NbkNgSpice::OnBtnOptions( wxCommandEvent & WXUNUSED( roEvtCmd ) )
   // Set the temperature in the current analysis panel
   if( poPnlAna->m_oPnlTemp.GetParent( ) != NULL )
   {
-    os1 = m_oDlgCfgOPT.rosGetValue( DlgNgsCfgOPT::ID_PNL_TEMP );
+    os1 = m_oDlgCfgOPT.rosGetValue( DlgNgSpiceCfgOPT::ID_PNL_TEMP );
     poPnlAna->m_oPnlTemp.bSetValue( os1 );
   }
 }
