@@ -4,8 +4,8 @@
 // Description : Provides a container class for the analysis configuration panels for the          *
 //               different analyses provided by NG-Spice electronic circuit simulator.             *
 // Started     : 2004-05-08                                                                        *
-// Last Update : 2015-01-12                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-10-03                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -22,8 +22,9 @@
 // Application Includes
 
 #include "TypeDefs.hpp"
+#include "Config.hpp"
 #include "base/NbkSimEngBase.hpp"
-#include "ngspice/dialogs/DlgNgsCfgOPT.hpp"
+#include "ngspice/dialogs/DlgNgSpiceCfgOPT.hpp"
 #include "ngspice/panels/PnlNgSpiceOP.hpp"
 #include "ngspice/panels/PnlNgSpiceDC.hpp"
 #include "ngspice/panels/PnlNgSpiceAC.hpp"
@@ -43,30 +44,34 @@ class NbkNgSpice : public NbkSimEngBase
 //  PnlNgSpiceFO * m_poPnlNgSpiceFO;
 
     // OPTIONS line setup dialog
-    DlgNgsCfgOPT   m_oDlgCfgOPT;
+    DlgNgSpiceCfgOPT   m_oDlgCfgOPT;
 
   public :
 
           NbkNgSpice( wxWindow * poParent, wxWindowID oWinID );
          ~NbkNgSpice( );
 
-    bool  bClear( void );
+    bool  bClear( void ) override;
 
-    bool  bLoad( const SimnBase & roSimn );
-    bool  bSave(       SimnBase & roSimn );
+    bool  bLoad( const SimnBase & roSimn ) override;
+    bool  bSave(       SimnBase & roSimn ) override;
 
-    bool  bSetPage(       eTypeCmd     eAnalysis );
-    bool  bSetPage( const wxString & rosAnalysis );
+    bool  bSetPage(       eTypeCmd     eAnalysis ) override;
+    bool  bSetPage( const wxString & rosAnalysis ) override;
 
-    const  wxString & rosGetPage( void );
-           eTypeCmd     eGetPage( void );
+    const  wxString & rosGetPage( void ) override;
+           eTypeCmd     eGetPage( void ) override;
 
     // Event handlers
     void  OnPageChangd( wxNotebookEvent & roEvtNbk );
     void  OnBtnOptions( wxCommandEvent  & roEvtCmd );
 
     // Leave this as the last line as private access is envoked by macro
+#if wxCHECK_VERSION( 3,0,0 )
     wxDECLARE_EVENT_TABLE( );
+#else
+    wxDECLARE_EVENT_TABLE( )
+#endif
 };
 
 //**************************************************************************************************
