@@ -2,8 +2,8 @@
 //                                        CmdNgSpiceAC.cpp                                         *
 //                                       ------------------                                        *
 // Started     : 2007-10-11                                                                        *
-// Last Update : 2014-12-12                                                                        *
-// Copyright   : (C) 2007 by MSWaters                                                              *
+// Last Update : 2018-09-25                                                                        *
+// Copyright   : (C) 2007-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -19,7 +19,7 @@
 //**************************************************************************************************
 // Constructor.
 
-CmdNgSpiceAC::CmdNgSpiceAC( void )
+CmdNgSpiceAC::CmdNgSpiceAC( void ) : CmdBase( )
 {
   bSetDefaults( );
 }
