@@ -4,8 +4,8 @@
 // Description : This class contains values associated with the NG-Spice AC command. It inherits   *
 //               from the class CmdBase.                                                           *
 // Started     : 2007-10-11                                                                        *
-// Last Update : 2015-03-07                                                                        *
-// Copyright   : (C) 2007 by MSWaters                                                              *
+// Last Update : 2018-09-23                                                                        *
+// Copyright   : (C) 2007-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -34,7 +34,7 @@ class CmdNgSpiceAC : public CmdBase
 {
   private :
 
-    virtual  bool  bValidate( void );
+    bool  bValidate( void ) override;
 
   public :
 
@@ -43,17 +43,17 @@ class CmdNgSpiceAC : public CmdBase
     wxString    m_osStep;   // The sweep step  value
     eTypeScale  m_eScale;   // The sweep scale type
 
-                   CmdNgSpiceAC( void );
-    virtual       ~CmdNgSpiceAC( );
+          CmdNgSpiceAC( void );
+         ~CmdNgSpiceAC( );
 
-    virtual  bool  bSetDefaults( void );
+    bool  bSetDefaults( void ) override;
 
-    virtual  bool  bParse ( void );
-    virtual  bool  bFormat( void );
+    bool  bParse ( void ) override;
+    bool  bFormat( void ) override;
 
     CmdNgSpiceAC & operator = ( const CmdGnuCapAC & roCmdAC );
 
-             void  Print( const wxString & rosPrefix=wxT("  ") );
+    void  Print( const wxString & rosPrefix=wxT("  ") ) override;
 };
 
 //**************************************************************************************************
