@@ -2,8 +2,8 @@
 //                                        CmdNgSpiceDC.cpp                                         *
 //                                       ------------------                                        *
 // Started     : 2007-08-21                                                                        *
-// Last Update : 2014-12-12                                                                        *
-// Copyright   : (C) 2007 by MSWaters                                                              *
+// Last Update : 2018-09-25                                                                        *
+// Copyright   : (C) 2007-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -19,7 +19,7 @@
 //**************************************************************************************************
 // Constructor.
 
-CmdNgSpiceDC::CmdNgSpiceDC( void )
+CmdNgSpiceDC::CmdNgSpiceDC( void ) : CmdBase( )
 {
   bSetDefaults( );
 }
@@ -47,15 +47,14 @@ bool  CmdNgSpiceDC::bValidate( void )
   // Check the sweep start and stop values
   if( ! CnvtType::bStrToFlt( m_osStart, &df1 ) ) SetErrMsg( wxT("Invalid sweep start value.") );
   if( ! CnvtType::bStrToFlt( m_osStop,  &df2 ) ) SetErrMsg( wxT("Invalid sweep stop value.") );
-  if( df2 < df1 )                                SetErrMsg( wxT("Start value greater than stop value.") );
 
   // Check the sweep step value and sweep scale
-  if( ! CnvtType::bStrToFlt( m_osStep, &df3 ) )  SetErrMsg( wxT("Invalid sweep step value.") );
-  if( df3 <= 0.0 )                               SetErrMsg( wxT("Step value less than or equal to zero.") );
+  if( ! CnvtType::bStrToFlt( m_osStep,  &df3 ) ) SetErrMsg( wxT("Invalid sweep step value.") );
+  if( df3 == 0.0 )                               SetErrMsg( wxT("Step value equal to zero.") );
 
   // Check the component to be used as the sweep source
   if( m_osSource.IsEmpty( ) && m_osSource!=wxT("TEMP") )
-                                                 SetErrMsg( wxT("No source component has been selected.") );
+    SetErrMsg( wxT("No source component has been selected.") );
 
   return( bIsValid( ) );
 }
@@ -128,6 +127,7 @@ bool  CmdNgSpiceDC::bParse( void )
 
   // Extract the step increment
   os1 = ostk1.GetNextToken( );
+  if( os1.GetChar( 0 ) == wxT('-') ) os1 = os1.Mid( 1 );
   if( CnvtType::bStrToFlt( os1, &df1 ) ) m_osStep  = os1;
   else                            return( bValidate( ) );
 
@@ -144,6 +144,7 @@ bool  CmdNgSpiceDC::bParse( void )
 bool  CmdNgSpiceDC::bFormat( void )
 {
   wxString  osCmd;
+  double    df1, df2;
 
   // Set the command name
   osCmd = wxT(".DC");
@@ -154,7 +155,12 @@ bool  CmdNgSpiceDC::bFormat( void )
   // Set sweep parameters
   osCmd << wxT(' ') << m_osStart;
   osCmd << wxT(' ') << m_osStop;
-  osCmd << wxT(' ') << m_osStep;
+  osCmd << wxT(' ');
+  if( CnvtType::bStrToFlt( m_osStart, &df1 ) && CnvtType::bStrToFlt( m_osStop, &df2 ) )
+    if( df1 > df2 )
+      osCmd << wxT('-');
+  osCmd             << m_osStep;
+
 
   assign( osCmd );
 
