@@ -4,8 +4,8 @@
 // Description : This class contains values associated with the NG-Spice DC command. It inherits   *
 //               from the class CmdBase.                                                           *
 // Started     : 2006-08-23                                                                        *
-// Last Update : 2015-03-07                                                                        *
-// Copyright   : (C) 2006 by MSWaters                                                              *
+// Last Update : 2018-09-23                                                                        *
+// Copyright   : (C) 2006-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -36,7 +36,7 @@ class CmdNgSpiceDC : public CmdBase
 {
   private :
 
-    virtual  bool  bValidate( void );
+    bool  bValidate( void ) override;
 
   public :
 
@@ -45,18 +45,18 @@ class CmdNgSpiceDC : public CmdBase
     wxString  m_osStep;    // Sweep step  value
     wxString  m_osSource;  // Sweep source
 
-                   CmdNgSpiceDC( void );
-    virtual       ~CmdNgSpiceDC( );
+             CmdNgSpiceDC( void );
+            ~CmdNgSpiceDC( );
 
-    virtual  bool  bSetDefaults( void );
+    bool  bSetDefaults( void ) override;
 
-    virtual  bool  bParse ( void );
-    virtual  bool  bFormat( void );
+    bool  bParse ( void ) override;
+    bool  bFormat( void ) override;
 
     CmdNgSpiceDC & operator = ( const CmdGnuCapOP & roCmdOP );
     CmdNgSpiceDC & operator = ( const CmdGnuCapDC & roCmdDC );
 
-             void  Print( const wxString & rosPrefix=wxT("  ") );
+    void  Print( const wxString & rosPrefix=wxT("  ") ) override;
 };
 
 //**************************************************************************************************
