@@ -2,8 +2,8 @@
 //                                        CmdNgSpiceOPT.cpp                                        *
 //                                       -------------------                                       *
 // Started     : 2006-08-23                                                                        *
-// Last Update : 2015-01-05                                                                        *
-// Copyright   : (C) 2006 by MSWaters                                                              *
+// Last Update : 2018-11-12                                                                        *
+// Copyright   : (C) 2006-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -19,7 +19,7 @@
 //**************************************************************************************************
 // Constructor.
 
-CmdNgSpiceOPT::CmdNgSpiceOPT( void )
+CmdNgSpiceOPT::CmdNgSpiceOPT( void ) : CmdBase( )
 {
   bSetDefaults( );
 }
@@ -422,46 +422,46 @@ CmdNgSpiceOPT & CmdNgSpiceOPT::operator = ( const CmdGnuCapOPT & roCmdOPT )
 {
   (CmdBase &) *this = (CmdBase &) roCmdOPT;
 
-  if( m_osABSTOL   != NGS_ABSTOL   ) m_osABSTOL   = roCmdOPT.m_osABSTOL;
-  if( m_osCHGTOL   != NGS_CHGTOL   ) m_osCHGTOL   = roCmdOPT.m_osCHGTOL;
-//if( m_osCONVABSS != NGS_CONVABSS ) m_osCONVABSS = roCmdOPT.m_osCONVABSS;
-//if( m_osCONVSTEP != NGS_CONVSTEP ) m_osCONVSTEP = roCmdOPT.m_osCONVSTEP;
-  if( m_osDEFAD    != NGS_DEFAD    ) m_osDEFAD    = roCmdOPT.m_osDEFAD;
-  if( m_osDEFAS    != NGS_DEFAS    ) m_osDEFAS    = roCmdOPT.m_osDEFAS;
-  if( m_osDEFL     != NGS_DEFL     ) m_osDEFL     = roCmdOPT.m_osDEFL;
-  if( m_osDEFW     != NGS_DEFW     ) m_osDEFW     = roCmdOPT.m_osDEFW;
-  if( m_osGMIN     != NGS_GMIN     ) m_osGMIN     = roCmdOPT.m_osGMIN;
-//if( m_osRAMPTIME != NGS_RAMPTIME ) m_osRAMPTIME = roCmdOPT.m_osRAMPTIME;
-  if( m_osRELTOL   != NGS_RELTOL   ) m_osRELTOL   = roCmdOPT.m_osRELTOL;
-//if( m_osRSERIES  != NGS_RSERIES  ) m_osRSERIES  = roCmdOPT.m_osRSERIES;
-//if( m_osRSHUNT   != NGS_RSHUNT   ) m_osRSHUNT   = roCmdOPT.m_osRSHUNT;
-  if( m_osTEMP     != NGS_TEMP     ) m_osTEMP     = roCmdOPT.m_osTEMP;
-  if( m_osTNOM     != NGS_TNOM     ) m_osTNOM     = roCmdOPT.m_osTNOM;
-  if( m_osTRTOL    != NGS_TRTOL    ) m_osTRTOL    = roCmdOPT.m_osTRTOL;
-  if( m_osVNTOL    != NGS_VNTOL    ) m_osVNTOL    = roCmdOPT.m_osVNTOL;
+  m_osABSTOL   = roCmdOPT.m_osABSTOL;
+  m_osCHGTOL   = roCmdOPT.m_osCHGTOL;
+//m_osCONVABSS = roCmdOPT.m_osCONVABSS;
+//m_osCONVSTEP = roCmdOPT.m_osCONVSTEP;
+  m_osDEFAD    = roCmdOPT.m_osDEFAD;
+  m_osDEFAS    = roCmdOPT.m_osDEFAS;
+  m_osDEFL     = roCmdOPT.m_osDEFL;
+  m_osDEFW     = roCmdOPT.m_osDEFW;
+  m_osGMIN     = roCmdOPT.m_osGMIN;
+//m_osRAMPTIME = roCmdOPT.m_osRAMPTIME;
+  m_osRELTOL   = roCmdOPT.m_osRELTOL;
+//m_osRSERIES  = roCmdOPT.m_osRSERIES;
+//m_osRSHUNT   = roCmdOPT.m_osRSHUNT;
+  m_osTEMP     = roCmdOPT.m_osTEMP;
+  m_osTNOM     = roCmdOPT.m_osTNOM;
+  m_osTRTOL    = roCmdOPT.m_osTRTOL;
+  m_osVNTOL    = roCmdOPT.m_osVNTOL;
 
-//if( m_osGMINSTEP != NGS_GMINSTEP ) m_osGMINSTEP = roCmdOPT.m_osGMINSTEP;
-  if( m_osITL1     != NGS_ITL1     ) m_osITL1     = roCmdOPT.m_osITL1;
-  if( m_osITL2     != NGS_ITL2     ) m_osITL2     = roCmdOPT.m_osITL2;
-  if( m_osITL3     != NGS_ITL3     ) m_osITL3     = roCmdOPT.m_osITL3;
-  if( m_osITL4     != NGS_ITL4     ) m_osITL4     = roCmdOPT.m_osITL4;
-  if( m_osITL5     != NGS_ITL5     ) m_osITL5     = roCmdOPT.m_osITL5;
-  if( m_osITL6     != NGS_ITL6     ) m_osITL6     = roCmdOPT.m_osITL6;
-//if( m_osMAXEVIT  != NGS_MAXEVIT  ) m_osMAXEVIT  = roCmdOPT.m_osMAXEVIT;
-//if( m_osMAXOPALT != NGS_MAXOPALT ) m_osMAXOPALT = roCmdOPT.m_osMAXOPALT;
-//if( m_osMAXORD   != NGS_MAXORD   ) m_osMAXORD   = roCmdOPT.m_osMAXORD;
-//if( m_osMAXWARNS != NGS_MAXWARNS ) m_osMAXWARNS = roCmdOPT.m_osMAXWARNS;
-//if( m_osSRCSTEPS != NGS_SRCSTEPS ) m_osSRCSTEPS = roCmdOPT.m_osSRCSTEPS;
+//m_osGMINSTEP = roCmdOPT.m_osGMINSTEP;
+  m_osITL1     = roCmdOPT.m_osITL1;
+  m_osITL2     = roCmdOPT.m_osITL2;
+  m_osITL3     = roCmdOPT.m_osITL3;
+  m_osITL4     = roCmdOPT.m_osITL4;
+  m_osITL5     = roCmdOPT.m_osITL5;
+  m_osITL6     = roCmdOPT.m_osITL6;
+//m_osMAXEVIT  = roCmdOPT.m_osMAXEVIT;
+//m_osMAXOPALT = roCmdOPT.m_osMAXOPALT;
+//m_osMAXORD   = roCmdOPT.m_osMAXORD;
+//m_osMAXWARNS = roCmdOPT.m_osMAXWARNS;
+//m_osSRCSTEPS = roCmdOPT.m_osSRCSTEPS;
 
-  if( m_osMETHOD   != NGS_METHOD   ) m_osMETHOD   = roCmdOPT.m_osMETHOD;
+  m_osMETHOD   = roCmdOPT.m_osMETHOD;
 
-//if( m_bBADMOS3   != NGS_BADMOS3  ) m_bBADMOS3   = roCmdOPT.m_bBADMOS3;
-//if( m_bINTERP    != NGS_INTERP   ) m_bINTERP    = roCmdOPT.m_bINTERP;
-//if( m_bNOOPAC    != NGS_NOOPAC   ) m_bNOOPAC    = roCmdOPT.m_bNOOPAC;
-//if( m_bNOOPALT   != NGS_NOOPALT  ) m_bNOOPALT   = roCmdOPT.m_bNOOPALT;
-  if( m_bOPTS      != NGS_OPTS     ) m_bOPTS      = roCmdOPT.m_bOPTS;
-//if( m_bTRYTOCOM  != NGS_TRYTOCOM ) m_bTRYTOCOM  = roCmdOPT.m_bTRYTOCOM;
-//if( m_bWARN      != NGS_WARN     ) m_bWARN      = roCmdOPT.m_bWARN;
+//m_bBADMOS3   = roCmdOPT.m_bBADMOS3;
+//m_bINTERP    = roCmdOPT.m_bINTERP;
+//m_bNOOPAC    = roCmdOPT.m_bNOOPAC;
+//m_bNOOPALT   = roCmdOPT.m_bNOOPALT;
+  m_bOPTS      = roCmdOPT.m_bOPTS;
+//m_bTRYTOCOM  = roCmdOPT.m_bTRYTOCOM;
+//m_bWARN      = roCmdOPT.m_bWARN;
 
   bFormat( );
 
