@@ -4,8 +4,8 @@
 // Description : This class contains values associated with the NG-Spice OPTIONS command. It       *
 //               inherits from the class CmdBase.                                                  *
 // Started     : 2006-08-23                                                                        *
-// Last Update : 2015-03-07                                                                        *
-// Copyright   : (C) 2006 by MSWaters                                                              *
+// Last Update : 2018-11-04                                                                        *
+// Copyright   : (C) 2006-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -41,8 +41,8 @@ class CmdGnuCapOPT;
 #define  NGS_DEFW      wxT("100.0um")    // MOSFET default channel width  (metre)
 #define  NGS_DEFAD     wxT("0.0")        // MOSFET default drain  diffusion area (sq.m)
 #define  NGS_DEFAS     wxT("0.0")        // MOSFET default source diffusion area (sq.m)
-#define  NGS_TEMP      wxT("27.0Deg.C")  // Operating temperature of circuit
-#define  NGS_TNOM      wxT("27.0Deg.C")  // Nominal temp. device parameters measured at
+#define  NGS_TEMP      wxT("27.0")       // Operating temperature of circuit
+#define  NGS_TNOM      wxT("27.0")       // Nominal temp. device parameters measured at
 #define  NGS_CONVABSS  wxT("0.1")        // Absolute step limit applied to code models
 #define  NGS_CONVSTEP  wxT("0.25")       // Relative step limit applied to code models
 #define  NGS_GMIN      wxT("1.0pS")      // Minimum allowable conductance
@@ -82,7 +82,7 @@ class CmdNgSpiceOPT : public CmdBase
 {
   private :
 
-    virtual  bool  bValidate( void );
+    bool  bValidate( void ) override;
 
   public :
 
@@ -136,17 +136,17 @@ class CmdNgSpiceOPT : public CmdBase
     bool      m_bTRYTOCOM;
     bool      m_bWARN;
 
-                   CmdNgSpiceOPT( void );
-    virtual       ~CmdNgSpiceOPT( );
+          CmdNgSpiceOPT( void );
+         ~CmdNgSpiceOPT( );
 
-    virtual  bool  bSetDefaults( void );
+    bool  bSetDefaults( void ) override;
 
-    virtual  bool  bParse ( void );
-    virtual  bool  bFormat( void );
+    bool  bParse ( void ) override;
+    bool  bFormat( void ) override;
 
     CmdNgSpiceOPT & operator = ( const CmdGnuCapOPT & roCmdOPT );
 
-             void  Print( const wxString & rosPrefix=wxT("  ") );
+    void  Print( const wxString & rosPrefix=wxT("  ") ) override;
 };
 
 //**************************************************************************************************
