@@ -2,8 +2,8 @@
 //                                        CmdNgSpicePR.cpp                                         *
 //                                       ------------------                                        *
 // Started     : 2007-10-16                                                                        *
-// Last Update : 2015-03-27                                                                        *
-// Copyright   : (C) 2007 by MSWaters                                                              *
+// Last Update : 2018-09-25                                                                        *
+// Copyright   : (C) 2007-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -19,11 +19,22 @@
 //**************************************************************************************************
 // Constructor.
 
-CmdNgSpicePR::CmdNgSpicePR( void )
+CmdNgSpicePR::CmdNgSpicePR( void ) : CmdBase( )
 {
   bSetDefaults( );
 }
 
+//**************************************************************************************************
+// Copy constructor.
+//
+// Argument List :
+//   roCmdPR - A reference to the object to be copied
+
+CmdNgSpicePR::CmdNgSpicePR( const CmdNgSpicePR & roCmdPR ) : CmdBase( )
+{
+  *this = roCmdPR;
+}
+
 //**************************************************************************************************
 // Destructor.
 
@@ -71,8 +82,8 @@ bool  CmdNgSpicePR::bSetDefaults( void )
   m_osaNodes.Empty( );
   m_osaCpnts.Empty( );
 
-  for( i1=(int)ePARAM_FST; i1<=(int)ePARAM_LST; i1++ ) m_bParams[ i1 ] = false;
-  for( i1=(int)eCPXPT_FST; i1<=(int)eCPXPT_LST; i1++ ) m_bCpxPts[ i1 ] = false;
+  for( i1=0; i1<(int)ePARAM_NONE; i1++ ) m_bParams[ i1 ] = false;
+  for( i1=0; i1<(int)eCPXPT_NONE; i1++ ) m_bCpxPts[ i1 ] = false;
 
   return( true );
 }
@@ -197,6 +208,7 @@ bool  CmdNgSpicePR::bParse( void )
             m_bCpxPts[ eCPXPT_MAGDB ] = true;
             break;
           }
+          else                   return( bValidate( ) );
         default :                return( bValidate( ) );
       }
     }
@@ -320,7 +332,7 @@ const wxString & CmdNgSpicePR::rosGetParamLst( void )
   osParamLst = wxT("");
 
   // Sequence through the various parameter types
-  for( i1=ePARAM_FST; i1<=ePARAM_LST; i1++ )
+  for( i1=0; i1<(int)ePARAM_NONE; i1++ )
   {
     if( ! m_bParams[ i1 ] ) continue;
 
@@ -334,7 +346,7 @@ const wxString & CmdNgSpicePR::rosGetParamLst( void )
     }
 
     // Sequence through the various complex parts
-    for( i2=eCPXPT_FST; i2<eCPXPT_LST; i2++ )
+    for( i2=0; i2<(int)eCPXPT_NONE-1; i2++ )
     {
       if( m_eAnaType == eCMD_AC )
       {
@@ -377,13 +389,13 @@ int  CmdNgSpicePR::iGetParamCnt( void )
 
   iProbes = m_osaNodes.GetCount( ) + m_osaCpnts.GetCount( );
 
-  for( iParams=0, i1=(int)ePARAM_FST; i1<=(int)ePARAM_LST; i1++ )
+  for( iParams=0, i1=0; i1<(int)ePARAM_NONE; i1++ )
     if( m_bParams[ i1 ] )
       iParams++;
 
   if( m_eAnaType == eCMD_AC )
   {
-    for( iCpxPts=0, i1=(int)eCPXPT_FST; i1<=(int)eCPXPT_LST-1; i1++ )
+    for( iCpxPts=0, i1=0; i1<(int)eCPXPT_NONE-1; i1++ )
       if( m_bCpxPts[ i1 ] )
         iCpxPts++;
   }
@@ -412,10 +424,8 @@ CmdNgSpicePR & CmdNgSpicePR::operator = ( const CmdNgSpicePR & roCmdPR )
   m_osaNodes = roCmdPR.m_osaNodes;
   m_osaCpnts = roCmdPR.m_osaCpnts;
 
-  for( i1=(int)ePARAM_FST; i1<=(int)ePARAM_LST; i1++ )
-    m_bParams[ i1 ] = roCmdPR.m_bParams[ i1 ];
-  for( i1=(int)eCPXPT_FST; i1<=(int)eCPXPT_LST; i1++ )
-    m_bCpxPts[ i1 ] = roCmdPR.m_bCpxPts[ i1 ];
+  for( i1=0; i1<(int)ePARAM_NONE; i1++ ) m_bParams[ i1 ] = roCmdPR.m_bParams[ i1 ];
+  for( i1=0; i1<(int)eCPXPT_NONE; i1++ ) m_bCpxPts[ i1 ] = roCmdPR.m_bCpxPts[ i1 ];
 
   bFormat( );
 
@@ -442,10 +452,8 @@ CmdNgSpicePR & CmdNgSpicePR::operator = ( const CmdGnuCapPR & roCmdPR )
   m_osaNodes = roCmdPR.m_osaNodes;
   m_osaCpnts = roCmdPR.m_osaCpnts;
 
-  for( i1=(int)ePARAM_FST; i1<=(int)ePARAM_LST; i1++ )
-    m_bParams[ i1 ] = roCmdPR.m_bParams[ i1 ];
-  for( i1=(int)eCPXPT_FST; i1<=(int)eCPXPT_LST; i1++ )
-    m_bCpxPts[ i1 ] = roCmdPR.m_bCpxPts[ i1 ];
+  for( i1=0; i1<(int)ePARAM_NONE; i1++ ) m_bParams[ i1 ] = roCmdPR.m_bParams[ i1 ];
+  for( i1=0; i1<(int)eCPXPT_NONE; i1++ ) m_bCpxPts[ i1 ] = roCmdPR.m_bCpxPts[ i1 ];
 
   bFormat( );
 
@@ -494,12 +502,12 @@ void  CmdNgSpicePR::Print( const wxString & rosPrefix )
   std::cout << '\n';
 
   std::cout << rosPrefix.mb_str( ) << "m_bParams [ n ] :";
-  for( i1=(int)ePARAM_FST; i1<=(int)ePARAM_LST; i1++ )
+  for( i1=0; i1<(int)ePARAM_NONE; i1++ )
     std::cout << ( m_bParams[ i1 ] ? " true " : " false" );
   std::cout << '\n';
 
   std::cout << rosPrefix.mb_str( ) << "m_bCpxPts [ n ] :";
-  for( i1=(int)eCPXPT_FST; i1<=(int)eCPXPT_LST; i1++ )
+  for( i1=0; i1<(int)eCPXPT_NONE; i1++ )
     std::cout << ( m_bCpxPts[ i1 ] ? " true " : " false" );
   std::cout << '\n';
 }
@@ -545,7 +553,7 @@ int  main( int argc, char * argv[ ] )
   osCmd = wxT(".PRINT AC VM(6,0) 0-VM(5) VM(1,7) VM(2) VP(6,0) 0-VP(5) VP(1,7) VP(2)");
 
   // Set things up for a formatter test
-  oCmd_PR.m_eAnaType = eCMD_AC;
+  oCmd_PR.bSetAnaType( eCMD_AC );
   oCmd_PR.m_osaCpnts.Add( wxT("6,0") );
   oCmd_PR.m_osaCpnts.Add( wxT("0,5") );
   oCmd_PR.m_osaCpnts.Add( wxT("1,7") );
