@@ -2,8 +2,8 @@
 //                                        CmdNgSpiceTR.cpp                                         *
 //                                       ------------------                                        *
 // Started     : 2007-10-15                                                                        *
-// Last Update : 2014-12-12                                                                        *
-// Copyright   : (C) 2007 by MSWaters                                                              *
+// Last Update : 2018-09-25                                                                        *
+// Copyright   : (C) 2007-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -19,7 +19,7 @@
 //**************************************************************************************************
 // Constructor.
 
-CmdNgSpiceTR::CmdNgSpiceTR( void )
+CmdNgSpiceTR::CmdNgSpiceTR( void ) : CmdBase( )
 {
   bSetDefaults( );
 }
@@ -260,7 +260,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdNgSpiceTR Test Utility"
-       << "\n     Version 1.02 (12/08/2011)\n";
+       << "\n     Version 1.03 (2016-09-29)\n";
 
   // Create a NG-SPICE TRANSIENT command object
   CmdNgSpiceTR  oCmd_TR;
