@@ -1,12 +1,12 @@
 //**************************************************************************************************
 //                                        PnlNgSpiceAC.hpp                                         *
 //                                       ------------------                                        *
-// Description : This class derives from the Analysis Panel base class and provides a GUI for a    *
-//               user to configure a AC Analysis for the NG-Spice electronic circuit simulation    *
+// Description : This class derives from the PnlAnaBase base class and provides a GUI for the user *
+//               to configure an AC Analysis for the NG-Spice electronic circuit simulation        *
 //               engine.                                                                           *
 // Started     : 2004-08-04                                                                        *
-// Last Update : 2015-01-12                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-09-29                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -32,17 +32,18 @@ class PnlNgSpiceAC : public PnlAnaBase
 {
   private :
 
-    void  Create( void );
+    void  Create      ( void );
+    void  CreateSigSrc( void ) override;
 
-    void  InitScale( void );
-    bool  bSetScale( eTypeScale eScale );
+    void  InitScale( void ) override;
+    bool  bSetScale( eTypeScale eScale ) override;
 
   public :
 
-          PnlNgSpiceAC( wxWindow * poWin );
-         ~PnlNgSpiceAC( );
+    explicit  PnlNgSpiceAC( wxWindow * poWin );
+             ~PnlNgSpiceAC( );
 
-    bool  bClear( void );
+    bool  bClear( void ) override;
 
     bool  bLoad( SimnNgSpice & roSimn );
     bool  bSave( SimnNgSpice & roSimn );
@@ -52,7 +53,11 @@ class PnlNgSpiceAC : public PnlAnaBase
     void  OnSrcName( wxCommandEvent & roEvtCmd );
 
     // Leave this as the last line as private access is envoked by macro
+#if wxCHECK_VERSION( 3,0,0 )
     wxDECLARE_EVENT_TABLE( );
+#else
+    wxDECLARE_EVENT_TABLE( )
+#endif
 };
 
 //**************************************************************************************************
