@@ -2,8 +2,8 @@
 //                                        PnlNgSpiceTR.cpp                                         *
 //                                       ------------------                                        *
 // Started     : 2004-08-05                                                                        *
-// Last Update : 2015-03-29                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-10-20                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -31,10 +31,9 @@ wxEND_EVENT_TABLE( )
 
 PnlNgSpiceTR::PnlNgSpiceTR( wxWindow * poWin ) : PnlAnaBase( poWin ), m_oDlgCfgSrc( poWin )
 {
-  bSetAnalysType( eCMD_TR );
-
-  Create( );  // Create the analysis panel
-  bClear( );  // Clear all object attributes
+  bSetAnalysType( eCMD_TR );  // Set the analysis panel type
+  Create( );                  // Create the analysis panel
+  bClear( );                  // Clear all object attributes
 }
 
 //**************************************************************************************************
@@ -50,14 +49,27 @@ PnlNgSpiceTR::~PnlNgSpiceTR( )
 void  PnlNgSpiceTR::Create( void )
 {
   PnlAnaBase::CreateBase( );    // Create the base controls
-  PnlAnaBase::CreateInitC( );   // Create and add the initial condtns controls
+  PnlAnaBase::CreateInitC( );   // Create the initial condtns controls
   PnlAnaBase::CreateTemp( );    // Create the analysis temperature controls
-              CreateSigSrc( );  // Create and add signal source controls
+  PnlAnaBase::CreateSigSrc( );  // Create the input signal source controls
+              CreateSigSrc( );  // Create the additional input signal source controls
 
+#ifdef LAYOUT_MNGR
   PnlAnaBase::DoLayout( );      // Layout the panel's GUI objects
+#endif // LAYOUT_MNGR
+
+  // The following block of code is required to circumvent a bug in wxWidgets. All declared wxChoice
+  // controls attempt a clear( ) operation in their destructor whether or not thay have actually
+  // been created. Causes a null pointer warning. ??? 2018-10-20
+  m_oPnlSrcLvl.bCreate( m_oChoSrcName.GetParent( ), ID_PNL_SRCLVL, -1, 95, 82 );
+  m_oPnlSrcLvl.Hide( );
 
   // Set the time sweep parameter labels
+#ifdef LAYOUT_MNGR
+  bSetSwpParsLbl( wxT("Time Sweep") );
+#else
   m_oSbxSwpPars.SetLabel( wxT(" Time Sweep ") );
+#endif // LAYOUT_MNGR
   m_oPnlStart  .bSetName( wxT("Start Time") );
   m_oPnlStop   .bSetName( wxT("Stop Time") );
   m_oPnlStep   .bSetName( wxT("Step Increment") );
@@ -78,16 +90,19 @@ void  PnlNgSpiceTR::Create( void )
 
 void  PnlNgSpiceTR::CreateSigSrc( void )
 {
-  // Create and add signal source controls
-  m_oSbxSigSrc .Create( this, ID_UNUSED   , wxT(" Signal Source "), wxPoint(   6, 178 ),
-                        wxSize( 255, 60 ) );
-  m_oChoSrcName.Create( this, ID_CHO_SRCNAME,                       wxPoint(  18, 200 ),
-                        wxSize( 121, GUI_CTRL_HT ) );
-  m_oBtnSetup  .Create( this, ID_BTN_SETUP, wxT("Setup ..."),       wxPoint( 143, 200 ),
-                        wxSize( 105, GUI_CTRL_HT ) );
+  wxPanel * poPnl;
 
-  // Set static box font
-  m_oSbxSigSrc.SetOwnFont( FONT_SLANT );
+  poPnl = static_cast< wxPanel * >( m_oChoSrcName.GetParent( ) );
+
+  // Create and add signal source controls
+#ifdef LAYOUT_MNGR
+  m_oBtnSetup.Create( poPnl, ID_BTN_SETUP, wxT("Setup ...") );
+  m_oBtnSetup.SetMinSize( wxSize( 105, GUI_CTRL_HT ) );
+#else
+  m_oSbxSigSrc.SetSize( wxSize( 255, 60 ) );
+  m_oBtnSetup .Create( poPnl, ID_BTN_SETUP, wxT("Setup ..."),
+                       wxPoint( 143, 200 ), wxSize( 105, GUI_CTRL_HT ) );
+#endif // LAYOUT_MNGR
 }
 
 //**************************************************************************************************
@@ -154,7 +169,7 @@ bool  PnlNgSpiceTR::bLoad( SimnNgSpice & roSimn )
   if( ! roSimn.m_oCmdTR.bIsValid( ) )                        return( false );
 
   // Set the source component name (a sweep source is not mandatory for a TR analysis)
-  PnlAnaBase::bSetSrcCpnt( roSimn.m_oCpntSwpSrc );
+  PnlAnaBase::bSetSrcCpnt( roSimn.m_oCpntSigSrc );
 
   // Set the initial state of the source setup dialog
   m_oDlgCfgSrc.bSetValues( roSimn.m_oCpntIndSrc );
@@ -210,7 +225,7 @@ bool  PnlNgSpiceTR::bSave( SimnNgSpice & roSimn )
     // Add the modifications from the independent source configuration dialog
     m_oDlgCfgSrc.bGetValues( roSimn.m_oCpntIndSrc );
     if( roSimn.m_oCpntIndSrc.bFormat( ) )
-      roSimn.m_oCpntSwpSrc = roSimn.m_oCpntIndSrc;
+      roSimn.m_oCpntSigSrc = roSimn.m_oCpntIndSrc;
     else
     {
       os1 = wxT("The signal source ")
@@ -220,7 +235,7 @@ bool  PnlNgSpiceTR::bSave( SimnNgSpice & roSimn )
   }
   else
   {
-    roSimn.m_oCpntSwpSrc.bClear( );
+    roSimn.m_oCpntSigSrc.bClear( );
     roSimn.m_oCpntIndSrc.bClear( );
   }
 
@@ -255,9 +270,6 @@ void  PnlNgSpiceTR::OnSrcName( wxCommandEvent & roEvtCmd )
 {
   wxString  os1;
 
-  // Execute the base class event handler first
-  PnlAnaBase::OnSrcName( roEvtCmd );
-
   // Set the signal source name in the configuration dialogue
   os1 = m_oChoSrcName.GetStringSelection( );
   if( os1 != wxT("None") ) m_oDlgCfgSrc.bSetName( os1 );
@@ -270,10 +282,11 @@ void  PnlNgSpiceTR::OnSrcName( wxCommandEvent & roEvtCmd )
 // Argument List:
 //   roEvtCmd - An object holding information about the event
 
-void  PnlNgSpiceTR::OnBtnSetup( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  PnlNgSpiceTR::OnBtnSetup( wxCommandEvent & roEvtCmd )
 {
+  // Display the signal source setup dialogue
   m_oDlgCfgSrc.CenterOnParent( );
-  m_oDlgCfgSrc.ShowModal( );
+  if( m_oDlgCfgSrc.ShowModal( ) != wxID_OK ) return;
 }
 
 //**************************************************************************************************
