@@ -2,8 +2,8 @@
 //                                          PrcGSchem.cpp                                          *
 //                                         ---------------                                         *
 // Started     : 2008-02-18                                                                        *
-// Last Update : 2014-12-30                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-10-26                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -22,11 +22,10 @@
 PrcGSchem::PrcGSchem( void ) : PrcBase( wxPROCESS_REDIRECT )
 {
   // Initialize the object attributes
-  m_oafnSchems.Clear( );
-  m_ofnLog    .Clear( );
+  m_oaNameSchems.Clear( );
 
-  // Attempt to set and find the appropriate binary
-  bSetBinary( BIN_GSCHEM );
+  // Attempt to set and find the binary file
+  bSetEdaSuite( g_oConfig.eGetEdaSuite( ) );
 }
 
 //**************************************************************************************************
@@ -36,6 +35,30 @@ PrcGSchem::~PrcGSchem( )
 {
 }
 
+//**************************************************************************************************
+// Set the EDA tool suite..
+//
+// Argument List :
+//   eEDA - The enumerated type specifier for the desired tool suite
+//
+// Return Values :
+//   true  - Success
+//   false - Failure
+
+bool  PrcGSchem::bSetEdaSuite( eTypeEDA eEDA )
+{
+  bool  bRtn;
+
+  switch( eEDA )
+  {
+    case eEDA_LEPTON : bRtn = bSetBinFile( BIN_LSCHEM ); break;
+    case eEDA_GEDA   : bRtn = bSetBinFile( BIN_GSCHEM ); break;
+    default          : bRtn = FALSE;
+  }
+
+  return( bRtn );
+}
+
 //**************************************************************************************************
 // Set the schematic file name/s.
 //
@@ -46,7 +69,7 @@ PrcGSchem::~PrcGSchem( )
 //   true  - Success
 //   false - Failure
 
-bool  PrcGSchem::bSetSchems( const wxString & rosFileNames )
+bool  PrcGSchem::bSetSchemFiles( const wxString & rosFileNames )
 {
   wxStringTokenizer  ostk1;
   wxArrayString      oas1;
@@ -55,7 +78,7 @@ bool  PrcGSchem::bSetSchems( const wxString & rosFileNames )
   while( ostk1.HasMoreTokens( ) )
     oas1.Add( ostk1.GetNextToken( ) );
 
-  return( bSetSchems( oas1 ) );
+  return( bSetSchemFiles( oas1 ) );
 }
 
 //**************************************************************************************************
@@ -68,13 +91,13 @@ bool  PrcGSchem::bSetSchems( const wxString & rosFileNames )
 //   true  - Success
 //   false - Failure
 
-bool  PrcGSchem::bSetSchems( const wxArrayString & roasFileNames )
+bool  PrcGSchem::bSetSchemFiles( const wxArrayString & roasFileNames )
 {
   wxFileName  ofn1;
   size_t      szt1;
 
   // Clear the current list of schematic files
-  m_oafnSchems.Clear( );
+  m_oaNameSchems.Clear( );
 
   // Check the argument is empty
   if( roasFileNames.IsEmpty( ) )                              return( true );
@@ -88,23 +111,41 @@ bool  PrcGSchem::bSetSchems( const wxArrayString & roasFileNames )
     if( ! ofn1.IsOk( )       ) continue;
     if( ! ofn1.FileExists( ) ) continue;
 
-    m_oafnSchems.Add( ofn1 );
+    m_oaNameSchems.Add( ofn1 );
   }
 
   // Check that at least one schematic file name was accepted
-  if( m_oafnSchems.IsEmpty( ) )                               return( false );
+  if( m_oaNameSchems.IsEmpty( ) )                               return( false );
 
   // Set the log file path
   ofn1 = roGetLogFile( );
-  ofn1.SetPath( m_oafnSchems.Item( 0 ).GetPath( ) );
+  ofn1.SetPath( m_oaNameSchems.Item( 0 ).GetPath( ) );
   bSetLogFile( ofn1.GetFullPath( ) );
 
   // Check if any of the schematic files were invalid
-  if( m_oafnSchems.GetCount( ) != roasFileNames.GetCount( ) ) return( false );
+  if( m_oaNameSchems.GetCount( ) != roasFileNames.GetCount( ) ) return( false );
 
   return( true );
 }
 
+//**************************************************************************************************
+// Get the EDA tool suite.
+//
+// Return Values :
+//   Success - The enumerate type for the EDA tool suite
+//   Failure - eEDA_NONE
+
+eTypeEDA  PrcGSchem::eGetEdaSuite( void )
+{
+  wxString  os1;
+
+  os1 = roGetBinFile( ).GetFullName( );
+
+  if( os1 == BIN_LSCHEM ) return( eEDA_LEPTON );
+  if( os1 == BIN_GSCHEM ) return( eEDA_GEDA   );
+  else                    return( eEDA_NONE   );
+}
+
 //**************************************************************************************************
 // Get a schematic file from the list of schematic files.
 //
@@ -112,17 +153,17 @@ bool  PrcGSchem::bSetSchems( const wxArrayString & roasFileNames )
 //   Success - The procedure name
 //   Failure - An empty file name
 
-const wxString & PrcGSchem::rosGetSchems( void )
+const wxString & PrcGSchem::rosGetSchemFiles( void )
 {
   static  wxString  osSchems;
   size_t  sz1;
 
   osSchems.Empty( );
 
-  for( sz1=0; sz1<m_oafnSchems.GetCount( ); sz1++ )
+  for( sz1=0; sz1<m_oaNameSchems.GetCount( ); sz1++ )
   {
     if( ! osSchems.IsEmpty( ) ) osSchems << wxT(' ');
-    osSchems << m_oafnSchems.Item( sz1 ).GetFullPath( );
+    osSchems << m_oaNameSchems.Item( sz1 ).GetFullPath( );
   }
 
   return( osSchems );
@@ -139,19 +180,45 @@ const wxString & PrcGSchem::rosGetSchems( void )
 
 bool  PrcGSchem::bExec( void )
 {
+  wxString  osArgLst;
+  size_t    sz1;
+
   // Test file names needed by this function
-  if( ! bBinExists( ) )                 return( false );
-  if( rosGetSchems( ).IsEmpty( ) )
+  if( ! bBinExists( ) )          return( false );
+  if( rosGetSchemFiles( ).IsEmpty( ) )
   {
-    m_osErrMsg << wxT("The schematic file/s have not been set.");
+    PrcBase::SetErrMsg( wxT("The schematic file/s have not been set.") );
     return( false );
   }
 
-  // Append input file name to argument list
-  if( ! bSetArgLst( rosGetSchems( ) ) ) return( false );
+  // Disable backup files in gschem eg. circuit.sch~
+  osArgLst << wxT("-c \"(auto-save-interval 0)\" ");
+
+#ifndef __WXMSW__
+  // Don't display the status windows at startup
+  osArgLst << wxT("-c \"(view-status)\" ");
+
+  // Don't display the side bar at startup
+  osArgLst << wxT("-c \"(view-sidebar)\" ");
+
+  // Use the light colour scheme
+  osArgLst << wxT("-c \"(view-light-colors)\"");
+#endif
+
+  // Append input file name/s to argument list
+  for( sz1=0; sz1<m_oaNameSchems.GetCount( ); sz1++ )
+    osArgLst << wxT(" ") << rosEscSpaceChrs( m_oaNameSchems.Item( sz1 ).GetFullPath( ) );
+
+  // Set the command line arguments
+  if( ! bSetArgLst( osArgLst ) ) return( false );
+
+#if defined( __WXMSW__ ) && defined( GSPICEUI_DEBUG )
+  // Set the execute flags
+  m_iFlags = wxEXEC_SHOW_CONSOLE;
+#endif
 
   // Execute the process
-  if( ! PrcBase::bExecAsync( ) )        return( false );
+  if( ! PrcBase::bExecAsync( ) ) return( false );
 
   return( true );
 }
