@@ -5,8 +5,8 @@
 //               the currently loaded netlist file is derived from a gSchem schematic file the     *
 //               user can envoke gschem and edit the schematic.                                    *
 // Started     : 2008-02-18                                                                        *
-// Last Update : 2015-01-05                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-10-10                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -23,6 +23,7 @@
 // Application Includes
 
 #include "TypeDefs.hpp"
+#include "Config.hpp"
 #include "base/PrcBase.hpp"
 
 // wxWidgets Includes
@@ -35,18 +36,20 @@ class PrcGSchem : public PrcBase
 {
   private :
 
-    ArrayFileName  m_oafnSchems; // The full names of the schematic file/s
+    ArrayFileName  m_oaNameSchems;  // The full names of the schematic file/s
 
   public :
 
           PrcGSchem( void );
          ~PrcGSchem( );
 
-    bool  bSetSchems( const wxString & rosFileNames );
-    bool  bSetSchems( const wxArrayString & roasFileNames );
+    bool  bSetEdaSuite  (       eTypeEDA           eEDA       );
+    bool  bSetSchemFiles( const wxString      &  rosFileNames );
+    bool  bSetSchemFiles( const wxArrayString & roasFileNames );
 
-    const wxString      & rosGetSchems( void );
-    const ArrayFileName & roaGetSchems( void ) { return( m_oafnSchems ); }
+          eTypeEDA          eGetEdaSuite  ( void );
+    const wxString      & rosGetSchemFiles( void );
+    const ArrayFileName & roaGetSchemFiles( void ) { return( m_oaNameSchems ); }
 
     virtual  bool  bExec( void );
 };
