@@ -2,8 +2,8 @@
 //                                          PrcGWave.cpp                                           *
 //                                         --------------                                          *
 // Started     : 2004-03-29                                                                        *
-// Last Update : 2014-12-30                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-10-26                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -22,11 +22,10 @@
 PrcGWave::PrcGWave( void ) : PrcBase( wxPROCESS_REDIRECT )
 {
   // Initialize the object attributes
-  m_ofnResults.Clear( );
-  m_ofnLog    .Clear( );
+  m_oNameResults.Clear( );
 
   // Attempt to set and find the gWave binary
-  bSetBinary( BIN_GWAVE );
+  bSetBinFile( BIN_GWAVE );
 }
 
 //**************************************************************************************************
@@ -46,7 +45,7 @@ PrcGWave::~PrcGWave( )
 //   true  - Success
 //   false - Failure
 
-bool  PrcGWave::bSetResults( const wxString & rosFileName )
+bool  PrcGWave::bSetResultsFile( const wxString & rosFileName )
 {
   wxFileName  ofn1;
 
@@ -56,7 +55,7 @@ bool  PrcGWave::bSetResults( const wxString & rosFileName )
   if( ! ofn1.IsOk( )       ) return( false );
   if( ! ofn1.FileExists( ) ) return( false );
 
-  m_ofnResults = ofn1;
+  m_oNameResults = ofn1;
 
   return( true );
 }
@@ -65,7 +64,7 @@ bool  PrcGWave::bSetResults( const wxString & rosFileName )
 // Filter the results file so that the data viewer utility is happy with it.
 //
 // There are several things that a data viewer can object to :
-//  - gwave doesn't like the GNU-Cap banner at the start to the results file, so it's removed here.
+//  - gwave doesn't like the GNU-Cap banner at the start of the results file, so it's removed here.
 //  - gwave doesn't like error messages interspersed with the lines of data, so they are removed
 //    here.
 //  - For good measure lines and fields are also formatted.
@@ -77,12 +76,13 @@ bool  PrcGWave::bSetResults( const wxString & rosFileName )
 bool  PrcGWave::bFilterFile( void )
 {
   wxString  os1;
-  size_t    szt1, szt2;
+  size_t    sz1, sz2;
   wxChar    oc1;
   bool      bRtn=true;
 
   // Attempt to open the results file
-  wxTextFile  oFileCct( m_ofnResults.GetFullPath( ) );
+  os1 = m_oNameResults.GetFullPath( );
+  wxTextFile  oFileCct( os1 );
   if( ! oFileCct.Exists( ) ) return( false );
   if( ! oFileCct.Open( ) )   return( false );
 
@@ -90,34 +90,34 @@ bool  PrcGWave::bFilterFile( void )
   if( oFileCct.GetFirstLine( ).GetChar( 0 ) == wxT('#') ) return( true );
 
   // Find the beginning of the data area (ie. the last line beginning with '#')
-  for( szt1=szt2=0; szt1<oFileCct.GetLineCount( ); szt1++ )
+  for( sz1=sz2=0; sz1<oFileCct.GetLineCount( ); sz1++ )
   {
-    os1 = oFileCct.GetLine( szt1 );
+    os1 = oFileCct.GetLine( sz1 );
     if( ! os1.IsEmpty( ) )
       if( os1.GetChar( 0 ) == wxT('#') )
-        szt2 = szt1;
+        sz2 = sz1;
   }
 
   // Delete the banner
-  for( szt1=0; szt1<szt2; szt1++ ) oFileCct.RemoveLine( 0 );
+  for( sz1=0; sz1<sz2; sz1++ ) oFileCct.RemoveLine( 0 );
   if( oFileCct.GetLineCount( ) <= 1 )                     return( false );
 
   // Delete any simulator error messages eg. "open circuit: internal node 3"
   // (All lines should start with a digit except for the first)
-  for( szt1=1; !oFileCct.Eof( ) && szt1<oFileCct.GetLineCount( ); szt1++ )
+  for( sz1=1; !oFileCct.Eof( ) && sz1<oFileCct.GetLineCount( ); sz1++ )
   {
-    os1 = oFileCct.GetLine( szt1 );
+    os1 = oFileCct.GetLine( sz1 );
     if( os1.Length( ) <= 1 )
     { // Delete empty lines
-      oFileCct.RemoveLine( szt1 );
-      szt1--;
+      oFileCct.RemoveLine( sz1 );
+      sz1--;
       continue;
     }
     oc1 = os1.GetChar( 1 );
     if( ! wxIsdigit( oc1 ) )
     { // Delete non-data lines
-      oFileCct.RemoveLine( szt1 );
-      szt1--;
+      oFileCct.RemoveLine( sz1 );
+      sz1--;
       continue;
     }
   }
@@ -230,25 +230,30 @@ bool  PrcGWave::bExec( void )
   wxString  os1;
 
   // Test file names needed by this function
-  if( ! bBinExists( ) )                             return( false );
-  if( !m_ofnResults.FileExists( ) || !m_ofnResults.IsOk( ) )
+  if( ! bBinExists( ) )          return( false );
+  if( !m_oNameResults.FileExists( ) || !m_oNameResults.IsOk( ) )
   {
-    os1 = m_ofnResults.GetFullPath( );
-    m_osErrMsg.Empty( );
-    if( os1.IsEmpty( ) )
-         m_osErrMsg << wxT("The results file has not been set.");
-    else m_osErrMsg << wxT("The results file doesn't exist : ") << os1;
+    os1 = m_oNameResults.GetFullPath( );
+    PrcBase::ClrErrMsg( );
+    if( os1.IsEmpty( ) ) PrcBase::SetErrMsg( wxT("The results file has not been set.") );
+    else                 PrcBase::SetErrMsg( wxT("The results file doesn't exist : ")  );
     return( false );
   }
 
   // Append input file name to argument list
-  if( ! bSetArgLst( m_ofnResults.GetFullPath( ) ) ) return( false );
+  os1 = rosEscSpaceChrs( m_oNameResults.GetFullPath( ) );
+  if( ! bSetArgLst( os1 ) )      return( false );
 
   // Filter the file before passing it to the waveform viewer process
-  if( ! bFilterFile( ) )                            return( false );
+  if( ! bFilterFile( ) )         return( false );
+
+#if defined( __WXMSW__ ) && defined( GSPICEUI_DEBUG )
+  // Set the execute flags
+  m_iFlags = wxEXEC_SHOW_CONSOLE;
+#endif
 
   // Execute the process
-  if( ! PrcBase::bExecAsync( ) )                    return( false );
+  if( ! PrcBase::bExecAsync( ) ) return( false );
 
   return( true );
 }
