@@ -5,8 +5,8 @@
 //               view the raw simulation data or envoke this utility which plots the data          *
 //               graphically.                                                                      *
 // Started     : 2008-01-10                                                                        *
-// Last Update : 2015-01-05                                                                        *
-// Copyright   : (C) 2008 by MSWaters                                                              *
+// Last Update : 2016-03-25                                                                        *
+// Copyright   : (C) 2008-2016 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -35,7 +35,7 @@ class PrcGaw : public PrcBase
 {
   private :
 
-    wxFileName  m_ofnResults; // The full simulator results file name
+    wxFileName  m_oNameResults;  // The full simulator results file name
 
     // Functions for reformatting the results file for input to the viewer
     bool  bFilterFile( void );
@@ -45,9 +45,9 @@ class PrcGaw : public PrcBase
           PrcGaw( void );
          ~PrcGaw( );
 
-    bool  bSetResults( const wxString & rosFileName );
+    bool  bSetResultsFile( const wxString & rosFileName );
 
-    const wxFileName & roGetResults( void ) { return( m_ofnResults ); }
+    const wxFileName & roGetResultsFile( void ) { return( m_oNameResults ); }
 
     virtual  bool  bExec( void );
 };
