@@ -2,8 +2,8 @@
 //                                          PrcGnuCap.cpp                                          *
 //                                         ---------------                                         *
 // Started     : 2003-09-01                                                                        *
-// Last Update : 2015-03-30                                                                        *
-// Copyright   : (C) 2003 by MSWaters                                                              *
+// Last Update : 2018-10-26                                                                        *
+// Copyright   : (C) 2003-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -25,7 +25,7 @@ PrcGnuCap::PrcGnuCap( void ) : PrcSimEngBase( )
   m_eSimEng = eSIMR_GNUCAP;
 
   // Set the simulator binary file name if it can be found
-  bSetBinary( BIN_GNUCAP );
+  bSetBinFile( BIN_GNUCAP );
 }
 
 //**************************************************************************************************
@@ -36,10 +36,9 @@ PrcGnuCap::~PrcGnuCap( )
 }
 
 //**************************************************************************************************
-// Check / format the component lines in the simulation object so that they are
-// compatible with GNU-Cap. Ie. add the substrate node to BJT components which
-// are missing it, the substrate node is assumed to be connected to the
-// collector. Eg. "Q1 nc nb ne BC109" would become "Q1 nc nb ne nc BC109".
+// Check / format the component lines in the simulation object so that they are compatible with
+// GNU-Cap. Ie. add the substrate node to BJT components which are missing it, the substrate node is
+// assumed to be connected to the collector. Eg. "Q1 NC NB NE BC109" becomes "Q1 NC NB NE NC BC109".
 //
 // Argument List :
 //   roaCpnts - An array of ArrayComponent objects
@@ -72,7 +71,7 @@ bool  PrcGnuCap::bFmtCpnts( ArrayComponent & roaCpnts )
 //   true  - Success
 //   false - Failure
 
-bool  PrcGnuCap::bFmtCommon( void )
+bool  PrcGnuCap::bFmtGeneral( void )
 {
   wxString  os1, os2;
   size_t    sz1, sz2;
@@ -81,8 +80,8 @@ bool  PrcGnuCap::bFmtCommon( void )
   // This function requires the result file to have been opened
   if( ! m_oFileResults.IsOpened( ) ) return( false );
 
-  // Find the beginning of the data area (ie. the last line beginning with '#')
-  // and delete all the lines before the data area
+  // Find the beginning of the data area (ie. the last line beginning with '#') and delete all
+  // preceding lines
   for( sz1=sz2=0; sz1<m_oFileResults.GetLineCount( ); sz1++ )
   {
     os1 = m_oFileResults.GetLine( sz1 );
@@ -92,22 +91,21 @@ bool  PrcGnuCap::bFmtCommon( void )
   }
   for( sz1=0; sz1<sz2; sz1++ ) m_oFileResults.RemoveLine( 0 );
 
-  // Format the column header line
-  bFmtColLabels( );
-
-  // Delete any simulator error messages eg. "open circuit: internal node 3"
-  // (All lines should start with a digit except for the first)
-  for( sz1=1; !m_oFileResults.Eof() && sz1<m_oFileResults.GetLineCount(); sz1++ )
+  // Delete any simulator error messages (eg. "open circuit: internal node 3"). All lines should
+  // start with a digit except for the first line (ie. the column headers).
+  for( sz1=1; !m_oFileResults.Eof( ) && sz1<m_oFileResults.GetLineCount( ); sz1++ )
   {
     os1 = m_oFileResults.GetLine( sz1 );
+
     if( os1.Length( ) <= 1 )
     { // Delete empty lines
       m_oFileResults.RemoveLine( sz1 );
       sz1--;
       continue;
     }
+
     oc1 = os1.GetChar( 1 );
-    if( ! wxIsdigit( oc1 ) )
+    if( ! wxIsdigit( oc1 ) && oc1!=wxT('-') && oc1!=wxT('+') )
     { // Delete non-data lines
       m_oFileResults.RemoveLine( sz1 );
       sz1--;
@@ -115,8 +113,12 @@ bool  PrcGnuCap::bFmtCommon( void )
     }
   }
 
-  // Format the data lines
-  bFmtDataLines( );
+  // Check that a data section exists
+  if( m_oFileResults.GetLineCount( ) <= 1 )
+  {
+    SetErrMsg( wxT("Couldn't find a data section in the results file.") );
+    return( false );
+  }
 
   return( true );
 }
@@ -133,33 +135,36 @@ bool  PrcGnuCap::bFmtColLabels( void )
 {
   wxStringTokenizer  ostk1;
   wxString           osLine, os1, os2;
-  int                i1;
+//  int                i1;
 
   // This function requires the result file to have already been opened
   if( ! m_oFileResults.IsOpened( ) ) return( false );
 
   // Get the column header line
-  ostk1 = m_oFileResults.GetFirstLine( );
-  if( ostk1.CountTokens( ) < 1 )     return( false );
+  ostk1.SetString( m_oFileResults.GetFirstLine( ) );
+  if( ostk1.CountTokens( ) < 1 )
+  {
+    SetErrMsg( wxT("There's insufficient column headers in the results file ie. should be 2 or more.") );
+    return( false );
+  }
 
-  // GNU-Cap has a bug in the OP and DC analysis results. In the case of OP the
-  // column label for the temperature values is missing ie. "Temp". For DC the
-  // column label for the sweep source values is missing eg. "Vin". This
-  // section of code inserts these labels.
+  // GNU-Cap has a bug in the OP and DC analysis results. In the case of OP the column label for the
+  // temperature values is missing ie. "Temp". For DC the column label for the sweep source values
+  // is missing eg. "Vin". This section of code inserts these labels.
   os1 = ostk1.GetNextToken( );
   os2 = roGetResultsFile( ).GetFullName( ).Right( 3 );
-// osLine = wxT("# "); // ??? 06/08/2005 Gwave breaks if there's a space after initial '#'
+// osLine = wxT("# "); // ??? 06/08/2005 Gwave breaks if there's a space after the initial '#'
   osLine = wxT('#');
   if(      os2 == wxT(".op") ) osLine << wxT("Temp");
-  else if( os2 == wxT(".dc") ) osLine << m_osSwpSrcName;
+  else if( os2 == wxT(".dc") ) osLine << m_osSigSrcName;
   else                         osLine << os1.Right( os1.Length( )-1 );
 
-  // Format each field
+  // Format each header field
   while( ostk1.HasMoreTokens( ) )
   {
     // Pad the column with spaces to the required width
-    i1 = GNUCAP_COL_WD - (osLine.Length( ) % GNUCAP_COL_WD);
-    osLine.Append( wxT(' '), i1 );
+//    i1 = GNUCAP_COL_WD - (osLine.Length( ) % GNUCAP_COL_WD);
+//    osLine.Append( wxT(' '), i1 );
 
     // Add the next label to the line
     osLine << wxT(' ') << ostk1.GetNextToken( );
@@ -172,6 +177,64 @@ bool  PrcGnuCap::bFmtColLabels( void )
   return( true );
 }
 
+//**************************************************************************************************
+// Format the data lines in the results file.
+//
+// Return Values :
+//   true  - Success
+//   false - Failure
+
+bool  PrcGnuCap::bFmtDataLines( void )
+{
+  wxStringTokenizer  ostk1;
+  wxString           osLine, os1;
+  size_t             sz1;
+  double             df1;
+//  int                i1;
+
+  // This function requires the result file to have been opened
+  if( ! m_oFileResults.IsOpened( ) ) return( false );
+
+  // Check that there is a data section
+  if( m_oFileResults.GetLineCount( ) <= 1 )
+  {
+    SetErrMsg( wxT("There's no data section in the results file.") );
+    return( false );
+  }
+
+  // Format the data lines
+  for( sz1=1; sz1<m_oFileResults.GetLineCount( ); sz1++ )
+  {
+    // Get a line of data
+    osLine = m_oFileResults.GetLine( sz1 );
+
+    // Tokenize the string
+    ostk1.SetString( osLine );
+    if( ostk1.CountTokens( ) < 1 )   return( false );
+
+    // Format each field
+    osLine.Empty( );
+    while( ostk1.HasMoreTokens( ) )
+    {
+      // Add the next parameter to the line
+      os1 = ostk1.GetNextToken( );
+      if( ! CnvtType::bStrToFlt( os1, &df1 ) ) df1 =      -9.9e-99;
+      if( ! CnvtType::bFltToStr( df1,  os1 ) ) os1 = wxT("-9.9e-99");
+      osLine << os1 << wxT(' ');
+
+      // Pad the column with spaces to the required width
+//      i1 = GNUCAP_COL_WD - (osLine.Length( ) % GNUCAP_COL_WD);
+//      osLine.Append( wxT(' '), i1 );
+    }
+
+    osLine.Trim( ); // Remove trailing space characters
+
+    m_oFileResults.GetLine( sz1 ) = osLine;
+  }
+
+  return( true );
+}
+
 //**************************************************************************************************
 // This function is a results file formatter for Fourier analysis result.
 //
@@ -181,14 +244,13 @@ bool  PrcGnuCap::bFmtColLabels( void )
 
 bool  PrcGnuCap::bFmtResultsFO( void )
 {
+  bool               bRtn;
   wxConfig         * poConfig;
   wxStringTokenizer  ostk1;
   wxString           os1, os2, os3;
   size_t             sz1, sz2;
   bool               b1;
 
-std::cerr << "PrcGnuCap::bFmtResultsFO( ) - 1\n"; // ???
-
   // This function requires the result file to have been opened
   if( ! m_oFileResults.IsOpened( ) ) return( false );
 
@@ -197,11 +259,13 @@ std::cerr << "PrcGnuCap::bFmtResultsFO( ) - 1\n"; // ???
   {
     os1 = m_oFileResults.GetLine( sz1 );
     if( ! os1.IsEmpty( ) )
+    {
       if( os1.Contains( wxT("--- actual ---") ) )
       {
         sz2 = sz1;
         break;
       }
+    }
   }
 
   // Delete all the lines before the data area
@@ -209,7 +273,7 @@ std::cerr << "PrcGnuCap::bFmtResultsFO( ) - 1\n"; // ???
 
   // Delete unwanted header lines
   for( os1=m_oFileResults.GetFirstLine( ); !m_oFileResults.Eof( );
-                                            os1=m_oFileResults.GetNextLine( ) )
+                                                                 os1=m_oFileResults.GetNextLine( ) )
   {
     if( os1.StartsWith( wxT("#freq") ) )
       m_oFileResults.RemoveLine( m_oFileResults.GetCurrentLine( ) );
@@ -221,8 +285,8 @@ std::cerr << "PrcGnuCap::bFmtResultsFO( ) - 1\n"; // ???
   poConfig->SetPath( wxT("/GNU-Cap") );
 
   // Delete unwanted columns of data
-  for( ostk1=m_oFileResults.GetFirstLine(); !m_oFileResults.Eof();
-                                           ostk1=m_oFileResults.GetNextLine() )
+  for( ostk1.SetString( m_oFileResults.GetFirstLine( ) ); !m_oFileResults.Eof( );
+                                                  ostk1.SetString( m_oFileResults.GetNextLine( ) ) )
   {
     if( ostk1.CountTokens( ) != 7 ) continue;
 
@@ -256,8 +320,8 @@ std::cerr << "PrcGnuCap::bFmtResultsFO( ) - 1\n"; // ???
 
   // Construct the data column headers
   os1 = wxT("#Freq");
-  for( ostk1=m_oFileResults.GetFirstLine( ); !m_oFileResults.Eof( );
-                                          ostk1=m_oFileResults.GetNextLine( ) )
+  for( ostk1.SetString( m_oFileResults.GetFirstLine( ) ); !m_oFileResults.Eof( );
+                                                  ostk1.SetString( m_oFileResults.GetNextLine( ) ) )
   {
     // Look for header lines
     if( ostk1.GetNextToken( ) != wxT("#") ) continue;
@@ -286,11 +350,11 @@ std::cerr << "PrcGnuCap::bFmtResultsFO( ) - 1\n"; // ???
   m_oFileResults[ 0 ] = os1;
 
   // Determine the number of unique data lines
-  ostk1 = m_oFileResults.GetFirstLine( );
-  ostk1 = m_oFileResults.GetNextLine( );
+  ostk1.SetString( m_oFileResults.GetFirstLine( ) );
+  ostk1.SetString( m_oFileResults.GetNextLine( ) );
   os1 = ostk1.GetNextToken( );
-  for( ostk1=m_oFileResults.GetNextLine( ), sz1=1; !m_oFileResults.Eof( );
-                                   ostk1=m_oFileResults.GetNextLine( ), sz1++ )
+  for( ostk1.SetString( m_oFileResults.GetNextLine( ) ), sz1=1; !m_oFileResults.Eof( );
+                                           ostk1.SetString( m_oFileResults.GetNextLine( ) ), sz1++ )
   {
     if( os1 == ostk1.GetNextToken( ) )
       break;
@@ -300,10 +364,10 @@ std::cerr << "PrcGnuCap::bFmtResultsFO( ) - 1\n"; // ???
   for( sz2=1; sz2<=sz1; sz2++ )
   {
     m_oFileResults.GoToLine( sz2-1 );
-    ostk1=m_oFileResults.GetNextLine( );
+    ostk1.SetString( m_oFileResults.GetNextLine( ) );
     os1 = ostk1.GetNextToken( );
-    for( ostk1=m_oFileResults.GetNextLine( ); !m_oFileResults.Eof( );
-                                          ostk1=m_oFileResults.GetNextLine( ) )
+    for( ostk1.SetString( m_oFileResults.GetNextLine( ) ); !m_oFileResults.Eof( );
+                                                  ostk1.SetString( m_oFileResults.GetNextLine( ) ) )
     {
       if( os1 == ostk1.GetNextToken( ) )
         m_oFileResults[ sz2 ] << wxT(' ') << ostk1.GetString( );
@@ -315,63 +379,13 @@ std::cerr << "PrcGnuCap::bFmtResultsFO( ) - 1\n"; // ???
   while( ! m_oFileResults.Eof( ) )
     m_oFileResults.RemoveLine( m_oFileResults.GetCurrentLine( ) );
 
-  // Format the header line and data lines
-  bFmtColLabels( );
-  bFmtDataLines( );
+  // Format the column header line and insert it at the start of the file
+  bRtn = bFmtColLabels( );
 
-std::cerr << "PrcGnuCap::bFmtResultsFO( ) - 2\n"; // ???
+  // Format the data lines
+  if( ! bFmtDataLines( ) ) bRtn = false;
 
-  return( true );
-}
-
-//**************************************************************************************************
-// Format the data lines in the results file.
-//
-// Return Values :
-//   true  - Success
-//   false - Failure
-
-bool  PrcGnuCap::bFmtDataLines( void )
-{
-  wxStringTokenizer  ostk1;
-  wxString           osLine, os1;
-  size_t             sz1;
-  double             df1;
-  int                i1;
-
-  // This function requires the result file to have been opened
-  if( ! m_oFileResults.IsOpened( ) ) return( false );
-
-  for( sz1=1; sz1<m_oFileResults.GetLineCount( ); sz1++ )
-  {
-    // Get a line of data
-    osLine = m_oFileResults.GetLine( sz1 );
-
-    // Tokenize the string
-    ostk1.SetString( osLine );
-    if( ostk1.CountTokens( ) < 1 )   return( false );
-
-    // Format each field
-    osLine.Empty( );
-    while( ostk1.HasMoreTokens( ) )
-    {
-      // Add the next parameter to the line
-      os1 = ostk1.GetNextToken( );
-      if( ! CnvtType::bStrToFlt( os1, &df1 ) ) df1 =      -9.999e+99;
-      if( ! CnvtType::bFltToStr( df1, os1 ) )  os1 = wxT("-9.999e+99");
-      osLine << os1;
-
-      // Pad the column with spaces to the required width
-      i1 = GNUCAP_COL_WD - (osLine.Length( ) % GNUCAP_COL_WD);
-      osLine.Append( wxT(' '), i1 );
-    }
-
-    osLine.Trim( ); // Remove trailing space characters
-
-    m_oFileResults.GetLine( sz1 ) = osLine;
-  }
-
-  return( true );
+  return( bRtn );
 }
 
 //**************************************************************************************************
@@ -390,13 +404,13 @@ bool  PrcGnuCap::bMakeArgLst( SimnBase & roSimn )
 
   // Record the sweep source component name since GNU-Cap has a bug in the DC
   // analysis results. The column label for the sweep source values is missing.
-  m_osSwpSrcName = roSimn.m_oCpntSwpSrc.rosGetName( );
+  m_osSigSrcName = roSimn.m_oCpntSigSrc.rosGetName( );
 
   // Envoke the base class operations
   if( ! PrcSimEngBase::bMakeArgLst( roSimn ) ) return( false );
 
   // Construct the command line to execute the simulation
-  os1 = wxT("-b ") + roSimn.roGetSaveFile( ).GetFullPath( );
+  os1 = wxT("-b ") + rosEscSpaceChrs( roSimn.roGetSaveFile( ).GetFullPath( ) );
   if( ! bSetArgLst( os1 ) )
   {
     SetErrMsg( wxT("Couldn't set argument list") );
@@ -419,15 +433,15 @@ bool  PrcGnuCap::bFmtResults( void )
   bool      bRtn;
   wxString  os1;
 
-  m_osErrMsg.Empty( );
+  // Clear error message
+  PrcBase::ClrErrMsg( );
 
   // Check that the results file exists
   if( ! roGetResultsFile( ).FileExists( ) )
   {
     os1.Empty( );
-    os1 << wxT("Results file doesn't exist : \n\n")
-        << roGetResultsFile( ).GetFullPath( );
-    SetErrMsg( os1 );
+    os1 << wxT("Results file doesn't exist : \n\n") << roGetResultsFile( ).GetFullPath( );
+    PrcBase::SetErrMsg( os1 );
     return( false );
   }
 
@@ -435,22 +449,27 @@ bool  PrcGnuCap::bFmtResults( void )
   if( ! m_oFileResults.Open( roGetResultsFile( ).GetFullPath( ) ) )
   {
     os1.Empty( );
-    os1 << wxT("Results file couldn't be opened : \n\n")
-        << roGetResultsFile( ).GetFullPath( );
-    SetErrMsg( os1 );
+    os1 << wxT("Results file couldn't be opened : \n\n") << roGetResultsFile( ).GetFullPath( );
+    PrcBase::SetErrMsg( os1 );
     return( false );
   }
 
   // Format the simulation results
   os1 = roGetResultsFile( ).GetFullName( ).Right( 3 );
-  if( os1 == wxT(".fo") ) bRtn = bFmtResultsFO( );
-  else                    bRtn = bFmtCommon( );
+  if( os1 != wxT(".fo") )
+  {
+    bRtn = bFmtGeneral( );
 
-  // Need last line to end with a '\n' or text controls will not load it
-  os1 = m_oFileResults.GetLastLine( );
-  if( os1.IsEmpty( ) ) os1 = wxT(" ");
-  if( os1.GetChar( os1.Len( )-1 ) != wxT('\n') )
-    m_oFileResults.GetLastLine( ) << wxT('\n');
+    // Format the column header line and insert it at the start of the file
+    if( bRtn ) bRtn = bFmtColLabels( );
+
+    // Format the data lines
+    if( bRtn ) bRtn = bFmtDataLines( );
+  }
+  else bRtn = bFmtResultsFO( );
+
+  // Align all the columns in the results file
+  if( bRtn ) bRtn = PrcSimEngBase::bFmtResults( );
 
   m_oFileResults.Write( );  // Save the changes to disk
   m_oFileResults.Close( );  // Close the file
