@@ -3,8 +3,8 @@
 //                                         ---------------                                         *
 // Description : This class provides the interface to the GNU-Cap electronic circuit simulator.    *
 // Started     : 2003-09-01                                                                        *
-// Last Update : 2015-01-05                                                                        *
-// Copyright   : (C) 2003 by MSWaters                                                              *
+// Last Update : 2018-09-24                                                                        *
+// Copyright   : (C) 2003-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -35,10 +35,6 @@
 
 #include <wx/config.h>
 
-// Local Constant Declarations
-
-#define GNUCAP_COL_WD  14  // Width of columns of data in results files
-
 //**************************************************************************************************
 
 class PrcGnuCap : public PrcSimEngBase
@@ -46,13 +42,13 @@ class PrcGnuCap : public PrcSimEngBase
   private:
 
     // The label for the X axis variable (missing in GNU-Cap OP & DC analysis)
-    wxString  m_osSwpSrcName;
+    wxString  m_osSigSrcName;
 
     // Functions to check / format the circuit description lines
 //    bool  bFmtCpnts( ArrayComponent & roaCpnts ); ??? 17/08/2009
 
     // Format the results file
-    bool  bFmtCommon   ( void );
+    bool  bFmtGeneral  ( void );
     bool  bFmtColLabels( void );
     bool  bFmtDataLines( void );
     bool  bFmtResultsFO( void );
@@ -63,10 +59,10 @@ class PrcGnuCap : public PrcSimEngBase
                   ~PrcGnuCap( );
 
     // Create the process argument list
-    virtual  bool  bMakeArgLst( SimnBase & roSimn );
+    virtual  bool  bMakeArgLst( SimnBase & roSimn ) override;
 
     // Format the results file
-    virtual  bool  bFmtResults( void );
+    virtual  bool  bFmtResults( void ) override;
 };
 
 //**************************************************************************************************
