@@ -3,8 +3,8 @@
 //                                        ----------------                                         *
 // Description : This class provides the interface to the NG-Spice circuit simulator.              *
 // Started     : 2004-05-07                                                                        *
-// Last Update : 2015-01-05                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-09-24                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -29,10 +29,6 @@
 #include "ngspice/commands/CmdNgSpicePR.hpp"
 #include "utility/CnvtType.hpp"
 
-// Local Constant Declarations
-
-#define NGSPICE_COL_WD  14  // Width of columns of data in results files
-
 //**************************************************************************************************
 
 class PrcNgSpice : public PrcSimEngBase
@@ -52,7 +48,7 @@ class PrcNgSpice : public PrcSimEngBase
     wxString & rosMakeCmdWIDTH( wxString & rosCmdPR );
 
     // Format the results file
-    bool  bFmtCommon   ( void );
+    bool  bFmtGeneral  ( void );
     bool  bFmtColLabels( void );
     bool  bFmtDataLines( void );
     bool  bFmtPhaseData( void ); // ??? (02/02/2006) Not yet implemented
@@ -63,10 +59,10 @@ class PrcNgSpice : public PrcSimEngBase
                   ~PrcNgSpice( );
 
     // Create the process argument list
-    virtual  bool  bMakeArgLst( SimnBase & roSimn );
+    virtual  bool  bMakeArgLst( SimnBase & roSimn ) override;
 
     // Format the results file
-    virtual  bool  bFmtResults( void );
+    virtual  bool  bFmtResults( void ) override;
 };
 
 //**************************************************************************************************
