@@ -2,8 +2,8 @@
 //                                          ChoUnits.cpp                                           *
 //                                         --------------                                          *
 // Started     : 2004-03-27                                                                        *
-// Last Update : 2015-01-24                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-10-19                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -74,7 +74,7 @@ bool  ChoUnits::bClear( void )
   m_eUnitsType = eUNITS_NONE;
   m_osDefUnits = wxT("Units");
 
-  if( bIsCreated( ) ) Clear( );
+  if( bIsCreated( ) ) ChoUnits::Clear( );
 
   return( true );
 }
@@ -93,148 +93,148 @@ bool  ChoUnits::bSetUnitsType( eTypeUnits eUType )
 {
   int  i1;
 
-  if( ! bIsCreated( ) )                     return( false );
-  if( eUType==m_eUnitsType && !IsEmpty( ) ) return( true );
+  if( ! bIsCreated( ) )                               return( false );
+  if( eUType==m_eUnitsType && !ChoUnits::IsEmpty( ) ) return( true );
 
   // Load the new choice items into the control
   switch( eUType )
   {
     case eUNITS_CAP :   // Capacitance
-      Clear( ); // Delete existing choice items from the list
-      Append( wxT("F")      , new wxStringClientData(   wxT("0") ) );
-      Append( wxT("mF")     , new wxStringClientData(  wxT("-3") ) );
-      Append( wxT("uF")     , new wxStringClientData(  wxT("-6") ) );
-      Append( wxT("nF")     , new wxStringClientData(  wxT("-9") ) );
-      Append( wxT("pF")     , new wxStringClientData( wxT("-12") ) );
+      ChoUnits::Clear( ); // Delete existing choice items from the list
+      ChoUnits::Append( wxT("F")      , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Append( wxT("mF")     , new wxStringClientData(  wxT("-3") ) );
+      ChoUnits::Append( wxT("uF")     , new wxStringClientData(  wxT("-6") ) );
+      ChoUnits::Append( wxT("nF")     , new wxStringClientData(  wxT("-9") ) );
+      ChoUnits::Append( wxT("pF")     , new wxStringClientData( wxT("-12") ) );
       m_osDefUnits = wxT("uF");
       break;
 
     case eUNITS_IND :   // Inductance
-      Clear( );
-      Append( wxT("H")      , new wxStringClientData(   wxT("0") ) );
-      Append( wxT("mH")     , new wxStringClientData(  wxT("-3") ) );
-      Append( wxT("uH")     , new wxStringClientData(  wxT("-6") ) );
+      ChoUnits::Clear( );
+      ChoUnits::Append( wxT("H")      , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Append( wxT("mH")     , new wxStringClientData(  wxT("-3") ) );
+      ChoUnits::Append( wxT("uH")     , new wxStringClientData(  wxT("-6") ) );
       m_osDefUnits = wxT("mH");
       break;
 
     case eUNITS_RES :   // Resistance
-      Clear( );
-      Append( wxT("GOhm")   , new wxStringClientData(   wxT("9") ) );
-      Append( wxT("MOhm")   , new wxStringClientData(   wxT("6") ) );
-      Append( wxT("kOhm")   , new wxStringClientData(   wxT("3") ) );
-      Append( wxT("Ohm")    , new wxStringClientData(   wxT("0") ) );
-      Append( wxT("mOhm")   , new wxStringClientData(  wxT("-3") ) );
-      Append( wxT("uOhm")   , new wxStringClientData(  wxT("-6") ) );
-      Append( wxT("nOhm")   , new wxStringClientData(  wxT("-9") ) );
+      ChoUnits::Clear( );
+      ChoUnits::Append( wxT("GOhm")   , new wxStringClientData(   wxT("9") ) );
+      ChoUnits::Append( wxT("MOhm")   , new wxStringClientData(   wxT("6") ) );
+      ChoUnits::Append( wxT("kOhm")   , new wxStringClientData(   wxT("3") ) );
+      ChoUnits::Append( wxT("Ohm")    , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Append( wxT("mOhm")   , new wxStringClientData(  wxT("-3") ) );
+      ChoUnits::Append( wxT("uOhm")   , new wxStringClientData(  wxT("-6") ) );
+      ChoUnits::Append( wxT("nOhm")   , new wxStringClientData(  wxT("-9") ) );
       m_osDefUnits = wxT("kOhm");
       break;
 
     case eUNITS_COND :  // Conductance
-      Clear( );
-      Append( wxT("kS")     , new wxStringClientData(   wxT("3") ) );
-      Append( wxT("S")      , new wxStringClientData(   wxT("0") ) );
-      Append( wxT("mS")     , new wxStringClientData(  wxT("-3") ) );
-      Append( wxT("uS")     , new wxStringClientData(  wxT("-6") ) );
-      Append( wxT("nS")     , new wxStringClientData(  wxT("-9") ) );
-      Append( wxT("pS")     , new wxStringClientData( wxT("-12") ) );
-      Append( wxT("fS")     , new wxStringClientData( wxT("-15") ) );
+      ChoUnits::Clear( );
+      ChoUnits::Append( wxT("kS")     , new wxStringClientData(   wxT("3") ) );
+      ChoUnits::Append( wxT("S")      , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Append( wxT("mS")     , new wxStringClientData(  wxT("-3") ) );
+      ChoUnits::Append( wxT("uS")     , new wxStringClientData(  wxT("-6") ) );
+      ChoUnits::Append( wxT("nS")     , new wxStringClientData(  wxT("-9") ) );
+      ChoUnits::Append( wxT("pS")     , new wxStringClientData( wxT("-12") ) );
+      ChoUnits::Append( wxT("fS")     , new wxStringClientData( wxT("-15") ) );
       m_osDefUnits = wxT("mS");
       break;
 
     case eUNITS_VOLT :  // Voltage
-      Clear( );
-      Append( wxT("MV")     , new wxStringClientData(   wxT("6") ) );
-      Append( wxT("kV")     , new wxStringClientData(   wxT("3") ) );
-      Append( wxT("V")      , new wxStringClientData(   wxT("0") ) );
-      Append( wxT("mV")     , new wxStringClientData(  wxT("-3") ) );
-      Append( wxT("uV")     , new wxStringClientData(  wxT("-6") ) );
-      Append( wxT("nV")     , new wxStringClientData(  wxT("-9") ) );
-      Append( wxT("pV")     , new wxStringClientData( wxT("-12") ) );
-      Append( wxT("fV")     , new wxStringClientData( wxT("-15") ) );
+      ChoUnits::Clear( );
+      ChoUnits::Append( wxT("MV")     , new wxStringClientData(   wxT("6") ) );
+      ChoUnits::Append( wxT("kV")     , new wxStringClientData(   wxT("3") ) );
+      ChoUnits::Append( wxT("V")      , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Append( wxT("mV")     , new wxStringClientData(  wxT("-3") ) );
+      ChoUnits::Append( wxT("uV")     , new wxStringClientData(  wxT("-6") ) );
+      ChoUnits::Append( wxT("nV")     , new wxStringClientData(  wxT("-9") ) );
+      ChoUnits::Append( wxT("pV")     , new wxStringClientData( wxT("-12") ) );
+      ChoUnits::Append( wxT("fV")     , new wxStringClientData( wxT("-15") ) );
       m_osDefUnits = wxT("mV");
       break;
 
     case eUNITS_CURR :  // Current
-      Clear( );
-      Append( wxT("kA")     , new wxStringClientData(   wxT("3") ) );
-      Append( wxT("A")      , new wxStringClientData(   wxT("0") ) );
-      Append( wxT("mA")     , new wxStringClientData(  wxT("-3") ) );
-      Append( wxT("uA")     , new wxStringClientData(  wxT("-6") ) );
-      Append( wxT("nA")     , new wxStringClientData(  wxT("-9") ) );
-      Append( wxT("pA")     , new wxStringClientData( wxT("-12") ) );
+      ChoUnits::Clear( );
+      ChoUnits::Append( wxT("kA")     , new wxStringClientData(   wxT("3") ) );
+      ChoUnits::Append( wxT("A")      , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Append( wxT("mA")     , new wxStringClientData(  wxT("-3") ) );
+      ChoUnits::Append( wxT("uA")     , new wxStringClientData(  wxT("-6") ) );
+      ChoUnits::Append( wxT("nA")     , new wxStringClientData(  wxT("-9") ) );
+      ChoUnits::Append( wxT("pA")     , new wxStringClientData( wxT("-12") ) );
       m_osDefUnits = wxT("mA");
       break;
 
     case eUNITS_TIME :  // Time
-      Clear( );
-      Append( wxT("Sec")    , new wxStringClientData(   wxT("0") ) );
-      Append( wxT("mSec")   , new wxStringClientData(  wxT("-3") ) );
-      Append( wxT("uSec")   , new wxStringClientData(  wxT("-6") ) );
-      Append( wxT("nSec")   , new wxStringClientData(  wxT("-9") ) );
-      Append( wxT("pSec")   , new wxStringClientData( wxT("-12") ) );
+      ChoUnits::Clear( );
+      ChoUnits::Append( wxT("Sec")    , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Append( wxT("mSec")   , new wxStringClientData(  wxT("-3") ) );
+      ChoUnits::Append( wxT("uSec")   , new wxStringClientData(  wxT("-6") ) );
+      ChoUnits::Append( wxT("nSec")   , new wxStringClientData(  wxT("-9") ) );
+      ChoUnits::Append( wxT("pSec")   , new wxStringClientData( wxT("-12") ) );
       m_osDefUnits = wxT("mSec");
       break;
 
     case eUNITS_FREQ :  // Frequency
-      Clear( );
-      Append( wxT("THz")    , new wxStringClientData(  wxT("12") ) );
-      Append( wxT("GHz")    , new wxStringClientData(   wxT("9") ) );
-      Append( wxT("MHz")    , new wxStringClientData(   wxT("6") ) );
-      Append( wxT("kHz")    , new wxStringClientData(   wxT("3") ) );
-      Append( wxT("Hz")     , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Clear( );
+      ChoUnits::Append( wxT("THz")    , new wxStringClientData(  wxT("12") ) );
+      ChoUnits::Append( wxT("GHz")    , new wxStringClientData(   wxT("9") ) );
+      ChoUnits::Append( wxT("MHz")    , new wxStringClientData(   wxT("6") ) );
+      ChoUnits::Append( wxT("kHz")    , new wxStringClientData(   wxT("3") ) );
+      ChoUnits::Append( wxT("Hz")     , new wxStringClientData(   wxT("0") ) );
       m_osDefUnits = wxT("kHz");
       break;
 
     case eUNITS_CHRG :  // Charge
-      Clear( );
-      Append( wxT("C")      , new wxStringClientData(   wxT("0") ) );
-      Append( wxT("mC")     , new wxStringClientData(  wxT("-3") ) );
-      Append( wxT("uC")     , new wxStringClientData(  wxT("-6") ) );
-      Append( wxT("nC")     , new wxStringClientData(  wxT("-9") ) );
-      Append( wxT("pC")     , new wxStringClientData( wxT("-12") ) );
-      Append( wxT("fC")     , new wxStringClientData( wxT("-15") ) );
+      ChoUnits::Clear( );
+      ChoUnits::Append( wxT("C")      , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Append( wxT("mC")     , new wxStringClientData(  wxT("-3") ) );
+      ChoUnits::Append( wxT("uC")     , new wxStringClientData(  wxT("-6") ) );
+      ChoUnits::Append( wxT("nC")     , new wxStringClientData(  wxT("-9") ) );
+      ChoUnits::Append( wxT("pC")     , new wxStringClientData( wxT("-12") ) );
+      ChoUnits::Append( wxT("fC")     , new wxStringClientData( wxT("-15") ) );
       m_osDefUnits = wxT("uC");
       break;
 
     case eUNITS_PHAD :  // Phase / angle
     case eUNITS_PHAR :
-      Clear( );
-      Append( wxT("Degree") , new wxStringClientData(   wxT("0") ) );
-      Append( wxT("Radian") , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Clear( );
+      ChoUnits::Append( wxT("Degree") , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Append( wxT("Radian") , new wxStringClientData(   wxT("0") ) );
       m_osDefUnits = wxT("Degree");
       break;
 
     case eUNITS_TMPC :  // Temperature
     case eUNITS_TMPF :
-      Clear( );
-      Append( wxT("Deg.C")  , new wxStringClientData(   wxT("0") ) );
-      Append( wxT("Deg.F")  , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Clear( );
+      ChoUnits::Append( wxT("Deg.C")  , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Append( wxT("Deg.F")  , new wxStringClientData(   wxT("0") ) );
       m_osDefUnits = wxT("Deg.C");
       break;
 
     case eUNITS_EXP :  // Dimensionless, append an exponent
-      Clear( );
-//    Append( wxT("x 1E21") , new wxStringClientData(  wxT("21") ) );
-//    Append( wxT("x 1E18") , new wxStringClientData(  wxT("18") ) );
-      Append( wxT("x 1E15") , new wxStringClientData(  wxT("15") ) );
-      Append( wxT("x 1E12") , new wxStringClientData(  wxT("12") ) );
-      Append( wxT("x 1E9")  , new wxStringClientData(   wxT("9") ) );
-      Append( wxT("x 1E6")  , new wxStringClientData(   wxT("6") ) );
-      Append( wxT("x 1E3")  , new wxStringClientData(   wxT("3") ) );
-      Append( wxT("x 1")    , new wxStringClientData(   wxT("0") ) );
-      Append( wxT("x 1E-3") , new wxStringClientData(  wxT("-3") ) );
-      Append( wxT("x 1E-6") , new wxStringClientData(  wxT("-6") ) );
-      Append( wxT("x 1E-9") , new wxStringClientData(  wxT("-9") ) );
-      Append( wxT("x 1E-12"), new wxStringClientData( wxT("-12") ) );
-      Append( wxT("x 1E-15"), new wxStringClientData( wxT("-15") ) );
-//    Append( wxT("x 1E-18"), new wxStringClientData( wxT("-18") ) );
-//    Append( wxT("x 1E-21"), new wxStringClientData( wxT("-21") ) );
+      ChoUnits::Clear( );
+//    ChoUnits::Append( wxT("x 1E21") , new wxStringClientData(  wxT("21") ) );
+//    ChoUnits::Append( wxT("x 1E18") , new wxStringClientData(  wxT("18") ) );
+      ChoUnits::Append( wxT("x 1E15") , new wxStringClientData(  wxT("15") ) );
+      ChoUnits::Append( wxT("x 1E12") , new wxStringClientData(  wxT("12") ) );
+      ChoUnits::Append( wxT("x 1E9")  , new wxStringClientData(   wxT("9") ) );
+      ChoUnits::Append( wxT("x 1E6")  , new wxStringClientData(   wxT("6") ) );
+      ChoUnits::Append( wxT("x 1E3")  , new wxStringClientData(   wxT("3") ) );
+      ChoUnits::Append( wxT("x 1")    , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Append( wxT("x 1E-3") , new wxStringClientData(  wxT("-3") ) );
+      ChoUnits::Append( wxT("x 1E-6") , new wxStringClientData(  wxT("-6") ) );
+      ChoUnits::Append( wxT("x 1E-9") , new wxStringClientData(  wxT("-9") ) );
+      ChoUnits::Append( wxT("x 1E-12"), new wxStringClientData( wxT("-12") ) );
+      ChoUnits::Append( wxT("x 1E-15"), new wxStringClientData( wxT("-15") ) );
+//    ChoUnits::Append( wxT("x 1E-18"), new wxStringClientData( wxT("-18") ) );
+//    ChoUnits::Append( wxT("x 1E-21"), new wxStringClientData( wxT("-21") ) );
       m_osDefUnits = wxT("x 1");
       break;
 
     case eUNITS_NONE :  // No units specified
-      Clear( );
-      Append( wxT("Units")  , new wxStringClientData(   wxT("0") ) );
+      ChoUnits::Clear( );
+      ChoUnits::Append( wxT("Units")  , new wxStringClientData(   wxT("0") ) );
       m_osDefUnits = wxT("Units");
       break;
 
@@ -246,8 +246,8 @@ bool  ChoUnits::bSetUnitsType( eTypeUnits eUType )
   m_eUnitsType = eUType;
 
   // Select the default units
-  i1 = FindString( m_osDefUnits, true );  // Do case sensitive string search
-  if( i1 != wxNOT_FOUND ) SetSelection( i1 );
+  i1 = ChoUnits::FindString( m_osDefUnits, true );  // Do case sensitive string search
+  if( i1 != wxNOT_FOUND ) ChoUnits::SetSelection( i1 );
 
   return( true );
 }
@@ -277,11 +277,11 @@ bool  ChoUnits::bSetUnits( const wxString & rosUnits )
     if( eUType != eGetUnitsType( ) ) return( false );
 
   // Check that the specified units are supported
-  i1 = FindString( rosUnits );
+  i1 = ChoUnits::FindString( rosUnits );
   if( i1 == wxNOT_FOUND )            return( false );
 
   // Set the units displayed in the control
-  SetSelection( i1 );
+  ChoUnits::SetSelection( i1 );
 
   return( true );
 }
@@ -304,14 +304,14 @@ bool  ChoUnits::bSetUnits( int iExp )
 
   if( ! bIsCreated( ) ) return( false );
 
-  for( ui1=0; ui1<GetCount( ); ui1++ )
+  for( ui1=0; ui1<ChoUnits::GetCount( ); ui1++ )
   {
     li1 = 0;
-    os1 = ( (wxStringClientData *) GetClientObject( ui1 ) )->GetData( );
+    os1 = ( (wxStringClientData *) ChoUnits::GetClientObject( ui1 ) )->GetData( );
     os1.ToLong( &li1 );
     if( (int) li1 == iExp )
     {
-      SetSelection( ui1 );
+      ChoUnits::SetSelection( ui1 );
       return( true );
     }
   }
@@ -332,10 +332,10 @@ bool  ChoUnits::bSetUnits( int iExp )
 bool  ChoUnits::bSetDefUnits( const wxString & rosUnits )
 {
   // Don't proceed unless the display object has been created
-  if( ! bIsCreated( ) )                       return( false );
+  if( ! bIsCreated( ) )                                 return( false );
 
   // Attempt to find the specified units
-  if( FindString( rosUnits ) == wxNOT_FOUND ) return( false );
+  if( ChoUnits::FindString( rosUnits ) == wxNOT_FOUND ) return( false );
 
   // Set the default units
   m_osDefUnits = rosUnits;
@@ -358,7 +358,7 @@ const wxString & ChoUnits::rosGetUnits( void )
 
   if( ! bIsCreated( ) ) return( osUnits );
 
-  osUnits = GetStringSelection( );
+  osUnits = ChoUnits::GetStringSelection( );
 
   return( osUnits );
 }
@@ -379,10 +379,10 @@ int  ChoUnits::iGetUnits( void )
 
   if( ! bIsCreated( ) )                   return( 0 );
 
-  i1 = GetSelection( );
+  i1 = ChoUnits::GetSelection( );
   if( i1 == wxNOT_FOUND )                 return( 0 );
 
-  os1 = ( (wxStringClientData *) GetClientObject( i1 ) )->GetData( );
+  os1 = ( (wxStringClientData *) ChoUnits::GetClientObject( i1 ) )->GetData( );
   if( ! CnvtType::bStrToInt( os1, &i1 ) ) return( 0 );
 
   return( i1 );
