@@ -1,9 +1,9 @@
 //**************************************************************************************************
-//                                          PnlTxtSpn.cpp                                          *
-//                                         ---------------                                         *
+//                                         PnlTxtSpn.cpp                                           *
+//                                        ---------------                                          *
 // Started     : 2004-03-20                                                                        *
-// Last Update : 2015-03-17                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-10-16                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -40,6 +40,10 @@ wxEND_EVENT_TABLE( )
 
 PnlTxtSpn::PnlTxtSpn( void ) : wxPanel( )
 {
+  // m_eValType must be initialized before calling bClear( ) or valgrind complains that it's value
+  // is tested in bClear( ) before being initialized (the problem is there but is benign)
+  m_eValType = eVALUE_INT;
+
   bClear( );
 }
 
@@ -137,8 +141,8 @@ bool  PnlTxtSpn::bClear( void )
   bool  bRtn=true;
 
   if( ! bSetValType( eVALUE_FLT )      ) bRtn = false;
+  if( ! bSetRange( -10000.0, 10000.0 ) ) bRtn = false;  // bSetRange( ) must preceed bSetValDef( )
   if( ! bSetValDef( 0.0 )              ) bRtn = false;
-  if( ! bSetRange( -10000.0, 10000.0 ) ) bRtn = false;
   if( ! bSetIncSz( 1.0, 100.0 )        ) bRtn = false;
 
   if( m_oTxtValue.GetParent( ) != NULL ) m_oTxtValue.Clear( );
@@ -336,7 +340,7 @@ bool  PnlTxtSpn::bSetRange( double dfMinValue, double dfMaxValue )
   double    df1;
 
   // Check argument validity
-  if( dfMinValue >= dfMaxValue )         return( false );
+  if( dfMinValue >= dfMaxValue ) return( false );
 
   // Set new parameter values
   m_dfMinValue = dfMinValue;
@@ -346,9 +350,11 @@ bool  PnlTxtSpn::bSetRange( double dfMinValue, double dfMaxValue )
   if( bIsCreated( ) )
   {
     os1 = m_oTxtValue.GetValue( );
-    CnvtType::bStrToFlt( os1, &df1 );
-    if(      df1 < m_dfMinValue ) bSetValue( m_dfMinValue );
-    else if( df1 > m_dfMaxValue ) bSetValue( m_dfMaxValue );
+    if( CnvtType::bStrToFlt( os1, &df1 ) )
+    {
+      if(      df1 < m_dfMinValue ) bSetValue( m_dfMinValue );
+      else if( df1 > m_dfMaxValue ) bSetValue( m_dfMaxValue );
+    }
   }
 
   return( true );
@@ -528,7 +534,7 @@ void  PnlTxtSpn::OnTxtChar( wxKeyEvent & roEvtKey )
 // Argument List :
 //   roEvtCmd - An object holding information about the event
 
-void  PnlTxtSpn::OnTxtMaxLen( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  PnlTxtSpn::OnTxtMaxLen( wxCommandEvent & roEvtCmd )
 {
   wxBell( );  // Sound the system bell
 }
