@@ -2,8 +2,8 @@
 //                                          PnlValue.cpp                                           *
 //                                         --------------                                          *
 // Started     : 2004-09-14                                                                        *
-// Last Update : 2015-03-27                                                                        *
-// Copyright   : (C) 2004 by MSWaters                                                              *
+// Last Update : 2018-11-04                                                                        *
+// Copyright   : (C) 2004-2018 MSWaters                                                            *
 //**************************************************************************************************
 
 //**************************************************************************************************
@@ -194,77 +194,75 @@ bool  PnlValue::bSetValueType( eTypeValue eVType )
 
 bool  PnlValue::bSetUnitsType( eTypeUnits eUType )
 {
-  if( ! bIsCreated( ) )                            return( false );
+  bool  bRtn=true;
 
-  switch( m_eShowUnits )
+  // Check that the display object has bee created
+  if( ! bIsCreated( ) ) return( false );
+
+  // Set the choice box units type
+  if( m_oChoUnits.eGetUnitsType( ) != eUType )
   {
-    //----------------------------------------------------------------------------------------------
-    case eSHOW_CHO  :
-
-      if( m_oChoUnits.eGetUnitsType( ) == eUType ) return( true );
-      if( ! m_oChoUnits.bSetUnitsType( eUType ) )  return( false );
-
+    if( m_oChoUnits.bSetUnitsType( eUType ) )
+    {
       // Automatically set the spin control parameters
       switch( eUType )
       {
         case eUNITS_CAP  :  // Capacitance
-          bSetDefValue( 100.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 ); break;
-
+          bSetDefValue( 100.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 );
+          break;
         case eUNITS_IND  :  // Inductance
-          bSetDefValue( 100.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 ); break;
-
+          bSetDefValue( 100.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 );
+          break;
         case eUNITS_RES  :  // Resistance
-          bSetDefValue( 100.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 ); break;
-
+          bSetDefValue( 100.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 );
+          break;
         case eUNITS_COND :  // Conductance
-          bSetDefValue( 100.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 ); break;
-
+          bSetDefValue( 100.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 );
+          break;
         case eUNITS_VOLT :  // Voltage
-          bSetDefValue(   1.0 ); bSetSpnRange( -10000.0 , 10000.0 ); bSetSpnIncSz( 1.0, 1000.0 ); break;
-
+          bSetDefValue(   1.0 ); bSetSpnRange( -10000.0,10000.0 ); bSetSpnIncSz( 1.0,1000.0 );
+          break;
         case eUNITS_CURR :  // Current
-          bSetDefValue(   1.0 ); bSetSpnRange( -1001.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 ); break;
-
+          bSetDefValue(   1.0 ); bSetSpnRange( -1001.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 );
+          break;
         case eUNITS_TIME :  // Time
-          bSetDefValue(   1.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 ); break;
-
+          bSetDefValue(   1.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 );
+          break;
         case eUNITS_FREQ :  // Frequency
-          bSetDefValue( 100.0 ); bSetSpnRange(     0.01, 1001.0 ); bSetSpnIncSz( 1.0, 100.0 ); break;
-
+          bSetDefValue( 100.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 );
+          break;
         case eUNITS_CHRG :  // Charge
-          bSetDefValue( 100.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 ); break;
-
+          bSetDefValue( 100.0 ); bSetSpnRange(     0.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 );
+          break;
         case eUNITS_PHAD :  // Phase / angle in Degree
-          bSetDefValue(   0.0 ); bSetSpnRange(  -200.0 ,  200.0 ); bSetSpnIncSz( 1.0,  10.0 ); break;
-
+          bSetDefValue(   0.0 ); bSetSpnRange(  -200.0 ,  200.0 ); bSetSpnIncSz( 1.0,  10.0 );
+          break;
         case eUNITS_PHAR :  // Phase / angle in Radian
-          bSetDefValue(   0.0 ); bSetSpnRange(    -3.2 ,    3.2 ); bSetSpnIncSz( 0.1,   0.5 ); break;
-
+          bSetDefValue(   0.0 ); bSetSpnRange(    -3.2 ,    3.2 ); bSetSpnIncSz( 0.1,   0.5 );
+          break;
         case eUNITS_TMPC :  // Temperature in Celcius
-          bSetDefValue(  27.0 ); bSetSpnRange(  -273.15,  300.0 ); bSetSpnIncSz( 1.0,  10.0 ); break;
-
+          bSetDefValue(  27.0 ); bSetSpnRange(  -273.15,  300.0 ); bSetSpnIncSz( 1.0,  10.0 );
+          break;
         case eUNITS_TMPF :  // Temperature in Fahrenheit
-          bSetDefValue(  80.0 ); bSetSpnRange(  -459.7 ,  500.0 ); bSetSpnIncSz( 1.0,  10.0 ); break;
-
+          bSetDefValue(  80.0 ); bSetSpnRange(  -459.7 ,  500.0 ); bSetSpnIncSz( 1.0,  10.0 );
+          break;
         case eUNITS_EXP  :  // Exponent (dimensionless)
-          bSetDefValue(   1.0 ); bSetSpnRange( -1001.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 ); break;
-
+          bSetDefValue(   1.0 ); bSetSpnRange( -1001.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 );
+          break;
         default :
-          bSetDefValue( 100.0 ); bSetSpnRange( -1001.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 ); break;
+          bSetDefValue( 100.0 ); bSetSpnRange( -1001.0 , 1001.0 ); bSetSpnIncSz( 1.0, 100.0 );
+          break;
       }
-
-    //----------------------------------------------------------------------------------------------
-    case eSHOW_LBL  :
-
-      if( m_oLblUnits.eGetUnitsType( ) == eUType ) return( true );
-      if( ! m_oLblUnits.bSetUnitsType( eUType ) )  return( false );
-      break;
-
-    //----------------------------------------------------------------------------------------------
-    case eSHOW_NONE :                              return( false );
+    }
+    else bRtn = false;
   }
 
-  return( true );
+  // Set the static label units type
+  if( m_oLblUnits.eGetUnitsType( ) != eUType )
+    if( ! m_oLblUnits.bSetUnitsType( eUType ) )
+      bRtn = false;
+
+  return( bRtn );
 }
 
 //**************************************************************************************************
@@ -537,17 +535,17 @@ bool  PnlValue::bSetUnits( const wxString & rosUnits )
 // control allowes the user to specify the units. A label simply displays the units.
 //
 // Argument List :
-//   eShow - Enumerated show (units) specifier
+//   eShowUnits - Enumerated show (units) specifier
 //
 // Return Values :
 //   Success - true
 //   Failure - false
 
-bool  PnlValue::bShowUnits( eTypeShow eShow )
+bool  PnlValue::bShowUnits( eTypeShow eShowUnits )
 {
   if( ! bIsCreated( ) ) return( false );
 
-  switch( eShow )
+  switch( eShowUnits )
   {
     case eSHOW_CHO  :
       m_oChoUnits.Show( true );
@@ -565,7 +563,7 @@ bool  PnlValue::bShowUnits( eTypeShow eShow )
       break;
   }
 
-  m_eShowUnits = eShow;
+  m_eShowUnits = eShowUnits;
 
   return( true );
 }
@@ -751,9 +749,11 @@ const wxString & PnlValue::rosGetUnits( void )
   {
     case eSHOW_CHO  :
       osUnits = m_oChoUnits.rosGetUnits( );
+      break;
 
     case eSHOW_LBL  :
       osUnits = m_oLblUnits.rosGetUnits( );
+      break;
 
     case eSHOW_NONE :
       break;
@@ -850,7 +850,7 @@ void  PnlValue::OnSpnScroll( wxSpinEvent & roEvtSpn )
 // Argument List :
 //   roEvtCmd - An object holding information about the event
 
-void  PnlValue::OnChoUnits( wxCommandEvent & WXUNUSED( roEvtCmd ) )
+void  PnlValue::OnChoUnits( wxCommandEvent & roEvtCmd )
 {
   eTypeUnits  eUType;
 
